// 提前加载env, 使config文件中可以获取到process.env参数
const dotenv = require('dotenv');

const { when } = require('@craco/craco');
const { BundleAnalyzerPlugin } = require('webpack-bundle-analyzer');
const path = require('path');
const { ProvidePlugin } = require('webpack');
const CracoLessPlugin = require('craco-less');
const ip = require('ip');
// antd V5 js变量转 v4 less变量
const { theme } = require('antd/lib');
const { convertLegacyToken } = require('@ant-design/compatible/lib');

const { defaultAlgorithm, defaultSeed } = theme;
const v4Token = convertLegacyToken(defaultAlgorithm(defaultSeed));
if (process.env.NODE_ENV === 'development') {
  dotenv.config({ path: '.env.development.local' });
}
module.exports = {
  devServer: {
    client: {
      overlay: {
        runtimeErrors: false,
      },
    },
  },
  style: {
    css: {
      loaderOptions: {
        modules: {
          exportLocalsConvention: 'camelCase',
        },
      },
    },
  },
  webpack: {
    alias: { '@': path.resolve(__dirname, 'src') },
    plugins: [
      new ProvidePlugin({
        Buffer: ['buffer', 'Buffer'],
        process: 'process',
      }),
    ],
    configure: {
      resolve: {
        fallback: {
          assert: require.resolve('assert'),
          buffer: require.resolve('buffer'),
          constants: require.resolve('constants-browserify'),
          crypto: require.resolve('crypto-browserify'),
          stream: require.resolve('stream-browserify'),
          process: require.resolve('process/browser'),
        },
      },
    },
  },

  plugins: [
    {
      plugin: CracoLessPlugin,
      options: {
        lessLoaderOptions: {
          lessOptions: {
            javascriptEnabled: true,
            modifyVars: v4Token,
          },
        },
      },
    },
  ],
};
