import React from 'react';
import PropTypes from 'prop-types';
import { Radio, Space } from 'antd';
import { useBackendOptions } from '@/hooks';

function RemoteRadio(props) {
  const {
    codeName,
    requestUrl,
    requestParam,
    valueAttr,
    titleAttr,
    refreshDeps,
    direction,
    ...restProps
  } = props;
  const [options] = useBackendOptions({
    codeName,
    requestUrl,
    requestParam,
    valueAttr,
    titleAttr,
    refreshDeps,
  });
  return (
    <Radio.Group {...restProps}>
      <Space direction={direction} wrap>
        {options.map((v) => (
          <Radio key={v.value} className="leading-[32px]" value={v.value}>
            {v.label}
          </Radio>
        ))}
      </Space>
    </Radio.Group>
  );
}

RemoteRadio.propTypes = {
  codeName: PropTypes.string,
  requestUrl: PropTypes.string,
  requestParam: PropTypes.object,
  valueAttr: PropTypes.string,
  titleAttr: PropTypes.string,
  refreshDeps: PropTypes.array,
};

RemoteRadio.defaultProps = {
  requestUrl: '/system/commonUtils/getSelectOption',
  valueAttr: 'key',
  titleAttr: 'label',
  direction: 'horizontal',
};
export default RemoteRadio;
