import React, { CSSProperties } from 'react';
import { ReloadOutlined, SearchOutlined } from '@ant-design/icons';
import { Button, Form, Space } from 'antd';
import { FormInstance } from 'antd/es/form/hooks/useForm';
import { RenderFormItem } from './FormBuilder';

interface SearchBarProps {
  itemList: any[];
  onSearch: (val?: any) => void;
  form?: FormInstance;
  componentProps?: object;
  style?: CSSProperties;
}

function SearchBar(props: SearchBarProps) {
  const [defaultForm] = Form.useForm();
  const { style, onSearch, itemList, componentProps, form = defaultForm } = props;

  function handleOnSearch() {
    form.validateFields().then((value) => onSearch(value));
  }

  function handleReset() {
    form.resetFields();
    onSearch(form.getFieldsValue());
  }

  return (
    <Form layout="inline" form={form} style={style}>
      {itemList.map((obj) => (
        <RenderFormItem key={obj.key} form={form} formItem={obj} componentProps={componentProps} />
      ))}

      <Form.Item>
        <Space>
          <Button
            {...componentProps}
            icon={<SearchOutlined />}
            onClick={handleOnSearch}
            type="primary"
          >
            查询
          </Button>
          <Button {...componentProps} icon={<ReloadOutlined />} onClick={handleReset}>
            重置
          </Button>
        </Space>
      </Form.Item>
    </Form>
  );
}

SearchBar.defaultProps = {
  // componentProps: { size: 'default' },
  style: { marginBottom: 16 },
};

export default SearchBar;
