import React, { useEffect, useState } from 'react';
import { ReloadOutlined, SearchOutlined } from '@ant-design/icons';
import { Button, Form } from 'antd';
import { FormInstance } from 'antd/es/form/hooks/useForm';
import { useToggle } from 'ahooks';
import classnames from 'classnames';
import { RenderFormItem } from './FormBuilder';
import ExpandBtn from '../common/Expand/ExpandBtn';

interface SearchBarProps {
  itemList: any[];
  onSearch: (val?: any) => void;
  form?: FormInstance;
  number?: number;
  xs?: number;
  sm?: number;
  md?: number;
  lg?: number;
  xl?: number;
  xxl?: number;
}

function SearchBarCollapse(props: SearchBarProps) {
  const [defaultForm] = Form.useForm();
  const { onSearch, itemList, form = defaultForm, number = 3, sm, md, lg, xl, xxl, xs } = props;
  const [expand, { toggle }] = useToggle(false);
  const [defaultShowNumber, setDefaultShowNumber] = useState(number);
  const widthNumber = [
    { width: 576, n: sm },
    { width: 768, n: md },
    { width: 992, n: lg },
    { width: 1200, n: xl },
    { width: 1600, n: xxl },
  ];

  useEffect(() => {
    window.addEventListener('resize', getWidth);
    return () => {
      window.removeEventListener('resize', getWidth);
    };
  }, []);

  function getWidth(e: any) {
    if (e.target.innerWidth < 576) {
      setDefaultShowNumber(xs || number);
    }
    Object.keys(widthNumber).forEach((key) => {
      // @ts-ignore
      // 处理 obj[key]
      const { width, n = number } = widthNumber[key];
      if (e.target.innerWidth >= width) {
        setDefaultShowNumber(n);
      }
    });
  }

  function handleReset() {
    form.resetFields();
    onSearch(form.getFieldsValue());
  }

  function handleSubmit() {
    form.validateFields().then((values) => {
      onSearch(values);
    });
  }

  const renderForm = (list: any[], expandParam = true) =>
    list.map((obj: any) => (
      <div key={obj.key} className={classnames({ 'mb-[8px]': expandParam })}>
        <RenderFormItem form={form} formItem={obj} />
      </div>
    ));

  return (
    <div className="flex">
      <Form layout="inline" form={form}>
        {renderForm(itemList.slice(0, defaultShowNumber))}
        {expand && renderForm(itemList.slice(defaultShowNumber))}
      </Form>
      <div className="flex mb-[8px] items-end">
        <Button icon={<SearchOutlined />} onClick={handleSubmit} type="primary">
          查询
        </Button>
        <Button className="ml-[8px]" icon={<ReloadOutlined />} onClick={handleReset}>
          重置
        </Button>
        {itemList.length > defaultShowNumber && (
          <ExpandBtn onClick={() => toggle()} expand={expand} className="ml-[8px]" />
        )}
      </div>
    </div>
  );
}

export default SearchBarCollapse;
