import React from 'react';
import { ReloadOutlined, SearchOutlined } from '@ant-design/icons';
import { Button, Drawer, Form, Space } from 'antd';
import { useBoolean } from 'ahooks';
import './AdvSearch.less';
import FormBuilder from '../../forms/FormBuilder';
import { useIndexPageContext } from './index';

interface AdvSearchProps {
  itemList: any[];
}

function AdvSearch(props: AdvSearchProps) {
  const { itemList } = props;
  const [drawerVisible, { setFalse, toggle }] = useBoolean(false);
  const { searchForm, fetchTableData } = useIndexPageContext();

  function toggleVisible() {
    toggle();
  }

  function handleSearchBtn() {
    searchForm.validateFields().then(() => {
      fetchTableData();
      setFalse();
    });
  }

  function handleReset() {
    searchForm.resetFields();
    fetchTableData();
  }

  return (
    <div className="adv-search-container">
      <div className="adv-search-handler" onClick={toggleVisible}>
        <SearchOutlined />
        高级查询
      </div>
      <Drawer
        title="高级查询"
        placement="right"
        onClose={setFalse}
        open={drawerVisible}
        width={400}
        rootClassName="adv-search-drawer"
        forceRender
        footer={
          <div style={{ textAlign: 'right' }}>
            <Space>
              <Button type="primary" icon={<SearchOutlined />} onClick={handleSearchBtn}>
                查询
              </Button>
              <Button onClick={handleReset} icon={<ReloadOutlined />}>
                重置
              </Button>
              <Button onClick={setFalse}>关闭</Button>
            </Space>
          </div>
        }
      >
        <Form form={searchForm}>
          <FormBuilder items={itemList} />
        </Form>
      </Drawer>
    </div>
  );
}

export default AdvSearch;
