import React, { ReactNode, useEffect, useRef, useState } from 'react';
import { Card, Col, Row, Table } from 'antd';
import { useSize } from 'ahooks';
import styles from '@/components/hoc/IndexPage/IndexPageNew.module.less';
import classNames from 'classnames';
import ToolBar from '../../ToolBar';
import IndexPagePurchaseSearchForm from './IndexPagePurchaseSearchForm';
import { useIndexPageContext } from './index';
import IndexPageIntroduce from './IndexPageIntroduce';
import request from '../../../utils/request';
import GetBusinessGuideConfiguration from '../../system/GetBusinessGuideConfiguration';

interface IndexPageProps {
  pageTitle: string;
  sceneNumber?: string;
  searchBarItemList?: any[];
  tableColumns: any[];
  pageExtra?: ReactNode;
  tableTitle?: ReactNode;
  tabList?: any[];
  onTabChange?: (key: string) => void;
  tableProps?: object;
  toolBarItemList?: any[];
  onSearch?: (val?: any) => void;
  showEmptyCellPlaceholder?: boolean;
}

function IndexPagePurchase(props: IndexPageProps) {
  const {
    pageTitle,
    pageExtra,
    tableTitle,
    tabList,
    onTabChange,
    searchBarItemList,
    tableColumns,
    tableProps,
    toolBarItemList,
    sceneNumber,
    onSearch,
    showEmptyCellPlaceholder = true,
  } = props;

  // @ts-ignore
  const { className, ...restTableProps } = tableProps || {};

  const {
    tableData,
    tableLoading,
    pagination,
    fetchTableData,
    selectedRowKeys,
    setSelectedRowKeys,
  } = useIndexPageContext();
  const colLeftRef = useRef(null);
  const [introduceList, setIntroduceList] = useState([]);

  const hasToolBarItemList: boolean = Array.isArray(toolBarItemList) && toolBarItemList.length > 0;
  const rowSelection = hasToolBarItemList
    ? { selectedRowKeys, onChange: setSelectedRowKeys }
    : undefined;

  useEffect(() => {
    if (sceneNumber) {
      fetchIntroduceList();
    }
  }, [sceneNumber]);

  const colLeftSize = useSize(colLeftRef.current);

  function fetchIntroduceList() {
    request.getWMessage('system-businessScenario-q-003', { sceneNumber }).then((res) => {
      const newIntroduce: any = GetBusinessGuideConfiguration(res.data);
      setIntroduceList(newIntroduce);
    });
  }

  function handleTableChange(page: any, filters: any, sorter: any) {
    const param = {
      current: page.current,
      pageSize: page.pageSize,
      sortField: sorter.field,
      sortOrder: sorter.order,
      ...filters,
    };
    fetchTableData(param);
  }

  return (
    <Row gutter={12} className="fullBox">
      <Col span={introduceList.length > 0 ? 20 : 24} className={styles.indexPageBox}>
        <Card
          title={<span style={{ fontWeight: 'bolder', fontSize: '18px' }}>{pageTitle}</span>}
          extra={pageExtra}
          className="!mb-4"
        >
          {searchBarItemList && (
            <IndexPagePurchaseSearchForm itemList={searchBarItemList} onSearch={onSearch} />
          )}
        </Card>

        <Card className={styles.tableListStyle} tabList={tabList} onTabChange={onTabChange}>
          {tableTitle}
          <Table
            className={classNames(
              { [styles.cellPlaceholder]: showEmptyCellPlaceholder },
              className,
            )}
            rowKey="id"
            size="middle"
            bordered
            columns={tableColumns}
            dataSource={tableData}
            loading={tableLoading}
            rowSelection={rowSelection}
            onChange={handleTableChange}
            pagination={{
              ...pagination,
              showQuickJumper: true,
              showSizeChanger: true,
              showTotal: (total) => `共 ${total} 项`,
            }}
            {...restTableProps}
          />
          {hasToolBarItemList && (
            <ToolBar
              className={classNames(styles.toolbar, {
                [styles.toolbarShift]: tableData.length > 0,
              })}
              itemList={toolBarItemList || []}
            />
          )}
        </Card>
      </Col>
      <Col span={!introduceList.length ? 0 : 4} ref={colLeftRef}>
        <div className={styles.introduceList}>
          <div className={styles.introduceListBox} style={{ width: colLeftSize?.width }}>
            {introduceList.map((i) => (
              <IndexPageIntroduce itemObj={i} key={i} />
            ))}
          </div>
        </div>
      </Col>
    </Row>
  );
}

export default IndexPagePurchase;
