import React, { useEffect, useState } from 'react';
import { Button, Form, Space } from 'antd';
import { DownOutlined, ReloadOutlined, SearchOutlined, UpOutlined } from '@ant-design/icons';
import FormBuilder, { RenderFormItem } from '../../forms/FormBuilder';
import { useIndexPageContext } from './index';

interface IndexPageNewSearchFormProps {
  itemList: any[];
  colLayout?: any;
  formItemLayout?: any;
  onSearch?: (val?: any) => void;
}

function IndexPagePurchaseSearchForm(props: IndexPageNewSearchFormProps) {
  const { itemList, colLayout, formItemLayout, onSearch } = props;
  const [showAll, setShowAll] = useState(false);
  const [allForm, setAllForm] = useState({});

  useEffect(() => {
    if (itemList.length <= 3) {
      setShowAll(true);
    }
  }, [itemList]);

  const { searchForm, fetchTableData } = useIndexPageContext();

  function handleReset() {
    searchForm.resetFields();
    if (onSearch) {
      onSearch(searchForm.getFieldsValue());
    } else {
      fetchTableData();
    }
  }

  function handleSearch() {
    const param = { ...allForm, ...searchForm.getFieldsValue() };
    if (onSearch) {
      onSearch(param);
    } else {
      fetchTableData(param);
    }
  }

  function handleShowAllSearch() {
    setShowAll(!showAll);
    setAllForm(searchForm.getFieldsValue());
  }

  const showItemList = showAll ? itemList : itemList.slice(0, 3);
  const formShowInline = itemList.length <= 3 || !showAll;
  const searchButton = (
    <Space>
      <Button icon={<SearchOutlined />} type="primary" onClick={handleSearch}>
        查询
      </Button>
      <Button icon={<ReloadOutlined />} onClick={handleReset}>
        重置
      </Button>
      {itemList.length > 3 && (
        <Button icon={showAll ? <UpOutlined /> : <DownOutlined />} onClick={handleShowAllSearch}>
          {showAll ? '收起' : '展开'}
        </Button>
      )}
    </Space>
  );
  return formShowInline ? (
    <Form form={searchForm} layout="inline">
      {showItemList.map((obj) => (
        <RenderFormItem key={obj.key} form={searchForm} formItem={obj} />
      ))}
      <Form.Item>{searchButton}</Form.Item>
    </Form>
  ) : (
    <>
      <Form form={searchForm} {...formItemLayout}>
        <FormBuilder items={showItemList} colLayout={colLayout} />
      </Form>
      <div className="text-right">{searchButton}</div>
    </>
  );
}

IndexPagePurchaseSearchForm.defaultProps = {
  formItemLayout: { labelCol: { span: 8 }, wrapperCol: { span: 16 } },
  colLayout: { lg: 8, md: 8, sm: 16 },
};

export default IndexPagePurchaseSearchForm;
