import React from 'react';
import { useHistory, useRouteMatch } from 'react-router-dom';
import { Badge, Steps } from 'antd';
import './MenuSteps.less';
import { MenuItem } from './withIndexPage';

interface MenuStepProps {
  menu: MenuItem[];
}

function MenuSteps(props: MenuStepProps) {
  const { menu } = props;

  const history = useHistory();
  const match = useRouteMatch();

  return (
    <Steps labelPlacement="vertical" className="custom-menu-steps">
      {menu.map(({ permission, link, name, icon, dataCount }) => (
        <Steps.Step
          className={permission ? 'step-active' : 'step-inactive'}
          key={link}
          icon={
            <Badge count={permission ? dataCount : 0}>
              <img src={process.env.PUBLIC_URL + icon} height="50" width="50" alt="logo" />
            </Badge>
          }
          title={name}
          status={match.path === link ? 'process' : 'wait'}
          onClick={permission ? () => history.push(link) : undefined}
        />
      ))}
    </Steps>
  );
}

MenuSteps.defaultProps = {};
export default MenuSteps;
