import React from 'react';
import { Table } from 'antd';
import ToolBar from '../../ToolBar';
import { useManagePage } from './index';
import ManagePageForm, { ManagePageFormProps } from './ManagePageForm';
import SearchBarCollapse from '../../forms/SearchBarCollapse';
import './ManagePage.less';

interface ManagePageProps {
  searchBarItemList?: any[];
  tableColumns: any[];
  tableProps?: any;
  toolBarItemList?: any[];
  formItemList?: any[];
  onFormSubmit?: (val: any) => PromiseLike<any>;
  formProps?: ManagePageFormProps;
  onSearch?: (val?: any) => void;
  number?: number;
  xs?: number;
  sm?: number;
  md?: number;
  lg?: number;
  xl?: number;
  xxl?: number;
}

function ManagePage(props: ManagePageProps) {
  const {
    toolBarItemList,
    searchBarItemList,
    tableColumns,
    tableProps = {},
    formProps,
    formItemList,
    onFormSubmit,
    onSearch,
    number,
    ...searchBarProps
  } = props;
  const rowKey = tableProps.rowKey || 'id';

  const managePage = useManagePage();
  const hasToolBarItemList: boolean = Array.isArray(toolBarItemList) && toolBarItemList.length > 0;

  function handleTableChange(pagination: any, filters: any, sorter: any) {
    const param = {
      current: pagination.current,
      pageSize: pagination.pageSize,
      sortField: sorter.field,
      sortOrder: sorter.order === 'ascend' ? 'asc' : 'desc',
      ...filters,
    };

    managePage.fetchTableData(param);
  }

  function handleSearch(params: any) {
    if (onSearch) {
      onSearch(params);
    } else {
      managePage.fetchTableData(params);
    }
  }

  return (
    <>
      {searchBarItemList && (
        <SearchBarCollapse
          form={managePage.searchBarForm}
          itemList={searchBarItemList}
          number={number || searchBarItemList.length}
          onSearch={handleSearch}
          {...searchBarProps}
        />
      )}
      <Table
        rowKey="id"
        size="middle"
        columns={tableColumns}
        dataSource={managePage.tableData}
        loading={managePage.tableLoading}
        // @ts-ignore
        footer={hasToolBarItemList ? () => <ToolBar itemList={toolBarItemList} /> : undefined}
        rowSelection={
          hasToolBarItemList
            ? {
                selectedRowKeys: managePage.selectedRowKeys,
                onChange: managePage.setSelectedRowKeys,
              }
            : undefined
        }
        onRow={(record: any, index: any) => ({
          onDoubleClick: () => {
            managePage.setFormInitVal(record);
            managePage.setSelectedRowKeys([record[rowKey]], [record]);
            managePage.setFormVisible(true);
          },
          index,
        })}
        onChange={handleTableChange}
        pagination={{
          ...managePage.pagination,
          showQuickJumper: true,
          showSizeChanger: true,
          showTotal: (total) => `共 ${total} 项`,
        }}
        {...tableProps}
      />
      {Array.isArray(formItemList) && (
        <ManagePageForm itemList={formItemList} onOk={onFormSubmit} {...formProps} />
      )}
    </>
  );
}

export default ManagePage;
