import React, { ReactNode } from 'react';
import { Form, Modal } from 'antd';
import { useBoolean } from 'ahooks';
import FormBuilder from '../../forms/FormBuilder';
import { useManagePage } from './index';

export interface ManagePageFormProps {
  itemList: any[];
  onOk?: (val: any) => PromiseLike<any>;
  width?: number;
  title?: ReactNode;
  formItemLayout?: any;
}

function ManagePageForm(props: ManagePageFormProps) {
  const { width, title, itemList, formItemLayout, onOk } = props;
  const { editForm, formVisible, setFormVisible } = useManagePage();
  const [loading, { setTrue, setFalse }] = useBoolean(false);

  const id = editForm.getFieldValue('id');

  function handleFormSubmit() {
    return editForm
      .validateFields()
      .then((values: any) => {
        if (onOk) {
          setTrue();
          return onOk(values);
        }
        return null;
      })
      .finally(setFalse);
  }

  return (
    <Modal
      centered
      open={formVisible}
      title={title || (id ? '修改' : '新增')}
      width={width}
      onOk={handleFormSubmit}
      onCancel={() => setFormVisible(false)}
      bodyStyle={{ maxHeight: '70vh', overflowY: 'auto' }}
      confirmLoading={loading}
    >
      <Form layout="horizontal" form={editForm} {...formItemLayout}>
        <FormBuilder items={itemList} />
      </Form>
    </Modal>
  );
}

ManagePageForm.defaultProps = {
  width: 700,
  loading: false,
  onOk: () => null,
  formItemLayout: {
    labelCol: { span: 6 },
    wrapperCol: { span: 16 },
  },
};

export default ManagePageForm;
