import React, { useEffect, useState } from 'react';
import { Form } from 'antd';
import { useRequest } from 'ahooks';
import request from '../../../utils/request';

export const ManagePageContext = React.createContext({} as any);

const withManagePage = (
  WrappedComponent: any,
  fetchRequestURL?: string,
  fetchRequestParam?: object,
) =>
  function ManagePageContainer(props: any) {
    const [currentRequestURL, setCurrentRequestURL] = useState(fetchRequestURL);
    const [currentRequestParam, setCurrentRequestParam] = useState(fetchRequestParam);
    const [selectedRows, setSelectedRows] = useState([]);
    const [selectedRowKeys, setSelectedRowKeys] = useState([]);
    const [tableData, setTableData] = useState([]);
    const [pagination, setPagination] = useState({ total: 0, current: 1, pageSize: 10 });
    const [formVisible, setFormVisible] = useState(false);
    const [editForm] = Form.useForm();
    const [searchBarForm] = Form.useForm();

    const {
      loading: tableLoading,
      run,
      refresh,
    } = useRequest(fetchTableData, {
      manual: true,
      refreshDeps: [currentRequestURL, currentRequestParam],
    });

    useEffect(() => {
      run();
    }, [currentRequestURL, currentRequestParam]);

    function fetchTableData(params?: any) {
      if (currentRequestURL) {
        const searchParams = searchBarForm.getFieldsValue();
        return request
          .get(currentRequestURL, {
            ...currentRequestParam,
            ...searchParams,
            pageSize: pagination.pageSize,
            ...params,
          })
          .then((res: any) => {
            if (res && res.code > 0 && res.data) {
              setTableData(res.data.list);
              setPagination({
                current: res.data.current,
                total: res.data.total,
                pageSize: res.data.pageSize,
              });
              setSelectedRows([]);
              setSelectedRowKeys([]);
            }
          });
      }
      return Promise.reject();
    }

    function setFetchURLAndParam(url: string, param: object | undefined = fetchRequestParam) {
      setCurrentRequestURL(url);
      setCurrentRequestParam(param);
    }

    function handleSetSelectedRowKeys(selectedRowKeysNow = [], selectedRowsNow = []) {
      setSelectedRows(selectedRowsNow);
      setSelectedRowKeys(selectedRowKeysNow);
    }

    function onSubmit(url: string, params: object) {
      return request.postWMessage(url, params).then((res) => {
        setFormVisible(false);
        refresh();
        return res;
      });
    }

    function handleAdd() {
      editForm.resetFields();
      setFormVisible(true);
    }

    function handleEdit() {
      editForm.setFieldsValue(selectedRows[0]);
      setFormVisible(true);
    }

    return (
      <ManagePageContext.Provider
        value={{
          selectedRows,
          selectedRowKeys,
          editForm,
          formVisible,
          pagination,
          tableLoading,
          tableData,
          searchBarForm,
          handleAdd,
          handleEdit,
          onSubmit,
          setFormVisible,
          setFormInitVal: editForm.setFieldsValue,
          setSelectedRowKeys: handleSetSelectedRowKeys,
          fetchTableData: run,
          refreshTableData: refresh,
          setFetchURLAndParam,
        }}
      >
        <WrappedComponent
          onSubmit={onSubmit}
          selectedRows={selectedRows}
          selectedRowKeys={selectedRowKeys}
          setSelectedRowKeys={handleSetSelectedRowKeys}
          fetchTableData={run}
          refreshTableData={refresh}
          form={editForm}
          searchBarForm={searchBarForm}
          setFormVisible={setFormVisible}
          setFormInitVal={editForm.setFieldsValue}
          handleAdd={handleAdd}
          handleEdit={handleEdit}
          setFetchURLAndParam={setFetchURLAndParam}
          {...props}
        />
      </ManagePageContext.Provider>
    );
  };

export default withManagePage;
