import { Tag } from 'antd';
import { TenantUserTypeColor } from '@/const/TenantType';
import {
  SyncOptionStatusColor,
  SyncOptionStatusName,
} from '@/pages/system/syncProcess/ProcessStatus';
import React from 'react';
import dayjs from 'dayjs';

const publicCol = [
  {
    title: '业务主键',
    dataIndex: 'businessId',
    key: 'businessId',
    align: 'center',
    width: 180,
  },
  {
    key: 'operateType',
    dataIndex: 'operateType',
    title: '操作类型',
    width: 80,
    align: 'center',
    render: (text) => (
      <span className={SyncOptionStatusColor[text]}>{SyncOptionStatusName[text]}</span>
    ),
  },
];

export const logDetailsInfoCol = [
  {
    title: '序号',
    dataIndex: 'index',
    key: 'index',
    width: 50,
    align: 'center',
    render: (text, record, index) => index + 1,
  },
  {
    dataIndex: 'tenantryUserType',
    key: 'tenantryUserType',
    title: '源租户',
    align: 'center',
    width: 120,
    render: (text, record) => {
      if (text) {
        return (
          <Tag color={TenantUserTypeColor[text]} className="py-1 px-1 w-24 text-sm text-center">
            {record.tenantryName}
          </Tag>
        );
      }
      return '-';
    },
  },
  {
    title: '来源主机',
    dataIndex: 'sourceHost',
    key: 'sourceHost',
    width: 120,
    align: 'center',
    render: (text) => text || '-',
  },
  {
    title: '业务类型',
    dataIndex: 'businessName',
    key: 'businessName',
    width: 100,
    align: 'center',
    render: (text) => text || '-',
  },
  {
    title: '数据模型',
    dataIndex: 'modelName',
    width: 120,
    align: 'center',
  },
  {
    title: '同步类型',
    dataIndex: 'syncType',
    key: 'syncType',
    width: 100,
    align: 'center',
  },
  ...publicCol,
  {
    title: '监听时间',
    dataIndex: 'syncTime',
    width: 150,
    align: 'center',
    render: (text) => (text ? dayjs(text).format('YYYY-MM-DD HH:mm:ss') : '-'),
  },
];
export const SynchronizationDetailsCol = [
  {
    title: '序号',
    dataIndex: 'index',
    key: 'index',
    width: 50,
    align: 'center',
    render: (text, record, index) => index + 1,
  },
  {
    dataIndex: 'tenantryUserType',
    key: 'tenantryUserType',
    title: '目标租户',
    align: 'center',
    width: 120,
    render: (text, record) => {
      if (text) {
        return (
          <Tag color={TenantUserTypeColor[text]} className="py-1 px-1 w-24 text-sm text-center">
            {record.tenantryName}
          </Tag>
        );
      }
      return '-';
    },
  },
  {
    title: '目标主机',
    dataIndex: 'hostName',
    key: 'hostName',
    width: 120,
    align: 'center',
  },
  {
    title: '表名',
    dataIndex: 'dataTableName',
    key: 'dataTableName',
    width: 120,
    align: 'center',
  },
  ...publicCol,
  {
    title: '命中时间',
    dataIndex: 'syncTime',
    key: 'syncTime',
    width: 150,
    align: 'center',
    render: (text) => (text ? dayjs(text).format('YYYY-MM-DD HH:mm:ss') : '-'),
  },
];
