import { Button, Drawer, Space, Table } from 'antd';
import React, { useEffect, useState } from 'react';
import request from '@/utils/request';
import {
  publicMessageAuthorization,
  publicMessageItemList,
} from '@/pages/system/message/MessageCommon';
import SearchBar from '@/components/forms/SearchBar';

function AddTemplate(props) {
  const { drawerVisible, setFalse, smsArea, setSelectedRowKeys, selectedRowKeys, fetchTableData } =
    props;
  const [drawerDataSource, setDrawerDataSource] = useState([]);
  const [pagination, setPagination] = useState({ total: 0, current: 1, pageSize: 10 });
  const columns = [
    ...publicMessageAuthorization,
    {
      title: '模板类型',
      dataIndex: 'templateType',
      key: 'templateType',
      align: 'center',
      width: 100,
      render: () => '条件触发',
    },
  ];
  useEffect(() => {
    if (smsArea) {
      fetchAddHostTableData();
    }
  }, [drawerVisible]);
  function fetchAddHostTableData() {
    request
      .getWMessage('/manager/smsTemplate/templateList', {
        isEnable: true,
      })
      .then((res) => {
        setDrawerDataSource(res.data.list || []);
        setPagination({
          current: res.data.current,
          total: res.data.total,
          pageSize: res.data.pageSize,
        });
      });
  }
  function handleSave() {
    request
      .postWMessage('/manager/smsTemplateAccredit/addTemplateAccredit', {
        smsArea,
        templateIds: selectedRowKeys,
      })
      .then(() => {
        setFalse();
        fetchTableData({ smsArea });
      });
  }
  function onClose() {
    setFalse();
    setSelectedRowKeys([]);
    fetchTableData({ smsArea });
  }
  function onSearch(value) {
    fetchAddHostTableData({ pageSize: pagination.pageSize, ...value });
  }
  return (
    <Drawer
      title="添加短信模板"
      open={drawerVisible}
      onClose={onClose}
      width={'45vw'}
      closeIcon
      footer={
        <div className="text-right">
          <Space>
            <Button onClick={onClose}>取消</Button>
            <Button type="primary" onClick={handleSave}>
              确定
            </Button>
          </Space>
        </div>
      }
    >
      <SearchBar onSearch={onSearch} itemList={publicMessageItemList} />
      <Table
        dataSource={drawerDataSource}
        columns={columns}
        rowKey="id"
        rowSelection={{
          selectedRowKeys,
          type: 'checkbox',
          onChange: (keys) => {
            setSelectedRowKeys(keys);
          },
        }}
        pagination={{
          ...pagination,
          showQuickJumper: true,
          showSizeChanger: true,
          showTotal: (total) => `共 ${total} 项`,
        }}
      />
    </Drawer>
  );
}
export default AddTemplate;
