import { Button, Card, Col, Form, message, Popconfirm, Row, Select, Space, Tag } from 'antd';
import StepDot from '@/components/widget/stepDot/StepDot';
import SelectAssociationCondition from '@/components/common/selectCondition/SelectAssociationCondition';
import { EditableProTable } from '@ant-design/pro-table';
import { useEffect, useRef, useState } from 'react';
import { useBoolean } from 'ahooks';
import FilterConditionModal from '@/components/common/selectCondition/FilterConditionModal';
import { v4 as uuid } from 'uuid';
import EvalToolbar from '@/components/evalBid/EvalToolbar';
import { useHistory, useParams } from 'react-router-dom';
import request from '@/utils/request';

function MappingFieldsSelect({ tableName, onChange, value }) {
  const [options, setOptions] = useState([]);
  function fetchSelectOptions() {
    return request.getWMessage('/syndata/dataModel/getTableColumn', { tableName }).then((res) => {
      const { data } = res;
      const optionsList = data.map((i) => ({ value: i, label: i }));
      setOptions(optionsList);
    });
  }
  useEffect(() => {
    if (tableName) {
      fetchSelectOptions();
    }
  }, [tableName]);
  return (
    <Select
      options={options}
      optionFilterProp="label"
      style={{ width: '100%' }}
      showSearch
      onChange={onChange}
      defaultValue={value}
    />
  );
}
function DataAcquisition({ setCurrent }) {
  const { id } = useParams();
  const [form] = Form.useForm();
  const [filterForm] = Form.useForm();
  const [mappingForm] = Form.useForm();
  const [editTableForm] = Form.useForm();
  const history = useHistory();
  const [visible, { setTrue, setFalse }] = useBoolean(false);
  const [dataSource, setDataSource] = useState([
    { id: 1, ruleName: 'procurement_plan_detail', ifAvailable: true, special: true },
    { id: 2, ruleName: 'project_bids', ifAvailable: true, special: false },
  ]);
  const [fieldMappingList, setFieldMappingList] = useState([]);
  const [editableKeys, setEditableKeys] = useState(dataSource.map((item) => item.id));
  const [mappingEditableKeys, setMappingEditableKeys] = useState([]);
  const [tableOptions, setTableOptions] = useState([]);
  const [currentRecord, setCurrentRecord] = useState([]);
  const [associationOptions, setAssociationOptions] = useState([]);
  const [fieldOptions, setFieldOptions] = useState([]);
  const [associationSubTableOptions, setAssociationSubTableOptions] = useState([
    { value: 'procurement_plan_detail', label: 'procurement_plan_detail' },
  ]);
  const editableFormRef = useRef();
  const fieldMappingFormRef = useRef();
  const columns = [
    {
      title: '表名',
      dataIndex: 'smsRelationshipTable',
      width: 220,
      formItemProps: {
        rules: [
          {
            required: true,
            message: '此项是必填项',
          },
        ],
      },
      renderFormItem: (_, item) => {
        const { isPrimary, smsRelationshipTable } = item.record;
        if (!isPrimary) {
          return (
            <Select
              options={tableOptions}
              optionFilterProp="label"
              style={{ width: '100%' }}
              onChange={handleChange}
              showSearch
            />
          );
        }
        return <span>{smsRelationshipTable}</span>;
      },
    },
    {
      title: '过滤条件',
      dataIndex: 'isConfigured',
      width: 100,
      align: 'center',
      renderFormItem: (_, config) => {
        const { isConfigured } = config.record;
        if (config.record.isPrimary) {
          return '-';
        }
        return isConfigured ? <Tag color="success">已设置</Tag> : <Tag>未设置</Tag>;
      },
    },
    {
      title: '操作',
      valueType: 'option',
      width: 150,
      align: 'center',
      render: (_, record) => null,
    },
  ];
  const fieldMappingCols = [
    {
      title: '序号',
      dataIndex: 'index',
      key: 'index',
      width: 50,
      align: 'center',
      editable: false,
      render: (text, record, index) => index + 1,
    },
    {
      title: '参数名',
      dataIndex: 'labelName',
      width: 200,
      renderFormItem: (_, config) => {
        const { labelName } = config.record;
        return (
          <Space>
            <span>{labelName}</span>
            {/*{ifAvailable ? (*/}
            {/*  <Tag color="warning">标签参数</Tag>*/}
            {/*) : (*/}
            <Tag color="processing">基础属性</Tag>
            {/*)}*/}
          </Space>
        );
      },
    },
    {
      title: <div className="text-center">映射表</div>,
      dataIndex: 'mappingTable',
      width: 220,
      align: 'left',
      formItemProps: {
        rules: [
          {
            required: true,
            message: '此项是必填项',
          },
        ],
      },
      renderFormItem: (_, item) => {
        return <Select style={{ width: '100%' }} options={tableOptions} showSearch />;
      },
    },
    {
      title: <div className="text-center">映射字段</div>,
      dataIndex: 'mappingField',
      width: 220,
      formItemProps: {
        rules: [
          {
            required: true,
            message: '此项是必填项',
          },
        ],
      },
      renderFormItem: (_, item) => {
        const { mappingTable } = item.record;
        return <MappingFieldsSelect tableName={mappingTable} />;
      },
    },
  ];
  function handleChange() {
    const formValues = editTableForm.getFieldsValue();
    const resultArray = Object.keys(formValues).map((key) => ({
      id: key,
      ...formValues[key],
    }));
    const primary = dataSource.filter(
      (i) =>
        i.isPrimary && {
          value: i.smsRelationshipTable,
          label: i.smsRelationshipTable,
        },
    );
    const allList = resultArray.concat(primary);
    const correlationTables = allList.map((i) => ({
      value: i.smsRelationshipTable,
      label: i.smsRelationshipTable,
    }));
    const uniqueArray = Array.from(
      new Set(correlationTables.map((item) => JSON.stringify(item))),
    ).map((item) => JSON.parse(item));
    setAssociationOptions(uniqueArray);
  }
  function openModal(record) {
    const { smsRelationshipTable, filterCondition } = record;
    if (smsRelationshipTable) {
      fetchSelectOptions(smsRelationshipTable).then((options) => setFieldOptions(options));
    }
    if (filterCondition && filterCondition.children?.length > 0) {
      if (typeof filterCondition === 'string') {
        filterForm.setFieldValue('associatedCondition', JSON.parse(filterCondition));
      } else {
        filterForm.setFieldValue('associatedCondition', filterCondition);
      }
    } else {
      filterForm.setFieldValue('associatedCondition', {});
    }
    setCurrentRecord(record);
    setTrue();
  }
  function fetchTableName() {
    return request.getWMessage('/syndata/dataModel/getTableName').then((res) => {
      const { data } = res;
      const options = data.map((i) => ({ value: i, label: i }));
      setTableOptions(options);
    });
  }
  function onClear() {
    form.resetFields(['associatedCondition']);
  }
  function handleDelete(deleteId, smsRelationshipTable) {
    const resultList = dataSource.filter((i) => i.id !== deleteId);
    setDataSource(resultList);
    const optionsList = resultList.map((i) => ({
      value: i.smsRelationshipTable,
      label: i.smsRelationshipTable,
    }));
    const uniqueArray = Array.from(new Set(optionsList.map((item) => JSON.stringify(item)))).map(
      (item) => JSON.parse(item),
    );
    setAssociationOptions(uniqueArray);
    const ifHas = resultList.filter((i) => i.smsRelationshipTable === smsRelationshipTable);
    if (ifHas.length === 0) {
      return Promise.resolve(smsRelationshipTable);
    }
    return Promise.reject();
  }
  function extractUniqueAAValues(obj) {
    const uniqueValues = new Set();
    function traverse(node) {
      if (node.leftTableName) {
        uniqueValues.add(node.leftTableName);
      }
      if (node.rightTableName) {
        uniqueValues.add(node.rightTableName);
      }
      if (node.children && Array.isArray(node.children)) {
        node.children.forEach((child) => traverse(child));
      }
    }
    traverse(obj);
    return Array.from(uniqueValues);
  }
  function handleSave() {
    Promise.all([form.validateFields(), mappingForm.validateFields()]).then(([res1, res2]) => {
      const { associatedCondition } = res1;
      const smsFieldMappings = Object.keys(res2).map((key) => ({
        id: key,
        ...res2[key],
      }));
      const smsRelationshipList = Object.keys(dataSource).map((key) => ({
        id: key,
        ...dataSource[key],
      }));
      const result = extractUniqueAAValues(associatedCondition);
      const tables = dataSource.map((item) => item.smsRelationshipTable);
      const uniqueDataSource = new Set(tables);
      const uniqueSelect = new Set(result);
      const areArraysEqual =
        uniqueDataSource.size === uniqueSelect.size &&
        [...uniqueDataSource].every((value) => uniqueSelect.has(value));
      if (!areArraysEqual) {
        message.error('关联条件中使用的表与关联表配置不一致');
        return;
      }
      return request.postWMessage('/manager/smsTemplate/saveDataConfig', {
        id,
        associatedCondition:
          typeof associatedCondition === 'string'
            ? JSON.parse(associatedCondition)
            : associatedCondition,
        smsFieldMappings,
        smsRelationshipList,
      });
    });
  }
  function fetchTemplateInfo() {
    return request.getWMessage('/manager/smsTemplate/getTemplate', { id }).then((res) => {
      const { data } = res;
      setDataSource(data.smsRelationshipList);
      if (data.smsRelationshipList?.length > 0) {
        setEditableKeys(data.smsRelationshipList.map((i) => i.id));
      }
      const optionsList = data.smsRelationshipList.map((i) => ({
        value: i.smsRelationshipTable,
        label: i.smsRelationshipTable,
      }));
      const uniqueArray = Array.from(new Set(optionsList.map((item) => JSON.stringify(item)))).map(
        (item) => JSON.parse(item),
      );
      setAssociationOptions(uniqueArray);
      if (data.associatedCondition) {
        form.setFieldValue('associatedCondition', JSON.parse(data.associatedCondition));
      }
    });
  }
  function fetchFieldMappingList() {
    return request.getWMessage('/manager/smsFieldMapping/fieldMappingList').then((res) => {
      const { data } = res;
      setFieldMappingList(data);
      setMappingEditableKeys(data.map((i) => i.id));
    });
  }
  function fetchSelectOptions(tableName) {
    return request.getWMessage('/syndata/dataModel/getTableColumn', { tableName }).then((res) => {
      const { data } = res;
      return data.map((i) => ({ value: i, label: i }));
    });
  }
  useEffect(() => {
    fetchTableName();
    fetchFieldMappingList();
    if (id) {
      fetchTemplateInfo();
    }
  }, [id]);

  return (
    <>
      <Row gutter={[0, 24]} justify="center" className="h-full pb-8">
        <Col span={22}>
          <StepDot title="关联表" number={1} />
          <Row className="mt-8" justify="center">
            <Col span={24}>
              <EditableProTable
                toolBarRender={false}
                tableAlertRender={false}
                columns={columns}
                bordered
                rowKey="id"
                value={dataSource}
                editableFormRef={editableFormRef}
                onChange={setDataSource}
                recordCreatorProps={{
                  newRecordType: 'dataSource',
                  creatorButtonText: '添加行',
                  record: () => ({ id: uuid().replace(/-/g, ''), isPrimary: false }),
                }}
                editable={{
                  type: 'multiple',
                  form: editTableForm,
                  editableKeys,
                  onChange: setEditableKeys,
                  onValuesChange: (_, recordList) => {
                    setDataSource(recordList);
                  },
                  actionRender: (row, config, defaultDom) => {
                    if (row.isPrimary) {
                      return '-';
                    } else {
                      if (row.smsRelationshipTable) {
                        return [
                          <a onClick={() => openModal(row)}>过滤条件</a>,
                          <Popconfirm
                            title="确定删除该记录?"
                            onConfirm={() => handleDelete(row.id, row.smsRelationshipTable)}
                          >
                            <a>删除</a>
                          </Popconfirm>,
                        ];
                      }
                      return [
                        <Popconfirm
                          title="确定删除该记录?"
                          onConfirm={() => handleDelete(row.id, row.smsRelationshipTable)}
                        >
                          <a>删除</a>
                        </Popconfirm>,
                      ];
                    }
                  },
                }}
              />
            </Col>
          </Row>
        </Col>
        <Col span={22}>
          <StepDot title="关联条件" number={2} />
          <Form form={form} className="ml-4 mt-8">
            <Card
              extra={
                <Space>
                  <Button onClick={() => onClear()}>清空</Button>
                </Space>
              }
            >
              <SelectAssociationCondition
                name="associatedCondition"
                fieldOptions={associationOptions}
                associationSubTableOptions={associationSubTableOptions}
                onFieldSelect={fetchSelectOptions}
                handleDelete={handleDelete}
                required={true}
              />
            </Card>
          </Form>
        </Col>
        <Col span={22}>
          <StepDot title="字段映射" number={3} />
          <EditableProTable
            toolBarRender={false}
            tableAlertRender={false}
            columns={fieldMappingCols}
            bordered
            rowKey="id"
            value={fieldMappingList}
            onChange={setFieldMappingList}
            editableFormRef={fieldMappingFormRef}
            recordCreatorProps={false}
            editable={{
              type: 'multiple',
              form: mappingForm,
              editableKeys: mappingEditableKeys,
              onChange: setMappingEditableKeys,
              onValuesChange: (_, recordList) => {
                setFieldMappingList(recordList);
              },
            }}
          />
        </Col>
        <FilterConditionModal
          open={visible}
          setFalse={setFalse}
          editableFormRef={editableFormRef}
          form={filterForm}
          fieldOptions={fieldOptions}
          currentRecord={currentRecord}
          setDataSource={setDataSource}
          dataSource={dataSource}
        />
      </Row>
      <EvalToolbar>
        <Space>
          <Button onClick={history.goBack}>返回</Button>
          <Button onClick={() => setCurrent((currentStep) => currentStep - 1)}>上一步</Button>
          <Button onClick={handleSave} type="primary">
            保存并校验
          </Button>
        </Space>
      </EvalToolbar>
    </>
  );
}
export default DataAcquisition;
