import { Cascader, Drawer, Table, Typography } from 'antd';
import React, { useEffect, useState } from 'react';
import request from '@/utils/request';
import SearchBar from '@/components/forms/SearchBar';
import dayjs from 'dayjs';
import RangePickerString from '@/components/forms/RangePickerString';

function MessageDetailLog(props) {
  const { drawerVisible, setFalse, templateId } = props;
  const [drawerDataSource, setDrawerDataSource] = useState([]);
  const [areaList, setAreaList] = useState([]);
  const [pagination, setPagination] = useState({ total: 0, current: 1, pageSize: 10 });
  const columns = [
    {
      title: '序号',
      dataIndex: 'index',
      width: 80,
      align: 'center',
      render: (text, record, index) => index + 1,
    },
    {
      title: '短信内容',
      dataIndex: 'smsContent',
      key: 'smsContent',
      align: 'center',
      width: 250,
      render: (text) => (
        <Typography.Paragraph
          ellipsis={{
            rows: 2,
            tooltip: true,
          }}
          className="!mb-0"
        >
          {text || '-'}
        </Typography.Paragraph>
      ),
    },
    {
      title: '发送地区',
      dataIndex: 'areaName',
      key: 'areaName',
      width: 150,
      align: 'center',
    },
    {
      title: '发送用户',
      dataIndex: 'sendUserName',
      key: 'sendUserName',
      align: 'center',
      width: 100,
      render: (text) => text || '-',
    },
    {
      title: '生成时间',
      dataIndex: 'createTime',
      width: 150,
      align: 'center',
      render: (text) => (text ? dayjs(text).format('YYYY-MM-DD HH:mm') : '-'),
    },
    {
      title: '用户名称',
      dataIndex: 'smsReceiveName',
      key: 'smsReceiveName',
      align: 'center',
      width: 100,
      render: (text) => text || '-',
    },
    {
      title: '手机号',
      dataIndex: 'smsPhone',
      key: 'smsPhone',
      align: 'center',
      width: 100,
    },
  ];
  const itemList = [
    {
      name: 'keyword',
      key: 'keyword',
      label: '模糊搜索',
      componentProps: { placeholder: '用户名称/手机号', style: { width: 230 } },
    },
    {
      name: 'smsArea',
      label: '地区',
      component: Cascader,
      componentProps: {
        placeholder: '请选择地区',
        style: { width: 200 },
        options: areaList,
        fieldNames: { label: 'areaName', value: 'areaId', children: 'children' },
        changeOnSelect: true,
        allowClear: true,
      },
    },
    {
      key: 'dateRangeArray',
      name: 'dateRangeArray',
      label: '时间范围',
      component: RangePickerString,
      componentProps: {
        allowClear: true,
        allowEmpty: [true, true],
      },
    },
  ];
  useEffect(() => {
    fetchAreaList();
  }, []);

  function fetchAreaList() {
    request.getWMessage('/manager/smsArea/smsAreaList').then((res) => {
      setAreaList(res.data);
    });
  }
  useEffect(() => {
    if (templateId) {
      fetchAddHostTableData();
    }
  }, [drawerVisible]);
  function fetchAddHostTableData(param) {
    request
      .getWMessage('/manager/smsSendInfo/sendInfoDetail', {
        templateId,
        ...param,
      })
      .then((res) => {
        setPagination({
          current: res.data.current,
          total: res.data.total,
          pageSize: res.data.pageSize,
        });
        setDrawerDataSource(res.data.list);
      });
  }
  function onClose() {
    setFalse();
  }
  function onSearch(value) {
    fetchAddHostTableData({ pageSize: pagination.pageSize, ...value });
  }
  return (
    <Drawer title="短信生成明细" open={drawerVisible} onClose={onClose} width={'65vw'}>
      <SearchBar onSearch={onSearch} itemList={itemList} />
      <Table dataSource={drawerDataSource} columns={columns} rowKey="id" pagination={false} />
    </Drawer>
  );
}
export default MessageDetailLog;
