import EditorFormItem from '@/components/common/RichEditor/EditorFormItem';
import { useEffect, useState } from 'react';
import request from '@/utils/request';
import { Card, Col, Form, Input, List, Row, Table } from 'antd';
import { useParams } from 'react-router-dom';

function getInputEle(item) {
  const { id, labelName } = item;
  const width = labelName.length * 16;
  const data = JSON.stringify({ ...item });
  return `<input style="width:${width}px;" disabled=true id=${id} value=${labelName}  aria-data=${data} />`;
}
function onClickSign(record) {
  const html = getInputEle({
    labelName: record.labelName,
    id: record.id,
    labelSql: record.labelSql,
  });
  window.tinymce.activeEditor.execCommand('mceInsertContent', false, html);
}
function MessageTemplates({ value, onChange, isAuthorization = true, setEditor }) {
  const { id } = useParams();
  const [dataSource, setDataSource] = useState([]);
  function getEditor(e) {
    if (e) {
      setEditor(e);
    }
  }
  useEffect(() => {
    fetchTagging();
  }, [id]);
  function fetchTagging() {
    request.getWMessage('/manager/smsLabel/labelList').then((res) => {
      setDataSource(res.data);
    });
  }
  function onSearch(labelName) {
    request
      .getWMessage('/manager/smsLabel/getLabel', { labelName })
      .then((res) => setDataSource(res.data));
  }
  return (
    <Row gutter={[24, 24]}>
      <Col span={18}>
        <EditorFormItem
          height={400}
          getEditor={getEditor}
          value={value}
          onChange={onChange}
          initProps={{
            paste_data_images: false,
            removed_menuitems: 'image media code help anchor newdocument',
            content_style:
              'body { font-family:宋体; font-size:12pt; input {border:none;color:#1677ff;font-size:12pt;}',
          }}
          hideImageToolbar
          hideFontToolbar
        />
      </Col>
      <Col span={6}>
        {isAuthorization ? (
          <Table
            rowKey="id"
            columns={[
              {
                title: '模板标签',
                dataIndex: 'id',
                width: 50,
                render: (_, record) => (
                  <div className="text-blue-6" onClick={() => onClickSign(record)}>
                    {record.labelName}
                  </div>
                ),
              },
            ]}
            pagination={false}
            dataSource={dataSource}
            scroll={{ y: 400 }}
            bordered
          />
        ) : (
          <Card type="inner" title="模板标签">
            <Input.Search onSearch={onSearch} />
            <List
              itemLayout="horizontal"
              dataSource={dataSource}
              renderItem={(item) => {
                return (
                  <List.Item key={item.id} onClick={() => onClickSign(item)}>
                    <span className="text-blue-6">{item.labelName}</span>
                  </List.Item>
                );
              }}
            />
          </Card>
        )}
      </Col>
    </Row>
  );
}
export default MessageTemplates;
