import { Button, Card, Col, Form, Input, Row, Space } from 'antd';
import StepDot from '@/components/widget/stepDot/StepDot';
import SelectCondition from '@/components/common/selectCondition/SelectCondition';
import MessageTemplates from '@/components/system/message/MessageTemplates';
import request from '@/utils/request';
import { useEffect, useState } from 'react';
import EvalToolbar from '@/components/evalBid/EvalToolbar';
import { useHistory, useParams } from 'react-router-dom';

export function parseInputIds(str) {
  const regex = /<input[^>]*?id="([^"]+)"[^>]*>/g;
  let match;
  const ids = [];

  while ((match = regex.exec(str))) {
    ids.push(match[1]);
  }
  const uniqueIds = Array.from(new Set(ids));
  return uniqueIds;
}
function TemplateConfiguration({ setCurrent }) {
  const { id } = useParams();
  const history = useHistory();
  const [selectOptions, setSelectOptions] = useState([]);
  const [form] = Form.useForm();
  const [editor, setEditor] = useState();
  function onClear() {
    form.resetFields(['triggerCondition', 'conditions']);
  }
  function fetchSelectOptions(tableName) {
    return request.getWMessage('/syndata/dataModel/getTableColumn', { tableName }).then((res) => {
      const { data } = res;
      const options = data.map((i) => ({ value: i, label: i }));
      setSelectOptions(options);
    });
  }
  function handleSave(params) {
    const saveParam = {
      id,
      templateContent: params.templateContent,
      triggerCondition: params.triggerCondition,
    };
    request.postWMessage('/manager/smsTemplate/saveTemplate', { ...saveParam });
  }
  function handleSaveTemplates() {
    return form.validateFields().then((values) => {
      return Promise.all([handleSave(values), handleSaveTagging()]).then(() => {
        setCurrent((currentStep) => currentStep + 1);
      });
    });
  }
  function fetchTemplateInfo() {
    return request.getWMessage('/manager/smsTemplate/getTemplate', { id }).then((res) => {
      const { data } = res;
      form.setFieldsValue({
        ...data,
        triggerCondition: JSON.parse(data.triggerCondition),
        conditions: data.triggerCondition,
      });
      fetchSelectOptions(res.data.tableName);
    });
  }
  function handleSaveTagging() {
    const html = editor.getContent();
    const labelIds = parseInputIds(html);
    request.postWMessage('/manager/smsTemplateLabel/saveTemplateLabel', {
      templateId: id,
      labelIds,
    });
  }
  useEffect(() => {
    if (id) {
      fetchTemplateInfo();
    }
  }, []);
  return (
    <>
      <Row gutter={[0, 24]} justify="center" className="h-full pb-8">
        <Col span={22}>
          <StepDot title="触发条件" number={1} />
          <Form form={form} className="ml-4">
            <Form.Item name="tableName" label="监听表名">
              <Input bordered={false} className="!text-black" disabled={true} />
            </Form.Item>
            <Form.Item
              name="conditions"
              rules={[
                {
                  required: true,
                  message: '请选择触发条件',
                },
              ]}
            >
              <Card
                extra={
                  <Space>
                    <Button onClick={() => onClear()}>清空</Button>
                  </Space>
                }
              >
                <SelectCondition
                  name="triggerCondition"
                  required={true}
                  fieldOptions={selectOptions}
                  disableRemove={true}
                />
              </Card>
            </Form.Item>
          </Form>
        </Col>
        <Col span={22}>
          <StepDot title="模板配置" number={2} />
          <Form form={form} className="ml-4">
            <Form.Item
              name="templateContent"
              rules={[
                {
                  required: true,
                  validator: (_, value, callback) => {
                    if (value?.length > 0) {
                      return callback();
                    }
                    return callback('请输入短信内容');
                  },
                },
              ]}
            >
              <MessageTemplates setEditor={setEditor} isAuthorization={false} />
            </Form.Item>
          </Form>
        </Col>
      </Row>
      <EvalToolbar>
        <Space>
          <Button onClick={history.goBack}>返回</Button>
          <Button onClick={handleSaveTemplates} type="primary">
            下一步
          </Button>
        </Space>
      </EvalToolbar>
    </>
  );
}
export default TemplateConfiguration;
