import { Col, Modal, Row, Space, Table } from 'antd';
import { InfoCircleFilled } from '@ant-design/icons';
import styles from '@/components/system/modelManagement/indestTheSource.module.less';
import React, { useEffect, useState } from 'react';
import TheHostOfTheDataSource from '@/components/system/modelManagement/TheHostOfTheDataSource';
import request from '@/utils/request';

function IngestTheSourceTable(props) {
  const { visible, setFalse, sourceData, getMeatColList } = props;
  const [dataSource, setDataSource] = useState([]);
  const [selectedRowKeys, setSelectedRowKeys] = useState([]);
  const [hostSelectedRowKeys, setHostSelectedRowKeys] = useState([]);
  function onOk() {
    request
      .postWMessage('/syndata/dataModel/getReferenceSourceTable', {
        dataModelId: sourceData.id,
        tenantryHostId: hostSelectedRowKeys.toString(),
      })
      .then(() => {
        setFalse();
        getMeatColList();
      });
  }
  function handleCancel() {
    setFalse();
    setSelectedRowKeys([]);
  }
  function setRowClassName(record) {
    return record.id === selectedRowKeys ? styles.selectedStyle : '';
  }
  function onSelectChange(record) {
    setSelectedRowKeys(record.id);
    // fetchTableData(record.id);
  }

  useEffect(() => {
    if (sourceData.id) {
      fetchTenantList();
    }
  }, [visible]);
  function fetchTenantList() {
    request.getWMessage('/syndata/dataModel/getTenantryList', { id: sourceData.id }).then((res) => {
      const { data } = res;
      setDataSource(data);
      if (data?.length > 0) {
        setSelectedRowKeys(data[0].id);
      }
    });
  }
  return (
    <Modal
      closeIcon
      title={
        <Space>
          <span>选择主机</span>
          <span className="text-blue-6">
            <InfoCircleFilled />
            仅可选择与当前模型库名相同的主机
          </span>
        </Space>
      }
      destroyOnClose
      okButtonProps={{ disabled: hostSelectedRowKeys?.length === 0 }}
      open={visible}
      onCancel={handleCancel}
      onOk={onOk}
      centered
      bodyStyle={{ height: '60vh', overflowY: 'auto' }}
      width="70vw"
    >
      <Row className={styles.rowStyle}>
        <Col span={5} className={styles.colBorder}>
          <Table
            dataSource={dataSource}
            bordered
            rowClassName={setRowClassName}
            columns={[
              {
                title: '租户名称',
                dataIndex: 'tenantryName',
                key: 'tenantryName',
                width: 120,
              },
            ]}
            style={{ padding: '5px' }}
            pagination={false}
            rowKey="id"
            onRow={(record) => ({
              onClick: () => {
                onSelectChange(record);
              },
            })}
          />
        </Col>
        {selectedRowKeys?.length > 0 && (
          <Col span={19} className="mt-2.5">
            <TheHostOfTheDataSource
              tenantryId={selectedRowKeys}
              dbName={sourceData.dbName}
              hostSelectedRowKeys={hostSelectedRowKeys}
              setHostSelectedRowKeys={setHostSelectedRowKeys}
            />
          </Col>
        )}
      </Row>
    </Modal>
  );
}

export default IngestTheSourceTable;
