import { Button, Drawer, Form, InputNumber, message, Select, Space, Popconfirm } from 'antd';
import React, { useEffect, useState } from 'react';
import { EditableProTable } from '@ant-design/pro-table';
import styles from '@/pages/system/modelManagement/metaDrawer.module.less';
import request from '@/utils/request';
import { GREATER_THAN_REGEXP } from '@/const/Validate';
import { v4 as uuid } from 'uuid';
import { useBoolean } from 'ahooks';
import IngestTheSourceTable from '@/components/system/modelManagement/IngestTheSourceTable';

function MetaDrawer(props) {
  const { open, setMetadataVisibleFalse, record } = props;
  const [fieldDataList, setFieldDataList] = useState([]);
  const [selectedRowKey, setSelectRowKey] = useState([]);
  const [editableKeys, setEditableRowKeys] = useState([]);
  const [importLoading, setImportLoading] = useState(false);
  const [saveLoading, setSaveLoading] = useState(false);
  const [editForm] = Form.useForm();
  const [visible, { setTrue, setFalse }] = useBoolean(false);

  useEffect(() => {
    if (open) {
      getMeatColList();
    }
  }, [open]);

  function getMeatColList() {
    request
      .getWMessage('/syndata/dataModel/getDataModelHypertable', { id: record.id })
      .then((res) => {
        setFieldDataList(res.data);
      });
  }

  function batchDelete() {
    let tempList = [...fieldDataList];
    selectedRowKey.forEach((item) => {
      tempList = tempList.filter((i) => i.id !== item);
    });
    request.post('/syndata/dataModel/deleteDataModelHypertable', selectedRowKey).then(() => {
      setFieldDataList(() => tempList);
      setSelectRowKey([]);
      getMeatColList();
    });
  }

  const fieldColumns = [
    {
      title: '字段代码',
      dataIndex: 'fieldCode',
      formItemProps: () => {
        return {
          rules: [
            { required: true, message: '此项为必填项' },
            {
              pattern: /^[^\s]*$/,
              message: '禁止输入空格',
            },
            {
              pattern: /^[^0-9]/,
              message: '不能以数字开头',
            },
          ],
        };
      },
    },
    {
      title: '字段含义',
      dataIndex: 'fieldMeaning',
    },
    {
      title: '数据类型',
      dataIndex: 'dataType',
      renderFormItem: () => (
        <Select style={{ width: '100px' }} getPopupContainer={() => document.body}>
          <Select.Option value="int">int</Select.Option>
          <Select.Option value="varchar">varchar</Select.Option>
          <Select.Option value="date">date</Select.Option>
          <Select.Option value="decimal">decimal</Select.Option>
          <Select.Option value="datetime">datetime</Select.Option>
        </Select>
      ),
      formItemProps: () => {
        return {
          rules: [{ required: true, message: '此项为必填项' }],
        };
      },
    },
    {
      title: '字段长度',
      dataIndex: 'fieldLength',
      formItemProps: () => {
        return {
          rules: [
            {
              required: true,
              validator: (values) => {
                // 通过validator自定义校验规则
                const { field } = values;
                // 获取当前行数据
                const current = editForm.getFieldValue(`${field.split('.')[0]}`) || {};
                if (
                  current.dataType === 'datetime' ||
                  current.dataType === 'date' ||
                  current.fieldLength
                ) {
                  const fieldLengthReg = /^[1-9]\d*$/;
                  if (fieldLengthReg.test(current.fieldLength)) {
                    return Promise.resolve();
                  }
                  return Promise.reject(new Error('请填写大于0的整数'));
                }
                return Promise.reject(new Error('此项为必填项'));
              },
            },
          ],
        };
      },
    },
    {
      title: '小数位数',
      dataIndex: 'decimalDigits',
      renderFormItem: (_, config) => {
        if (config.record.dataType === 'decimal') {
          return <InputNumber />;
        }
        return <span className="pl-12">-</span>;
      },
      formItemProps: () => {
        return {
          rules: [
            {
              required: true,
              validator: (values) => {
                // 通过validator自定义校验规则
                const { field } = values;
                // 获取当前行数据
                const current = editForm.getFieldValue(`${field.split('.')[0]}`) || {};
                if (current.dataType === 'decimal' && !current.decimalDigits) {
                  return Promise.reject(new Error('此项为必填项'));
                }
                return Promise.resolve();
              },
            },
          ],
        };
      },
    },
    {
      title: '是否主键',
      dataIndex: 'isPrimary',
      render: (text) => (!text ? '否' : '是'),
      formItemProps: () => {
        return {
          rules: [{ required: true, message: '此项为必填项' }],
        };
      },
      renderFormItem: () => (
        <Select style={{ width: '100px' }} getPopupContainer={() => document.body}>
          <Select.Option value={false}>否</Select.Option>
          <Select.Option value={true}>是</Select.Option>
        </Select>
      ),
    },
    {
      title: '排序',
      dataIndex: 'sort',
      formItemProps: () => {
        return {
          rules: [
            { required: true, message: '此项为必填项' },
            {
              pattern: GREATER_THAN_REGEXP,
              message: '输入值应为大于0的整数',
            },
          ],
        };
      },
    },
    {
      title: '操作',
      valueType: 'option',
      render: (text, row, _, action) => [
        <Button
          type="link"
          size="small"
          key={`editable${row.id}`}
          onClick={() => {
            action?.startEditable?.(row.id);
          }}
        >
          编辑
        </Button>,
        <Popconfirm
          title="确认删除吗?"
          onConfirm={() => setFieldDataList(fieldDataList.filter((item) => item.id !== row.id))}
        >
          <Button type="link" size="small" key={`delete${row.id}`}>
            删除
          </Button>
        </Popconfirm>,
      ],
    },
  ];

  function save(createFlag) {
    setSaveLoading(true);
    let saveList = [];
    let ifSame = false;
    const currentList = [...fieldDataList];
    currentList.forEach((item, index) => {
      const temp = item;
      for (let i = 0; i < currentList.length; i += 1) {
        if (temp.fieldCode === currentList[i].fieldCode && i !== index) {
          temp.ifSame = true;
          ifSame = true;
        }
      }
      saveList.push(temp);
    });
    if (ifSame) {
      message.error('存在重复数据');
      setSaveLoading(false);
      setFieldDataList(saveList);
    } else {
      saveList = [];
      currentList.forEach((item, index) => {
        const temp = item;
        temp.dataModelId = record.id;
        if (temp.dataType === 'decimal') {
          temp.ddlColumnType = `${temp.dataType}(${temp.fieldLength},${temp.decimalDigits})`;
        }
        if (temp.dataType === 'datetime' || temp.dataType === 'date') {
          temp.ddlColumnType = `${temp.dataType}`;
        } else {
          temp.ddlColumnType = `${temp.dataType}(${temp.fieldLength})`;
        }
        saveList.push(temp);
      });
      request
        .postWMessage('/syndata/dataModel/saveDataModelHypertable', saveList)
        .then(() => {
          getMeatColList();
        })
        .finally(() => {
          setSaveLoading(false);
        });
    }
  }

  function handleImport() {
    setTrue();
  }
  return (
    <>
      <Drawer
        title="元数据配置"
        open={open}
        onClose={setMetadataVisibleFalse}
        destroyOnClose={true}
        closeIcon={false}
        width={1300}
        footer={
          <Space className="w-full justify-end">
            <Button onClick={setMetadataVisibleFalse}>取消</Button>
            <Button type="primary" loading={saveLoading} onClick={() => save(false)}>
              保存
            </Button>
          </Space>
        }
      >
        <div className="flex justify-between mb-2">
          <Space size="large">
            <span>模型名称:{record.modelName}</span>
            <span> 模型标识:{record.modelIdentification}</span>
            <span>表名:{record.tableName}</span>
          </Space>
          <Space>
            {/*<Button type="primary" danger onClick={batchDelete}>*/}
            {/*  批量删除*/}
            {/*</Button>*/}
            <Button loading={importLoading} onClick={handleImport}>
              引用源表
            </Button>
          </Space>
        </div>
        <EditableProTable
          rowSelection={{
            type: 'checkbox',
            onChange: setSelectRowKey,
          }}
          toolBarRender={false}
          tableAlertRender={false}
          columns={fieldColumns}
          value={fieldDataList}
          rowKey="id"
          onChange={setFieldDataList}
          recordCreatorProps={{
            record: () => ({ id: uuid().replace(/-/g, '') }),
          }}
          // recordCreatorProps={false}
          rowClassName={(item) => {
            if (item.ifEmpty) {
              return styles.emptyRow;
            }
            if (item.ifSame) {
              return styles.errorRow;
            }
            return '';
          }}
          editable={{
            type: 'multiple',
            form: editForm,
            editableKeys,
            onChange: setEditableRowKeys,
            actionRender: (row, config, defaultDom) => [defaultDom.save, defaultDom.cancel],
          }}
        />
      </Drawer>
      <IngestTheSourceTable
        visible={visible}
        setFalse={setFalse}
        sourceData={record}
        getMeatColList={getMeatColList}
      />
    </>
  );
}

export default MetaDrawer;
