import SearchBar from '@/components/forms/SearchBar';
import { Form, Radio, Table, Tag } from 'antd';
import React, { useEffect, useState } from 'react';
import request from '@/utils/request';
import { useRequest } from 'ahooks';
import { HostType, HostTypeName } from '@/const/TenantType';

function TheHostOfTheDataSource(props) {
  const { tenantryId, dbName, hostSelectedRowKeys, setHostSelectedRowKeys, setHostName } = props;

  const [searchForm] = Form.useForm();
  const [pagination, setPagination] = useState({ total: 0, current: 1, pageSize: 10 });
  const searchBarItem = [
    {
      key: 'keyword',
      label: '模糊搜索',
      componentProps: { placeholder: '主机名称/标识', style: { width: 230 } },
    },
    {
      key: 'usageType',
      label: '用途类型',
      component: Radio.Group,
      initialValue: '',
      componentProps: {
        options: [
          {
            label: '全部',
            value: '',
          },
          { value: HostType.BUSINESS, label: '业务库' },
          { value: HostType.QUERY, label: '查询库' },
        ],
      },
    },
  ];
  const tableCol = [
    {
      title: '主机名称',
      dataIndex: 'hostName',
      key: 'hostName',
      width: 150,
      align: 'center',
    },
    {
      title: '用途类型',
      dataIndex: 'usageType',
      key: 'usageType',
      align: 'center',
      width: 100,
      render: (text) => (
        <Tag color={text === HostType.BUSINESS ? 'orange' : 'blue'} className="py-1 px-4">
          {HostTypeName[text]}
        </Tag>
      ),
    },
    {
      title: '主机标识',
      width: 150,
      align: 'center',
      dataIndex: 'hostIdentification',
      key: 'hostIdentification',
    },
  ];
  function fetchTableData(params) {
    return request
      .getWMessage('/syndata/dataModel/getTenantryHostList', { ...params, tenantryId, dbName })
      .then((res) => {
        setPagination({
          current: res.data.current,
          total: res.data.total,
          pageSize: res.data.pageSize,
        });
        return res;
      });
  }
  const { data = { list: [] }, run } = useRequest(
    async (params) => {
      const res = await fetchTableData(params);
      const { list, total } = res.data || {};
      return { list, total };
    },
    {
      manual: true,
    },
  );
  function onChange(page, filters) {
    const params = {
      current: page.current,
      pageSize: page.pageSize,
      ...filters,
    };
    run({ ...params, ...searchForm.getFieldsValue() });
  }

  useEffect(() => {
    if (tenantryId && dbName) {
      run();
    }
  }, [tenantryId, dbName]);
  return (
    <div className="ml-2.5">
      <SearchBar
        onSearch={(value) => {
          run({ pageSize: pagination.pageSize, ...value });
        }}
        itemList={searchBarItem}
        form={searchForm}
      />
      <Table
        rowKey="id"
        size="middle"
        bordered
        columns={tableCol}
        dataSource={data.list}
        onChange={onChange}
        scroll={{ y: 360 }}
        rowSelection={{
          hostSelectedRowKeys,
          type: 'radio',
          onChange: (key, rowData) => {
            setHostSelectedRowKeys(key);
            setHostName(rowData[0].hostName);
          },
        }}
        pagination={{
          ...pagination,
          showQuickJumper: true,
          showSizeChanger: true,
          showTotal: (total) => `共 ${total} 项`,
        }}
      />
    </div>
  );
}
export default TheHostOfTheDataSource;
