import { Button, Checkbox, Col, Drawer, Row, Space, Table } from 'antd';
import React, { useEffect, useState } from 'react';
import request from '@/utils/request';
import { addHostManageColumns } from '@/components/system/syncModel/HostManageCol';
import StartSyncingModal from '@/components/system/syncModel/StartSyncingModal';

function AddAHostDrawer(props) {
  const {
    drawerVisible,
    setFalse,
    isMaintenance = false, //是否主机维护
    activeKey,
    id,
    fetchTableData,
    postUrl = '/syndata/syncTask/saveSyncTaskHost',
    requestUrl = '/syndata/syncTask/getTenantryHostList',
  } = props;
  const [drawerDataSource, setDrawerDataSource] = useState([]);
  const [selectedRowKeys, setSelectedRowKeys] = useState([]);
  const [isSync, setIsSync] = useState(false);

  useEffect(() => {
    if (activeKey && id) {
      fetchAddHostTableData();
    }
  }, [drawerVisible]);
  function fetchAddHostTableData() {
    request
      .getWMessage(requestUrl, {
        id,
        syncModelTargetTenantId: activeKey,
      })
      .then((res) => {
        if (isMaintenance) {
          setDrawerDataSource(res.data || []);
        } else {
          setDrawerDataSource(res.data.tenantryHostList);
          setSelectedRowKeys(res.data.selectedTenantryHostList);
        }
      });
  }
  function handleSave() {
    request
      .postWMessage(postUrl, {
        id,
        syncModelTargetTenantId: activeKey,
        metaData: selectedRowKeys,
        isSync,
      })
      .then(() => {
        fetchTableData(activeKey);
        setFalse();
      });
  }
  function handleCheck(e) {
    setIsSync(e.target.checked);
  }
  function onClose() {
    setFalse();
    setSelectedRowKeys([]);
    setIsSync(false);
  }
  return (
    <Drawer
      title="添加主机"
      open={drawerVisible}
      onClose={onClose}
      width={'45vw'}
      closeIcon
      footer={
        <Row justify="end">
          {isMaintenance && (
            <Col span={18}>
              <Checkbox onClick={handleCheck} checked={isSync}>
                立即开始所选主机的结构和数据同步
              </Checkbox>
            </Col>
          )}
          <Col span={6} style={{ textAlign: 'right' }}>
            <Space>
              <Button onClick={onClose}>取消</Button>
              <Button type="primary" onClick={handleSave}>
                确定
              </Button>
            </Space>
          </Col>
        </Row>
      }
    >
      <Table
        dataSource={drawerDataSource}
        columns={addHostManageColumns}
        rowKey="id"
        pagination={false}
        rowSelection={{
          selectedRowKeys,
          type: 'checkbox',
          onChange: (keys) => {
            setSelectedRowKeys(keys);
          },
        }}
      />
    </Drawer>
  );
}
export default AddAHostDrawer;
