import { Button, Form, Popconfirm, Space, Table } from 'antd';
import { hostManageColumns } from '@/components/system/syncModel/HostManageCol';
import React, { useEffect, useState } from 'react';
import { SyncStatus } from '@/pages/system/syncProcess/ProcessStatus';
import request from '@/utils/request';
import StartSyncingModal from '@/components/system/syncModel/StartSyncingModal';
import { useBoolean } from 'ahooks';
import { SyncContentType } from '@/const/HostStatus';

function HostManageTable(props) {
  const { activeKey, dataSource, fetchTableData } = props;
  const [
    startSyncingVisible,
    { setTrue: setStartSyncingVisibleTrue, setFalse: setStartSyncingVisibleFalse },
  ] = useBoolean(false);
  const [taskStatus, setTaskStatus] = useState(false);
  const [form] = Form.useForm();
  useEffect(() => {
    if (activeKey) {
      fetchTableData(activeKey);
    }
  }, [activeKey]);
  function handleDelete(deleteId) {
    request
      .deleteWMessage('/syndata/syncTask/deleteSyncTaskHost', {
        id: deleteId,
      })
      .then(() => {
        fetchTableData(activeKey);
      });
  }
  function openSync(params) {
    setTaskStatus(params.taskStatus);
    if (params.taskStatus || params.taskIsFull) {
      setStartSyncingVisibleTrue();
      form.setFieldsValue({ ...params, syncSelect: SyncContentType.All });
    } else {
      saveHostStatus(params);
    }
  }
  function saveHostStatus(params) {
    request
      .postWMessage('/syndata/syncTask/startOrPauseSyncTaskHost', {
        id: params.id,
        status: !params.status,
      })
      .then(() => fetchTableData(activeKey));
  }
  const options = [
    {
      title: '操作',
      align: 'center',
      width: 100,
      dataIndex: 'option',
      key: 'option',
      render: (_, record) => {
        if (record.taskStatus === SyncStatus.SUCCESS) {
          return '-';
        }
        return (
          <Space>
            {record.status ? (
              <Button type="link" size="small" onClick={() => saveHostStatus(record)}>
                停用
              </Button>
            ) : (
              <>
                <Button type="link" size="small" onClick={() => openSync(record)}>
                  启用
                </Button>
                <Popconfirm title="确认删除吗?" onConfirm={() => handleDelete(record.id)}>
                  <Button type="link" size="small">
                    删除
                  </Button>
                </Popconfirm>
              </>
            )}
          </Space>
        );
      },
    },
  ];
  return (
    <>
      <Table
        dataSource={dataSource}
        columns={hostManageColumns.concat(options)}
        className="px-2 pt-2"
        rowKey="id"
        pagination={false}
        size="small"
      />
      <StartSyncingModal
        visible={startSyncingVisible}
        taskStatus={taskStatus}
        form={form}
        activeKey={activeKey}
        fetchTableData={fetchTableData}
        setVisibleFalse={setStartSyncingVisibleFalse}
      />
    </>
  );
}
export default HostManageTable;
