import G6 from '@antv/g6';
import { useEffect } from 'react';
import request from '@/utils/request';
import { useParams } from 'react-router-dom';
import sync from '@/pages/system/syncProcess/img/sync.JPG';
import success from '@/pages/system/syncProcess/img/success.JPG';
import error from '@/pages/system/syncProcess/img/error.JPG';
import { HostStatusColorMap, HostStatusNameMap, HostStatusXMap } from '@/const/HostStatus';
import { TabKey } from '@/pages/system/syncProcess/ProcessStatus';
export default function ListeningDetails(props) {
  const { id } = useParams();
  const { activeKey } = props;
  useEffect(() => {
    getProcessInfo();
  }, [id, activeKey]);
  function fetchData() {
    return request.getWMessage('/syndata/MonitorOverview/getTaskListeningDetails', { id });
  }
  function getHostCount() {
    return request.getWMessage('/syndata/MonitorOverview/getTaskHostNum', { id });
  }
  function getProcessInfo() {
    return Promise.all([fetchData(), getHostCount()]).then(([res, hostData]) => {
      const { data } = res;
      const { data: hostCount } = hostData;
      if (data && hostCount && activeKey === TabKey.MONITOR) {
        registerChart(data, hostCount);
      }
    });
  }
  function getImg(currentStatus) {
    if (currentStatus === null) {
      return sync;
    }
    if (currentStatus) {
      return success;
    }
    return error;
  }
  function registerChart(data, count) {
    G6.Util.traverseTree(data, (d) => {
      return true;
    });

    G6.registerNode(
      'icon-node',
      {
        options: {
          size: [60, 150],
        },
        draw(cfg, group) {
          const styles = this.getShapeStyle(cfg);
          const { labelCfg = {} } = cfg;
          const w = styles.width;
          const h = styles.height;
          const keyShape = group.addShape('rect', {
            attrs: {
              ...styles,
              x: -w / 2,
              y: -h / 2,
            },
          });
          const { style, hostStatus, label, syncStatus } = cfg;
          group.addShape('rect', {
            attrs: {
              x: 1 - w / 2,
              y: 1 - h / 2,
              ...style,
            },
          });
          group.addShape('image', {
            attrs: {
              x: 8 - w / 2,
              y: 20 - h,
              width: hostStatus === null ? 35 : 40,
              height: 60,
              img: getImg(hostStatus),
            },
            name: 'image-shape',
          });
          if (label) {
            group.addShape('text', {
              attrs: {
                ...labelCfg.style,
                text: label,
                x: label.length < 5 ? -w / 4 - 3 * label.length : -w / 3 - (3 * label.length) / 2,
                y: 55 - h / 2,
              },
            });
          }
          group.addShape('rect', {
            attrs: {
              x: 50 - w / 2,
              y: 15 - h / 2,
              width: 60,
              radius: 8,
              height: 15,
              fill: HostStatusColorMap[syncStatus],
            },
          });
          group.addShape('text', {
            attrs: {
              ...labelCfg.style,
              fill: '#FFF',
              text: HostStatusNameMap[syncStatus],
              x: HostStatusXMap[syncStatus] - w / 2,
              y: 27 - h / 2,
            },
          });
          return keyShape;
        },
        update: undefined,
      },
      'rect',
    );
    G6.registerEdge('flow-line', {
      draw(cfg, group) {
        const startPoint = cfg.startPoint;
        const endPoint = cfg.endPoint;
        const { style } = cfg;
        const shape = group.addShape('path', {
          attrs: {
            stroke: style.stroke,
            endArrow: style.endArrow,
            path: [
              ['M', startPoint.x - 20, startPoint.y + 20],
              ['L', startPoint.x - 20, (startPoint.y + endPoint.y) / 2],
              ['L', endPoint.x - 20, (startPoint.y + endPoint.y) / 2],
              ['L', endPoint.x - 20, endPoint.y - 20],
            ],
          },
        });

        return shape;
      },
    });

    const defaultStateStyles = {
      hover: {
        stroke: '#1890ff',
        lineWidth: 2,
      },
    };

    const defaultNodeStyle = {
      radius: 5,
    };

    const defaultEdgeStyle = {
      stroke: '#91d5ff',
      endArrow: false,
    };

    const defaultLayout = {
      type: 'compactBox',
      direction: 'TB',
      getId: function getId(d) {
        return d.id;
      },
      getHeight: function getHeight() {
        return 12;
      },
      getWidth: function getWidth() {
        return 10;
      },
      getVGap: function getVGap() {
        return 40;
      },
      getHGap: function getHGap() {
        return 50;
      },
    };

    const defaultLabelCfg = {
      style: {
        fill: '#000',
        fontSize: 8,
      },
    };
    const container = document.getElementById('container');
    const screenWidth = 1400;
    let width = screenWidth;
    if (count > 6) {
      width = screenWidth + (count - 5) * 150;
    }
    const height = container.clientHeight - 20;
    const graph = new G6.TreeGraph({
      container: 'container',
      width,
      height,
      animate: false,
      defaultNode: {
        type: 'icon-node',
        size: [90, 40],
        style: defaultNodeStyle,
        labelCfg: defaultLabelCfg,
      },
      defaultEdge: {
        type: 'flow-line',
        style: defaultEdgeStyle,
      },
      maxZoom: '2',
      minZoom: '2',
      linkCenter: true,
      nodeStateStyles: defaultStateStyles,
      edgeStateStyles: defaultStateStyles,
      layout: defaultLayout,
    });
    graph.data(data);
    graph.render();
    graph.fitView();
    if (typeof window !== 'undefined')
      window.onresize = () => {
        if (!graph || graph.get('destroyed')) return;
        if (!container || !container.scrollWidth || !container.scrollHeight) return;
        graph.changeSize(container.scrollWidth, container.scrollHeight);
      };
  }
  return <div id="container" className="overflow-auto" style={{ height: 'calc(75vh - 48px)' }} />;
}
