import { Col, Form, Modal, Row } from 'antd';
import request from '@/utils/request';
import DatePickerString from '@/components/forms/DatePickerString';
import dayjs from 'dayjs';

function CountComponent({ value = 0 }) {
  return <span className="text-red-6 ml-0.5">本次将清理共计{value}条日志信息</span>;
}
function LogClearModal(props) {
  const { visible, setFalse, refreshTableData } = props;
  const [form] = Form.useForm();
  function handleCancel() {
    form.resetFields();
    setFalse();
  }
  function handleFormSubmit() {
    return form.validateFields().then((values) => {
      request
        .getWMessage('/log/logClear/clearAndExport', { dateRange: values.dateRange })
        .then(() => {
          handleCancel();
          refreshTableData();
        });
    });
  }
  function handleChangeDate(currentDate) {
    request
      .getWMessage('/log/logClear/queryExportCount', { dateRange: currentDate })
      .then((res) => {
        form.setFieldsValue({ count: res.data });
      });
  }
  return (
    <Modal
      closeIcon
      title="日志清理"
      open={visible}
      onCancel={handleCancel}
      onOk={handleFormSubmit}
      centered
      width={500}
      className="mb-2"
    >
      <Row justify="center">
        <Col span={20}>
          <Form form={form} requiredMark={false}>
            <Form.Item
              name="dateRange"
              rules={[{ required: true, message: '请选择截止日期' }]}
              label={<span className="text-blue-6">请选择需清理的日志截止日期</span>}
            >
              <DatePickerString
                format="YYYY-MM-DD"
                onChange={handleChangeDate}
                disabledDate={(current) => current && current >= dayjs().endOf('day')}
              />
            </Form.Item>
            <Form.Item
              name="count"
              noStyle
              shouldUpdate={(prevValues, currentValues) =>
                prevValues.dateRange !== currentValues.dateRange
              }
            >
              <CountComponent />
            </Form.Item>
          </Form>
        </Col>
      </Row>
    </Modal>
  );
}
export default LogClearModal;
