import React, { CSSProperties, ReactNode } from 'react';
import styles from './StepDot.module.less';
import classNames from 'classnames';

interface StepDotProps {
  size?: 'large' | 'middle' | 'small';
  number: string | number;
  title?: string | Element;
  extra?: ReactNode;
  extraFloat?: 'none' | 'right';
  children?: string | ReactNode;
  style?: CSSProperties;
}

function StepDot({
  size,
  number,
  title,
  extra,
  extraFloat = 'right',
  children,
  ...restProps
}: StepDotProps) {
  return (
    <div className={classNames(styles.stepDotContainer, size && styles[size])} {...restProps}>
      <div className={styles.number}>{number}</div>
      {/*@ts-ignore*/}
      <span className={styles.title}>{title || children}</span>
      {extra && (
        <span className="extra" style={{ float: extraFloat }}>
          {extra}
        </span>
      )}
    </div>
  );
}

StepDot.defaultProps = {
  display: 'block',
};

export default StepDot;
