import ErrorLog from '@/pages/system/syncProcess/ErrorLog';
import MessageTemplateEdit from '@/pages/system/message/MessageTemplateEdit';
import MessageTemplates from '@/components/system/message/MessageTemplates';
import TemplateAuthorizationEdit from '@/pages/system/message/TemplateAuthorizationEdit';
import MessageLog from '@/pages/system/message/MessageLog';

/**
 * 本文件包含所有的路由配置
 * @createBy ShenShuo
 */
export interface RouteConfig {
  path: string; // 前端路由路径
  component?: string; // 页面文件名称(只能指定Pages文件夹下的文件)
  exact?: boolean; // 是否精确匹配, default: true
  headerRender?: boolean; // 是否展示页头, default: true
  menuRender?: boolean; // 是否展示菜单, default: true
  layout?: string; // 布局文件名称(只能指定layouts文件夹下的文件), 需要配合children使用
  children?: RouteConfig[]; // 子路由
  wrappers?: string[]; // 配置路由的高阶组件(只能指定layouts/wrappers文件夹下的文件)
}

export default [
  {
    path: '/account',
    layout: 'LoginLayout',
    children: [
      { path: '/account/login', component: 'LoginPage' },
      { path: '/account/register', component: 'RegisterPage' },
    ],
  },
  {
    path: '/',
    layout: 'PrimaryLayout',
    wrappers: ['Authenticated'],
    children: [
      { path: '/', component: 'WorkBench' },
      { path: '/home', component: 'HomePage' },
      { path: '/system/businessModel', component: 'BusinessModel' },
      { path: '/system/dataModel', component: 'DataModel' },
      { path: '/system/tenantTypeManagement', component: 'TenantTypeManagement' },
      { path: '/system/tenantCharacteristics', component: 'TenantCharacteristics' },
      { path: '/system/hostGroupManagement', component: 'HostGroupManagement' },
      { path: '/system/syncModelConfig', component: 'SyncModelConfig' },
      { path: '/system/syncModelEdit/:id', component: 'SyncModelEdit' },
      { path: '/system/syncTaskList', component: 'SyncTaskList' },
      { path: '/system/HostMaintenanceEdit/:id', component: 'HostMaintenance' },
      { path: '/system/syncProcessManage/:id?', component: 'SyncProcessManage' },
      { path: '/system/syncProcessManage/details/:id?', component: 'SyncProcessManageDetails' },
      { path: '/system/syncProcessManage/errorLog/:id', component: 'ErrorLog' },
      { path: '/workBench', component: 'WorkBench' },
      { path: '/system/logDetails', component: 'LogDetails' },
      { path: '/system/LogDetailsInfo', component: 'LogDetailsInfo' },
      { path: '/system/messageTemplateConfiguration', component: 'MessageTemplateConfiguration' },
      { path: '/system/messageTemplateEdit/:id', component: 'MessageTemplateEdit' },
      { path: '/system/messageTemplates', component: 'MessageTemplates' },
      { path: '/system/messageTemplateAuthorization', component: 'MessageTemplateAuthorization' },
      { path: '/system/messageLog', component: 'MessageLog' },
      {
        path: '/system/TemplateAuthorizationEdit/:id/:templateId',
        component: 'TemplateAuthorizationEdit',
      },
    ],
  },
] as RouteConfig[];
