/*
 * @description 本文件所有export必须是RegExp类型
 * 所有正则的验证必须在本文件中统一
 */

// 密码
export const PASSWORD_REGEXP: RegExp =
  /(?![0-9A-Z]+$)(?![0-9a-z]+$)(?![a-zA-Z]+$)[0-9A-Za-z]{8,18}$/;

// 强密码
export const STRONG_PASSWORD_REGEXP: RegExp =
  /^(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[~!@#$^&*()_+`])[\da-zA-Z~!@#$^&*()_+`]{8,20}$/;
/** /(?=\S*[~!@#$^&*()_+`])(?=\S*\d)(?=\S*[A-Z])(?=\S*[a-z])[a-zA-Z0-9~!@#$^&*()_+`]{8,20}$/;
 */

// 账号9
export const ACCOUNT_REGEXP: RegExp = /^[a-zA-Z0-9_]+$/;

// 邮编
export const POST_CODE_REGEXP: RegExp = /^[0-9]{6}$/;

// 手机
export const MOBILE_REGEXP: RegExp = /^[1][3-9][0-9]{9}$/;
//校验非空
export const NOT_NULL: RegExp = /\S/;

// 座机
export const PHONE_REGEXP: RegExp = /^([0-9]{3,4}-)?[0-9]{7,8}$/;

//区号是0开头的座机
export const PHONE_REGEXP_ZERO: RegExp = /^0\d{2,3}-?\d{7,8}$/;

// 座机&手机
export const TELEPHONE_MOBILE_REGEXP: RegExp =
  /^((1[3-9][0-9])|(14[5|7])|(15([0-3]|[5-9]))|(18[0,5-9]))\d{8}$|^0\d{2,3}-?\d{7,8}$/;

// 纯数字
export const NUMBER_REGEXP: RegExp = /^[0-9]*$/;

// 纯英文&下划线&数字
export const ENGLISH_UNDERLINE_REGEXP: RegExp = /^[a-zA-Z_0-9]+$/;

// 不超过100的数字
export const LESS_THAN_REGEXP: RegExp = /^(?:[1-9]?\d|100)$/;

// 大于0的数字
export const GREATER_THAN_REGEXP: RegExp = /^([1-9][0-9]*)+$/;

// 大写字母和下划线
export const UPPERCASE_UNDERSCORE_REGEXP: RegExp = /^[A-Z_]*$/;

// 四位大写字母
export const CAPITAL_REGEXP: RegExp = /^[A-Z]{4}$/;

// 身份证
export const ID_CARD_REGEXP: RegExp = /(^\d{15}$)|(^\d{18}$)|(^\d{17}(\d|X|x)$)/;

// 社会信用代码
export const CREDIT_CODE_REGEXP: RegExp = /^[^_IOZSVa-z\W]{2}\d{6}[^_IOZSVa-z\W]{10}$/g;

// 网址
export const WEBSITE_URL_REGEXP: RegExp = /^(https|http):\/\/\S+$/;

//输入值范围应为0-100内，最多保留两位小数
export const LESS_THAN_TWO_DECIMAL_REGEXP: RegExp = /^(100|(([1-9])\d?|0)((\.)(\d){1,2})?)$/;

//去除末尾的偶数0
export const REMOVER_ZERO_REGEXP: RegExp = /(00|0000|000000)$/;

//输入数字并且用逗号隔开
export const NUMBER_COMMA: RegExp = /^(\d+\.\d|\d+)(,(\d+\.\d|\d+))*,?$/;
//只能输入两位正整数，可以以0开头
export const NUMBER_ZERO_REGEXP: RegExp = /^(0[1-9]|[1-9]\d)$/;
// 同时验证手机号码和固定电话号码(带区号或不带区号)
export const TELEPHONE_MOBILE_COMMON__REGEXP: RegExp = /^1[3-9]\d{9}$|^(\d{3,4}-)?\d{7,8}$/;
//校验ip地址
export const IP_REGEXP: RegExp =
  /^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/;
//校验端口号
export const PORT_REGEXP: RegExp =
  /^(?:[1-9]\d{0,3}|[1-5]\d{4}|6[0-4]\d{3}|65[0-4]\d{2}|655[0-2]\d|6553[0-5])$/;
