import { useState } from 'react';
import { LabeledValue } from 'antd/es/select';
import { useRequest } from 'ahooks';
import request from '../utils/request';

export interface Options {
  codeName?: string;
  requestUrl?: string;
  requestParam?: any;
  valueAttr?: string;
  titleAttr?: string;
  mapOptionsFunc?: (item: any, index?: number) => LabeledValue;
  refreshDeps?: any[];
  initialOptions?: any[];
}

function useBackendOptions(options = {} as Options) {
  const {
    codeName,
    requestUrl = '/system/commonUtils/getSelectOption',
    requestParam,
    valueAttr = 'key',
    titleAttr = 'label',
    refreshDeps,
    mapOptionsFunc = defaultMapOptionsFunc,
    initialOptions = [],
  } = options;
  const [optionList, setOptionList] = useState<any[]>(initialOptions);

  useRequest(fetch, {
    refreshDeps,
  });

  function defaultMapOptionsFunc(item: any) {
    return {
      value: item[valueAttr],
      label: item[titleAttr],
      disabled: !!item.disabled,
    };
  }

  function fetch() {
    const params = codeName ? { codeName } : requestParam;
    return request.getWMessage(requestUrl, params).then((res) => {
      if (Array.isArray(res.data)) {
        const list = res.data.map(mapOptionsFunc);
        setOptionList(list);
      }
    });
  }

  return [optionList];
}

export default useBackendOptions;
