import { useMemo, useState } from 'react';
import { PaginationProps } from 'antd/es/pagination';
import { Page } from '../utils/request';

interface TablePaginationProps {
  dataSource: any[];
  pagination: PaginationProps;
}

const initialPagination = {
  current: 1,
  total: 0,
  pageSize: 10,
};

const defaultPaginationProps = {
  showQuickJumper: true,
  showSizeChanger: true,
  showTotal: (total: number) => `共 ${total} 条记录`,
};

type TablePaginationReturn = [
  TablePaginationProps,
  (page: Page) => void,
  (options: PaginationProps) => void,
];

function useTablePagination(paginationOptions?: PaginationProps): TablePaginationReturn {
  const [data, setData] = useState<TablePaginationProps>({
    dataSource: [],
    pagination: initialPagination,
  });
  const [paginationProps, setPaginationProps] = useState<PaginationProps>({
    ...defaultPaginationProps,
    ...paginationOptions,
  });

  const tableProps = useMemo<TablePaginationProps>(
    () => ({
      dataSource: data.dataSource,
      pagination: {
        ...paginationProps,
        ...data.pagination,
      },
    }),
    [data, paginationProps],
  );

  function setPage({ list, current, total, pageSize }: Page) {
    if (Array.isArray(list)) {
      setData({
        dataSource: list,
        pagination: {
          current,
          total,
          pageSize,
        },
      });
    }
  }

  function setPaginationOptions(options: PaginationProps) {
    setPaginationProps((prevState) => ({ ...prevState, ...options }));
  }

  return [tableProps, setPage, setPaginationOptions];
}

export default useTablePagination;
