import { message } from 'antd';
import request from '../utils/request';
import { useToken } from './index';

interface UploadOptions {
  maxFileSize?: number; // 上传文件大小, in MB
  acceptFileType?: string | string[]; // 可以上传的文件类型
}

const MAX_FILE_SIZE = 5;
const ACCEPT_FILE_TYPE = ['doc', 'pdf', 'jpg', 'png', 'xls', 'docx', 'xlsx'];

interface defaultUploadProps {
  name: string;
  action?: string;
  headers: object;
  onDownload: (id: string) => void;
  beforeUpload: (file: any) => boolean;
}

function useUploadProps(options: UploadOptions = {}): defaultUploadProps {
  const token = useToken();
  const { maxFileSize = MAX_FILE_SIZE, acceptFileType = ACCEPT_FILE_TYPE } = options;

  function onDownload(id: string) {
    request.download('joffice-file-s-003', { id });
  }

  function beforeUpload(file: any) {
    if (!file.type) {
      message.error('未获取到文件类型!');
      return false;
    }

    if (file.size > maxFileSize * 1024 * 1024) {
      message.error(`上传的文件大小不能超过${maxFileSize}MB`);
      return false;
    }

    const suffix = file.name.substring(file.name.lastIndexOf('.') + 1);
    if (acceptFileType.indexOf(suffix) < 0) {
      message.error(`只能上传${acceptFileType.toString()}类型的文件`);
      return false;
    }
    return true;
  }

  return {
    name: 'files',
    action: process.env.REACT_APP_UPLOAD,
    headers: {
      authorization: `Bearer ${token}`,
    },
    onDownload,
    beforeUpload,
  };
}

export default useUploadProps;
