import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import { FloatButton, Layout } from 'antd';
import { CustomLayoutContext } from '@/layouts/provider';
import PrimaryHeader from '@/layouts/header/PrimaryHeader';
import SiderMenu from '@/layouts/sider/SiderMenu';
import ErrorBoundary from './error/ErrorBoundary';

const { Content, Header } = Layout;

function PrimaryLayout({ children }) {
  const { menuDisplay, headerDisplay } = useContext(CustomLayoutContext);
  return (
    <Layout className="main-layout">
      {headerDisplay && (
        <Header className="primary-layout-header">
          <PrimaryHeader />
        </Header>
      )}
      <Layout>
        {menuDisplay && <SiderMenu />}
        <Content className="content-layout">
          <ErrorBoundary>{children}</ErrorBoundary>
          <FloatButton.BackTop />
        </Content>
      </Layout>
    </Layout>
  );
}

PrimaryLayout.propTypes = {
  children: PropTypes.element.isRequired,
};

export default PrimaryLayout;
