import React from 'react';
import { Route, Switch, useLocation } from 'react-router-dom';
import { RouteConfig } from '@/config/routes';
import Page403 from '../../pages/Page403';
import RouteRenderComponent from './RouteRenderComponent';
import Page404 from '../../pages/Page404';

interface RouteListProps {
  routeConfig: RouteConfig[];
}

function RouteList(props: RouteListProps) {
  const { routeConfig } = props;
  const location = useLocation();

  return (
    <Switch location={location}>
      {routeConfig.map((config) => {
        const { path, component, exact = !!component, ...restProps } = config;
        return (
          <Route
            key={path}
            exact={exact}
            path={path}
            render={(RouteProps) => {
              return <RouteRenderComponent component={component} {...restProps} {...RouteProps} />;
            }}
          />
        );
      })}
      <Route path="/403" component={Page403} />
      <Route component={Page404} />
    </Switch>
  );
}

RouteList.defaultProps = {
  routeConfig: [],
};

export default RouteList;
