import React, { useContext } from 'react';
import { Link, useHistory, useLocation } from 'react-router-dom';
import { HomeOutlined, PoweroffOutlined, SettingOutlined, UserOutlined } from '@ant-design/icons';
import useUserInfo from '@/hooks/useUserInfo';
import { Avatar, Space } from 'antd';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import { CustomLayoutContext } from '@/layouts/provider';
import UserAvatar from '@/layouts/header/UserAvatar';
import logo from '@/components/login/img/logo.png';
import styles from './OperatorLayout.module.less';

const hideHomePageMenu = [
  '/workspace',
  '/workspaceForPurchaseCenter',
  '/workspaceForAgentCenter',
  '/workspaceForRegulator',
];

function getFirstUrl(menuList) {
  return menuList?.[0]?.children?.[0].menuUrl || menuList?.[0]?.menuUrl || '/';
}

function ExtraIcon(props) {
  const { label, Icon, onClick } = props;
  return (
    <span className="cursor-pointer" onClick={onClick}>
      <Avatar
        size={32}
        className="bg-[#f4f4f4] mr-[8px] !leading-[30px]"
        icon={<Icon className="text-[#aeaeae]" />}
      />
      <span>{label}</span>
    </span>
  );
}

function PrimaryHeader({ logout, menu }) {
  const { menuDisplay } = useContext(CustomLayoutContext);
  const userInfo = useUserInfo();
  const location = useLocation();
  const history = useHistory();
  const homePagePath = menuDisplay ? getFirstUrl(menu) : '/';
  function handleLogout() {
    logout();
    history.push('/account/login');
  }

  return (
    <div className={styles.header}>
      <Link to={homePagePath}>
        <img alt="logo" src={logo} />
      </Link>
      <div className={styles.right}>
        <Space size={32}>
          <span>
            <UserAvatar className="mr-[8px]" size={32} defaultIcon={<UserOutlined />} />
            <span>{userInfo.username}</span>
          </span>
          {hideHomePageMenu.indexOf(location.pathname) === -1 && (
            <ExtraIcon
              label="平台首页"
              Icon={HomeOutlined}
              onClick={() => history.push('/workBench')}
            />
          )}
          <ExtraIcon label="退出系统" Icon={PoweroffOutlined} onClick={handleLogout} />
        </Space>
      </div>
    </div>
  );
}

PrimaryHeader.propTypes = {
  logout: PropTypes.func,
};
const mapStateToProps = (state) => ({ menu: state.user.menu });
const mapDispatchToProps = (dispatch) => ({
  logout: dispatch.login.logout,
});

export default connect(mapStateToProps, mapDispatchToProps)(PrimaryHeader);
