import React from 'react';
import { Layout, Menu } from 'antd';
import { useHistory, useLocation } from 'react-router-dom';
import { useSessionStorageState } from 'ahooks';
import styles from '@/layouts/header/OperatorLayout.module.less';
import menuIcon from '@/config/menuIcon';

const menu = [
  {
    menuName: '管理工作台',
    menuUrl: '/workBench',
  },
  {
    menuUrl: 'test',
    menuIco: 'solution',
    children: [
      {
        menuUrl: '/system/businessModel',
        menuName: '业务模型管理',
      },
      {
        menuUrl: '/system/dataModel',
        menuName: '数据模型管理',
      },
      {
        menuUrl: '/system/tenantTypeManagement',
        menuName: '租户类型管理',
      },
      {
        menuUrl: '/system/tenantCharacteristics',
        menuName: '租户特征管理',
      },
      {
        menuUrl: '/system/hostGroupManagement',
        menuName: '主机群管理',
      },
    ],
    menuName: '基础数据管理',
  },
  {
    menuUrl: 'sync',
    menuIco: 'solution',
    menuName: '同步模型管理',
    children: [
      {
        menuName: '同步模型配置',
        menuUrl: '/system/syncModelConfig',
      },
    ],
  },
  {
    menuUrl: 'task',
    menuIco: 'solution',
    menuName: '同步任务管理',
    children: [
      {
        menuName: '同步任务管理',
        menuUrl: '/system/syncTaskList',
      },
      {
        menuName: '日志总览',
        menuUrl: '/system/logDetails',
      },
    ],
  },
  {
    menuUrl: 'message',
    menuIco: 'solution',
    menuName: '短信数据管理',
    children: [
      {
        menuName: '短信模板配置',
        menuUrl: '/system/messageTemplateConfiguration',
      },
      { menuName: '短信模板授权', menuUrl: '/system/messageTemplateAuthorization' },
      {
        menuName: '短信生成日志',
        menuUrl: '/system/messageLog',
      },
    ],
  },
];

function SiderMenu() {
  const location = useLocation();
  const [openMenu, setOpenMenu] = useSessionStorageState('defaultOpenMenuKey', {
    defaultValue: [],
  });
  const history = useHistory();

  console.log(location);

  function renderMenuItem(item) {
    const { key, id, menuIco, menuName, menuUrl, children } = item;
    const MenuIcon = menuIcon[menuIco];

    return {
      key: menuUrl || key || id,
      icon: menuIco && MenuIcon && <MenuIcon />,
      children: children && children.length > 0 && children.map(renderMenuItem),
      label: menuName,
    };
  }

  return (
    <Layout.Sider className={styles.sideBox}>
      <div className={styles.menuBox}>
        <Menu
          mode="inline"
          inlineIndent="32"
          openKeys={openMenu}
          onOpenChange={(openKeys) => setOpenMenu(openKeys)}
          theme="light"
          selectedKeys={[location.pathname]}
          items={menu.map(renderMenuItem)}
          onClick={({ key }) => history.push(key)}
        />
      </div>
    </Layout.Sider>
  );
}

SiderMenu.propTypes = {};

SiderMenu.defaultProps = {};

export default SiderMenu;
