import { Form, Input, Button, Checkbox, Card, notification, Layout } from 'antd';
import styles from '@/components/login/login.module.less';
import store from 'store';
import { connect, useSelector } from 'react-redux';
import { getPageQuery } from '@/utils/utils';
import { useHistory } from 'react-router-dom';
import mainpic from '@/components/login/img/mainpic.png';
import title from '@/components/login/img/title.png';
import { useEffect, useState } from 'react';
import { LockOutlined, UserOutlined } from '@ant-design/icons';
import Captcha from '@/components/forms/Captcha';

const layout = {
  labelCol: {
    span: 8,
  },
  wrapperCol: {
    span: 16,
  },
};
const tailLayout = {
  wrapperCol: {
    offset: 8,
    span: 16,
  },
};

function LoginPage(props) {
  const { redirectUrl, preLogin } = props;
  const [form] = Form.useForm();
  const userId = useSelector((state) => state.user.id);
  const { location, replace } = useHistory();
  const [loading, setLoading] = useState(false);
  useEffect(() => {
    if (!store.enabled) {
      notification.error({
        message: '您的浏览器不支持本地储存',
        description: '请关闭"隐私模式"或升级更高版本的浏览器',
      });
    }
  }, []);
  function handleSubmit() {
    form.validateFields().then((values) => {
      const prevUserId = userId;
      setLoading(true);
      preLogin(values)
        .then((res) => {
          const { id } = res.data;
          // if (isProduction() && !STRONG_PASSWORD_REGEXP.test(values.password)) {
          //   replace('/user/changePassword');
          //   return;
          // }
          if (location.pathname.indexOf('/login') > -1) {
            const { rf } = getPageQuery();
            if (prevUserId === id && rf) {
              window.location.href = rf;
            } else if (redirectUrl) {
              replace(redirectUrl);
            } else {
              const defaultUrl = '/workBench';
              replace(defaultUrl);
            }
          }
        })
        .catch(() => {
          setLoading(false);
          form.resetFields(['captcha']);
        });
    });
  }
  return (
    <Layout className={styles.layoutWrap}>
      <Layout.Content className={styles.content}>
        <div className={styles.loginWrapForSz}>
          <Card
            width={1200}
            className={styles.contentCard}
            bordered={false}
            bodyStyle={{ padding: 0 }}
          >
            <div className={styles.center}>
              <img alt="pic" src={mainpic} className={styles.centerPic} />
            </div>
            <Card
              className={styles.right}
              bodyStyle={{ padding: '180px 68px 48px 0px ' }}
              bordered={false}
              style={{ boxShadow: 'none' }}
            >
              <div className={styles.rightTitle}>
                <img alt="logo" src={title} />
                <p>提升数据价值及效率</p>
              </div>
              <div className={styles.rightContent}>
                <Form name="basic" form={form}>
                  <Form.Item name="username" rules={[{ required: true, message: '请输入用户名' }]}>
                    <Input
                      data-id={10}
                      placeholder="请输入用户名"
                      prefix={<UserOutlined style={{ color: 'rgba(0,0,0,.25)' }} />}
                    />
                  </Form.Item>
                  <Form.Item
                    name="password"
                    rules={[{ required: true, message: '请输入登录密码' }]}
                  >
                    <Input.Password
                      data-id={11}
                      placeholder="请输入密码"
                      prefix={<LockOutlined style={{ color: 'rgba(0,0,0,.25)' }} />}
                    />
                  </Form.Item>
                  <Form.Item
                    name="captcha"
                    rules={[
                      { required: true, message: '请完成滑块验证' },
                      { type: 'enum', enum: ['success'], message: '验证失败, 请重新验证' },
                    ]}
                    initialValue="fail"
                  >
                    <Captcha onSuccess={handleSubmit} />
                  </Form.Item>
                  <Button
                    data-id={12}
                    block
                    type="primary"
                    loading={loading}
                    onClick={handleSubmit}
                  >
                    登录
                  </Button>
                </Form>
              </div>
            </Card>
          </Card>
        </div>
      </Layout.Content>
    </Layout>
  );
}

const mapDispatchToProps = (dispatch) => ({
  preLogin: dispatch.login.preLogin,
});
export default connect(null, mapDispatchToProps)(LoginPage);
// export default LoginPage;
