import { ManagePage, withManagePage } from '@/components/hoc/ManagePage';
import { Card, Cascader, Typography } from 'antd';
import { useBoolean } from 'ahooks';
import request from '@/utils/request';
import {
  publicMessageAuthorization,
  publicMessageItemList,
} from '@/pages/system/message/MessageCommon';
import { useEffect, useState } from 'react';
import dayjs from 'dayjs';
import MessageDetailLog from '@/components/system/message/MessageDetailLog';

function MessageLog() {
  const [visible, { setTrue, setFalse }] = useBoolean(false);
  const [areaList, setAreaList] = useState([]);
  const [templateId, setTemplateId] = useState([]);
  const searchBarItemList = [
    ...publicMessageItemList,
    {
      name: 'smsArea',
      label: '地区',
      component: Cascader,
      componentProps: {
        placeholder: '请选择地区',
        options: areaList,
        fieldNames: { label: 'areaName', value: 'areaId', children: 'children' },
        changeOnSelect: true,
        allowClear: true,
        style: { width: 200 },
      },
    },
  ];
  const tableColumns = [
    {
      title: '序号',
      dataIndex: 'index',
      width: 80,
      align: 'center',
      render: (text, record, index) => index + 1,
    },
    ...publicMessageAuthorization,
    {
      title: '备注说明',
      dataIndex: 'remark',
      key: 'remark',
      align: 'center',
      width: 220,
      render: (text) => (
        <Typography.Paragraph
          ellipsis={{
            rows: 2,
            tooltip: true,
          }}
          className="!mb-0"
        >
          {text || '-'}
        </Typography.Paragraph>
      ),
    },
    {
      title: '最新生成时间',
      dataIndex: 'createTime',
      width: 150,
      align: 'center',
      render: (text) => (text ? dayjs(text).format('YYYY-MM-DD HH:mm') : '-'),
    },
    {
      title: '生成数量',
      dataIndex: 'generateNum',
      width: 100,
      align: 'center',
      render: (text, record) => <a onClick={() => handleOpenDetail(record.templateId)}>{text}</a>,
    },
  ];
  useEffect(() => {
    fetchAreaList();
  }, []);

  function fetchAreaList() {
    request.getWMessage('/manager/smsArea/smsAreaList').then((res) => {
      setAreaList(res.data);
    });
  }
  function handleOpenDetail(recordId) {
    setTrue();
    setTemplateId(recordId);
  }
  return (
    <>
      <Card title="短信生成日志">
        <ManagePage tableColumns={tableColumns} searchBarItemList={searchBarItemList} />
      </Card>
      <MessageDetailLog drawerVisible={visible} setFalse={setFalse} templateId={templateId} />
    </>
  );
}
export default withManagePage(MessageLog, '/manager/smsSendInfo/sendInfoList');
