import { Button, Card, Col, Popconfirm, Row, Space, Switch, Table } from 'antd';
import styles from '@/components/system/message/messageEdit.module.less';
import React, { useEffect, useState } from 'react';
import request from '@/utils/request';
import SearchBar from '@/components/forms/SearchBar';
import {
  publicMessageAuthorization,
  publicMessageItemList,
} from '@/pages/system/message/MessageCommon';
import AddTemplate from '@/components/system/message/AddTemplate';
import { useBoolean } from 'ahooks';
import { useHistory } from 'react-router-dom';

function MessageTemplateAuthorization() {
  const [dataSource, setDataSource] = useState([]);
  const [areaDataSource, setAreaDataSource] = useState([]);
  const [selectedRowKeys, setSelectedRowKeys] = useState();
  const [drawerVisible, { setTrue, setFalse }] = useBoolean(false);
  const [pagination, setPagination] = useState({ total: 0, current: 1, pageSize: 10 });
  const [drawerSelectedRowKeys, setDrawerSelectedRowKeys] = useState([]);
  const history = useHistory();
  const columns = [
    {
      title: '序号',
      dataIndex: 'index',
      key: 'index',
      width: 80,
      align: 'center',
      render: (text, record, index) => index + 1,
    },
    ...publicMessageAuthorization,
    {
      title: '启用状态',
      dataIndex: 'isEnable',
      width: 120,
      editable: false,
      align: 'center',
      componentProps: {
        unCheckedChildren: '否',
        checkedChildren: '是',
      },
      render: (text, record) => (
        <Switch
          checked={text}
          checkedChildren="是"
          unCheckedChildren="否"
          onChange={(e) => handleSave({ ...record, isEnable: e })}
        />
      ),
    },
    {
      title: '操作',
      align: 'center',
      width: 180,
      dataIndex: 'option',
      valueType: 'option',
      render: (text, record) => {
        return (
          <Space>
            <Button
              type="link"
              size="small"
              onClick={() =>
                history.push(`/system/TemplateAuthorizationEdit/${record.id}/${record.templateId}`)
              }
            >
              编辑
            </Button>
            <Popconfirm title="确认移除吗?" onConfirm={() => handleDeleteFeature(record.id)}>
              <Button type="link" size="small">
                移除
              </Button>
            </Popconfirm>
          </Space>
        );
      },
    },
  ];
  function handleSave(values) {
    return request
      .postWMessage('/manager/smsTemplateAccredit/updateTemplateAccredit', values)
      .then(() => fetchTableData({ smsArea: selectedRowKeys }));
  }
  function handleDeleteFeature(deleteId) {
    request
      .deleteWMessage('/manager/smsTemplateAccredit/removeTemplateAccredit', { id: deleteId })
      .then(() => fetchTableData({ smsArea: selectedRowKeys }));
  }
  function getAreaList() {
    return request.getWMessage('/manager/smsArea/smsAreaList').then((res) => {
      const { data } = res;
      setAreaDataSource(data);
      if (data?.length > 0) {
        setSelectedRowKeys(data[0].areaId);
        fetchTableData({ smsArea: data[0].areaId });
      }
    });
  }
  function getCharacteristic(id) {
    return request
      .getWMessage('/syndata/tenantryHost/getTenantryHostFeature', {
        id: id,
      })
      .then((res) => setDataSource(res.data));
  }
  function onSelectChange(record) {
    setSelectedRowKeys(record.areaId);
    fetchTableData({ smsArea: record.areaId });
  }
  function fetchTableData(param) {
    return request
      .getWMessage('/manager/smsTemplateAccredit/templateAccreditList', {
        ...param,
      })
      .then((res) => {
        setPagination({
          current: res.data.current,
          total: res.data.total,
          pageSize: res.data.pageSize,
        });
        setDataSource(res.data.list || []);
      });
  }
  function onSearch(value) {
    fetchTableData({ pageSize: pagination.pageSize, ...value, smsArea: selectedRowKeys });
  }
  function handleClick() {
    setDrawerSelectedRowKeys(dataSource.map((i) => i.templateId));
    setTrue();
  }

  useEffect(() => {
    getAreaList();
  }, []);
  function setRowClassName(record) {
    return record.areaId === selectedRowKeys ? styles.selectedStyle : '';
  }
  return (
    <Card
      title="短信模板配置"
      extra={
        <Button type="primary" onClick={() => handleClick()}>
          模板授权
        </Button>
      }
      bodyStyle={{ minHeight: 'calc(90vh - 90px)', padding: 0 }}
    >
      <Row className={styles.rowStyle} gutter={[24, 24]}>
        <Col span={4} className={styles.colBorder}>
          <Table
            dataSource={areaDataSource}
            rowClassName={setRowClassName}
            columns={[
              {
                title: '地区',
                dataIndex: 'areaName',
                key: 'areaName',
                width: 200,
              },
            ]}
            rowKey="areaId"
            onRow={(record) => ({
              onClick: () => {
                onSelectChange(record);
              },
            })}
            pagination={false}
            scroll={{ y: '67vh' }}
          />
        </Col>
        {selectedRowKeys && (
          <Col span={20} className="mt-4">
            <SearchBar onSearch={onSearch} itemList={publicMessageItemList} />
            <Table
              dataSource={dataSource}
              columns={columns}
              rowKey="id"
              bordered
              pagination={{
                ...pagination,
                showQuickJumper: true,
                showSizeChanger: true,
                showTotal: (total) => `共 ${total} 项`,
              }}
            />
          </Col>
        )}
      </Row>
      <AddTemplate
        drawerVisible={drawerVisible}
        setFalse={setFalse}
        smsArea={selectedRowKeys}
        selectedRowKeys={drawerSelectedRowKeys}
        setSelectedRowKeys={setDrawerSelectedRowKeys}
        fetchTableData={fetchTableData}
      />
    </Card>
  );
}

export default MessageTemplateAuthorization;
