import { ManagePage, withManagePage } from '@/components/hoc/ManagePage';
import { Button, Card, Form, Input, Modal, Popconfirm, Space, Switch } from 'antd';
import FormBuilder from '@/components/forms/FormBuilder';
import { useBoolean } from 'ahooks';
import request from '@/utils/request';
import RemoteSelect from '@/components/forms/RemoteSelect';
import { searchItem, tenantTypeColumns } from '@/pages/system/message/MessageCommon';
import React from 'react';
import styles from '@/pages/system/modelManagement/Model.module.less';
import { useHistory } from 'react-router-dom';

function MessageTemplateConfiguration(props) {
  const [visible, { setTrue, setFalse }] = useBoolean(false);
  const history = useHistory();
  const [form] = Form.useForm();
  const formItemLayout = { labelCol: { span: 4 }, wrapperCol: { span: 18 } };
  function handleCancel() {
    setFalse();
    form.resetFields();
  }
  function handleEdit(record) {
    setTrue();
    form.setFieldsValue(record);
  }
  function handleFormSubmit() {
    return form.validateFields().then((values) => {
      handleSave(values);
    });
  }
  function handleSave(param) {
    return request.postWMessage('/manager/smsTemplate/addTemplate', param).then(() => {
      setFalse();
      form.resetFields();
      props.refreshTableData();
    });
  }
  function handleDelete(id) {
    request.deleteWMessage('/manager/smsTemplate/deleteTemplate', { id }).then(() => {
      setFalse();
      props.refreshTableData();
    });
  }
  const options = [
    {
      title: '启用状态',
      dataIndex: 'isEnable',
      width: 120,
      editable: false,
      align: 'center',
      componentProps: {
        unCheckedChildren: '否',
        checkedChildren: '是',
      },
      render: (text, record) => (
        <Switch
          checked={text}
          checkedChildren="是"
          unCheckedChildren="否"
          disabled={!record.isPass}
          onChange={(e) => handleSave({ ...record, isEnable: e })}
        />
      ),
    },
    {
      title: '操作',
      width: 80,
      dataIndex: 'options',
      align: 'center',
      render: (_, record) => {
        return (
          <Space>
            <Button type="link" onClick={() => handleEdit(record)} size="small">
              编辑
            </Button>
            <Button
              type="link"
              onClick={() => history.push(`/system/MessageTemplateEdit/${record.id}`)}
              size="small"
            >
              配置
            </Button>
            <Popconfirm title="确认删除吗?" onConfirm={() => handleDelete(record.id)}>
              <Button type="link" size="small">
                删除
              </Button>
            </Popconfirm>
          </Space>
        );
      },
    },
  ];
  const formItems = [
    { name: 'id', key: 'id', visible: false },
    {
      name: 'templateIdentification',
      key: 'templateIdentification',
      label: '模板标识',
      required: true,
      disabled: true,
    },
    {
      name: 'templateName',
      key: 'templateName',
      label: '模板标题',
      required: true,
    },
    // {
    //   name: 'templateType',
    //   key: 'templateType',
    //   label: '触发类型',
    //   component: Radio.Group,
    //   required: true,
    //   componentProps: {
    //     options: messageTypeOptions,
    //   },
    // },
    {
      name: 'dbName',
      key: 'dbName',
      label: '库名',
      required: true,
    },
    {
      name: 'tableName',
      key: 'tableName',
      label: '表名',
      required: true,
    },
    {
      name: 'sendUser',
      key: 'sendUser',
      label: '发送用户',
      required: true,
      component: RemoteSelect,
      componentProps: {
        allowClear: true,
        placeholder: '请选择',
        requestUrl: '/manager/smsDict/option',
        requestParam: { dictType: 'office_type' },
        titleAttr: 'dictLabel',
        valueAttr: 'dictValue',
      },
    },
    {
      name: 'remark',
      label: '备注说明',
      component: Input.TextArea,
      extra: '最多输入100字',
      formItemProps: {
        className: styles.reMark,
      },
      componentProps: {
        rows: 4,
        maxLength: 100,
      },
    },
  ];
  function handleAdd() {
    setTrue();
    getTemplateIdentification();
  }
  function getTemplateIdentification() {
    return request.getWMessage('/manager/smsTemplate/getTemplateIdentification').then((res) => {
      form.setFieldsValue({ templateIdentification: res.data });
    });
  }
  return (
    <>
      <Card
        title="短信模板配置"
        extra={
          <Button onClick={handleAdd} type="primary">
            新增
          </Button>
        }
      >
        <ManagePage
          tableColumns={tenantTypeColumns.concat(options)}
          searchBarItemList={searchItem}
        />
      </Card>
      <Modal
        closeIcon
        title={form.getFieldValue('id') ? '编辑模版' : '新建模板'}
        open={visible}
        onCancel={handleCancel}
        onOk={handleFormSubmit}
        centered
        width={700}
        className="mb-2"
      >
        <Form form={form} {...formItemLayout}>
          <FormBuilder items={formItems} />
        </Form>
      </Modal>
    </>
  );
}
export default withManagePage(MessageTemplateConfiguration, '/manager/smsTemplate/templateList');
