import { Button, Card, Form } from 'antd';
import MessageTemplates from '@/components/system/message/MessageTemplates';
import EvalToolbar from '@/components/evalBid/EvalToolbar';
import React, { useEffect, useState } from 'react';
import { useHistory, useParams } from 'react-router-dom';
import request from '@/utils/request';

function TemplateAuthorizationEdit() {
  const history = useHistory();
  const { id, templateId } = useParams();
  const [form] = Form.useForm();
  const [editor, setEditor] = useState();

  function handleSave() {
    form.validateFields().then((values) => {
      request
        .postWMessage('/manager/smsTemplateAccredit/updateTemplateAccredit', {
          templateContent: editor.getContent(),
          id,
        })
        .then(fetchTemplateMessage);
    });
  }
  function fetchTemplateMessage() {
    request.getWMessage('/manager/smsTemplateAccredit/getTemplateAccredit', { id }).then((res) => {
      form.setFieldsValue(res.data);
    });
  }
  function fetchRestoreTemplateMessage() {
    request
      .postWMessage('/manager/smsTemplateAccredit/resetTemplateAccredit', { id, templateId })
      .then(fetchTemplateMessage);
  }
  useEffect(() => {
    fetchTemplateMessage();
  }, [id]);
  return (
    <Card
      extra={
        <Button type="primary" onClick={() => fetchRestoreTemplateMessage()}>
          恢复默认模板
        </Button>
      }
      title="短信模板配置"
    >
      <Form form={form}>
        <Form.Item name="templateContent" required noStyle>
          <MessageTemplates setEditor={setEditor} />
        </Form.Item>
      </Form>
      <EvalToolbar>
        <Button onClick={() => history.goBack()}>返回</Button>
        <Button type="primary" onClick={() => handleSave()}>
          保存
        </Button>
      </EvalToolbar>
    </Card>
  );
}
export default TemplateAuthorizationEdit;
