import { ManagePage, withManagePage } from '@/components/hoc/ManagePage';
import { Button, Card, Form, Input, Modal, Popconfirm, Space } from 'antd';
import request from '@/utils/request';
import { useBoolean } from 'ahooks';
import FormBuilder from '@/components/forms/FormBuilder';
import { businessModelCol, keyWordItem } from '@/pages/system/modelManagement/ModelColumns';
import styles from './Model.module.less';

function BusinessModel(props) {
  const [visible, { setTrue, setFalse }] = useBoolean(false);
  const [form] = Form.useForm();
  const formItemLayout = { labelCol: { span: 4 }, wrapperCol: { span: 18 } };
  const formItem = [
    { name: 'id', visible: false },
    {
      name: 'modelName',
      label: '模型名称',
      required: true,
    },
    {
      name: 'modelIdentification',
      label: '模型标识',
      disabled: !!form.getFieldValue('id'),
      required: true,
    },
    {
      name: 'remark',
      label: '备注信息',
      component: Input.TextArea,
      extra: '最多输入100字',
      formItemProps: {
        className: styles.reMark,
      },
      componentProps: {
        rows: 4,
        maxLength: 100,
      },
    },
  ];

  const option = {
    title: '操作',
    width: 80,
    align: 'center',
    render: (_, record) => {
      return (
        <Space>
          <Button type="link" onClick={() => handleEdit(record)} size="small">
            编辑
          </Button>
          <Popconfirm title="确认删除吗?" onConfirm={() => handleDelete(record.id)}>
            <Button type="link" size="small">
              删除
            </Button>
          </Popconfirm>
        </Space>
      );
    },
  };

  function handleEdit(record) {
    setTrue();
    form.setFieldsValue(record);
  }

  function handleCancel() {
    setFalse();
    form.resetFields();
  }

  function handleDelete(deleteId) {
    request
      .deleteWMessage('/syndata/businessModel/deleteBusinessModel', { id: deleteId })
      .then(() => {
        props.refreshTableData();
      });
  }

  function handleFormSubmit() {
    return form.validateFields().then((values) => {
      request
        .postWMessage('/syndata/businessModel/saveBusinessModel', values)
        .then(() => {
          props.refreshTableData();
        })
        .finally(() => {
          setFalse();
          form.resetFields();
        });
    });
  }

  return (
    <>
      <Card
        title="业务模型管理"
        extra={
          <Button onClick={setTrue} type="primary">
            新增
          </Button>
        }
      >
        <ManagePage
          tableColumns={businessModelCol.concat(option)}
          searchBarItemList={[keyWordItem]}
        />
      </Card>
      <Modal
        title="业务模型维护"
        open={visible}
        onCancel={handleCancel}
        onOk={handleFormSubmit}
        centered
        width={700}
        closeIcon
      >
        <Form form={form} {...formItemLayout}>
          <FormBuilder items={formItem} />
        </Form>
      </Modal>
    </>
  );
}

export default withManagePage(BusinessModel, '/syndata/businessModel/getBusinessModel');
