import React from 'react';
import { Line } from '@ant-design/plots';

function LineChart({ data }) {
  const config = {
    data,
    xField: 'hour',
    yField: 'value',
    seriesField: 'category',
    color: ['#1677FF', 'red'],
    tooltip: {
      formatter: (v) => {
        return { name: v.hour, value: `${v.value}万` };
      },
    },
    // X 轴相关配置
    xAxis: {
      grid: {
        line: {
          style: {
            stroke: 'rgba(0,0,0,0.05)',
          },
        },
      },
    },
    // Y 轴相关配置
    yAxis: {
      // max: 3000,
      // 文本标签
      label: {
        autoRotate: false,
        style: {
          fill: '#aaa',
          fontSize: 12,
        },
        // 数值格式化为千分位
        formatter: (v) => {
          return `${v}万`;
        },
      },
      // 坐标轴线的配置项 null 表示不展示
      grid: {
        line: {
          style: {
            stroke: 'rgba(0,0,0,0.05)',
          },
        },
      },
    },
    label: {
      layout: [
        {
          type: 'hide-overlap',
        },
      ],
      // 隐藏重叠label
      style: {
        textAlign: 'right',
      },
      formatter: (item) => item.value,
    },
    // point
    point: {
      size: 3,
      style: (item) => {
        return {
          lineWidth: 3,
          fillOpacity: 1,
          fill: 'white',
          stroke: item.category === '同步成功' ? '#1677FF' : 'red',
        };
      },
      shape: 'circle',
    },
    // annotations: [
    //   // 辅助线
    //   {
    //     type: 'line',
    //     start: ['0%', '20%'],
    //     end: ['100%', '20%'],
    //     top: true,
    //     style: {
    //       stroke: '#F59A23',
    //       lineWidth: 2,
    //       lineDash: [10, 4],
    //     },
    //   },
    // ],
    legend: {
      position: 'top-right',
    },
    // 度量相关配置
    meta: {
      // year 对应 xField || yField
      year: {
        range: [0, 1],
      },
    },
    autoFit: true,
  };
  return <>{data?.length > 0 && <Line {...config} />}</>;
}
export default LineChart;
