import React, { useEffect, useState } from 'react';
import { Card, Col, Row, Table, Tag } from 'antd';
import styles from '@/pages/staging.module.less';
import TitleStyle from '@/layouts/header/TitleStyle';
import WorkBenchCol from '@/pages/system/staging/WorkBenchCol';
import {
  CountColor,
  CountName,
  WorkBenchColor,
  WorkBenchName,
} from '@/pages/system/staging/WorkBenchType';
import LineChart from '@/pages/system/staging/LineChart';
import { TenantUserTypeColor } from '@/const/TenantType';
import Histogram from '@/pages/system/staging/Histogram';
import request from '@/utils/request';

function WorkBench() {
  const [dataSource, setDataSource] = useState([]);
  const [lineChartData, setLineChartData] = useState([]);
  const [histogramData, setHistogramData] = useState([]);
  const [asyncItemData, setAsyncItemData] = useState([]);
  const [countItemData, setCountItemData] = useState([]);
  useEffect(() => fetchData(), []);
  function fetchData() {
    return request.getWMessage('/syndata/workBenchManagement/getWorkBenchData').then((res) => {
      const { data } = res;
      const asyncItem = data.overviewOfSynchronizationTasks;
      const asyncItemMap = Object.entries(asyncItem).map(([key, value]) => ({
        key,
        value,
        label: WorkBenchName[key],
      }));
      setAsyncItemData(asyncItemMap);
      const countItem = data.basicdatastatistics;
      const countItemMap = Object.entries(countItem).map(([key, value]) => ({
        key,
        value,
        label: CountName[key],
      }));
      setCountItemData(countItemMap);
      setLineChartData(data.synchronousDataToday);
      setDataSource(data.hostOperatingStateList);
      setHistogramData(data.monthlySynchronizationData);
    });
  }
  const tenantColumns = [
    {
      title: '租户类型',
      dataIndex: 'tenantryUserType',
      align: 'center',
      width: 100,
      render: (text, record) => (
        <Tag color={TenantUserTypeColor[text]} className="w-24 text-sm text-center">
          {record.tenantTypeName}
        </Tag>
      ),
    },
    {
      title: '主机总数',
      dataIndex: 'numberOfHosts',
      key: 'numberOfHosts',
      width: 100,
      align: 'center',
      render: (text) => <span className="text-blue-6">{text}</span>,
    },
    {
      title: '正常',
      width: 80,
      align: 'center',
      dataIndex: 'normalHost',
      key: 'normalHost',
      render: (text) => <span className="text-green-6">{text}</span>,
    },
    {
      title: '异常',
      width: 80,
      align: 'center',
      dataIndex: 'abnormalHost',
      key: 'abnormalHost',
      render: (text) => <span className="text-red-6">{text}</span>,
    },
  ];
  return (
    <div className={styles.box}>
      <Row gutter={12}>
        <Col span={12}>
          <Card bodyStyle={{ paddingTop: '8px', height: '100%' }} className={styles.cardStyle}>
            <Card.Meta title={<TitleStyle>同步任务总览</TitleStyle>} />
            <WorkBenchCol items={asyncItemData} colorMap={WorkBenchColor} nameMap={WorkBenchName} />
          </Card>
        </Col>
        <Col span={12}>
          <Card bodyStyle={{ paddingTop: '8px', height: '100%' }} className={styles.cardStyle}>
            <Card.Meta title={<TitleStyle>基础数据统计</TitleStyle>} />
            <WorkBenchCol items={countItemData} colorMap={CountColor} />
          </Card>
        </Col>
      </Row>
      <Row>
        <Col span={24}>
          <Card>
            <Card.Meta title={<TitleStyle>今日同步数据情况</TitleStyle>} />
            <LineChart data={lineChartData} />
          </Card>
        </Col>
      </Row>
      <Row gutter={12}>
        <Col span={8}>
          <Card bodyStyle={{ paddingTop: '8px', overflow: 'scroll' }}>
            <Card.Meta title={<TitleStyle>主机运行状态</TitleStyle>} />
            <Table
              size="small"
              dataSource={dataSource}
              columns={tenantColumns}
              rowKey="tenantryUserType"
              style={{ paddingTop: '8px' }}
              pagination={false}
            />
          </Card>
        </Col>
        <Col span={16}>
          <Card bodyStyle={{ paddingTop: '16px' }}>
            <Card.Meta title={<TitleStyle>月度同步情况统计</TitleStyle>} />
            <Histogram data={histogramData} />
          </Card>
        </Col>
      </Row>
    </div>
  );
}
export default WorkBench;
