import { Button, Col, message, Row, Select, Switch } from 'antd';
import React, { useEffect, useState } from 'react';
import request from '@/utils/request';
import EditProTable from '@/components/table/EditProTable';

function MetaDataTable(props) {
  const { dataModelId, metaDataDataSource, setMetaDataDataSource, setFalse } = props;
  const [selectedRowKey, setSelectRowKey] = useState([]);
  const [pagination, setPagination] = useState({ total: 0, current: 1, pagSize: 10 });
  useEffect(() => {
    if (dataModelId) {
      fetchTableData();
    }
  }, [dataModelId]);
  function fetchTableData(param) {
    return request
      .getWMessage('/syndata/syncModel/getSyncModelHypertable', { id: dataModelId, ...param })
      .then((res) => {
        setMetaDataDataSource(res.data.list || []);
        setPagination({
          current: res.data.current,
          total: res.data.total,
          pageSize: res.data.pageSize,
        });
      })
      .finally(setFalse);
  }
  const fieldColumns = [
    {
      title: '源字段',
      editable: false,
      width: 120,
      align: 'center',
      dataIndex: 'sourceField',
      formItemProps: () => {
        return {
          rules: [
            { required: true, message: '此项为必填项' },
            {
              pattern: /^[^\s]*$/,
              message: '禁止输入空格',
            },
            {
              pattern: /^[^0-9]/,
              message: '不能以数字开头',
            },
          ],
        };
      },
      // render: (text, record) => {
      //   if (record.isPrimary) {
      //     return (
      //       <Space>
      //         <span>{text}</span>
      //         <Tag color="#f50">主键</Tag>
      //       </Space>
      //     );
      //   }
      //   return text;
      // },
    },
    {
      title: '数据类型',
      dataIndex: 'sourceDataType',
      width: 120,
      editable: false,
      align: 'center',
      renderFormItem: () => (
        <Select style={{ width: '100px' }} getPopupContainer={() => document.body}>
          <Select.Option value="int">int</Select.Option>
          <Select.Option value="varchar">varchar</Select.Option>
          <Select.Option value="date">date</Select.Option>
          <Select.Option value="decimal">decimal</Select.Option>
          <Select.Option value="datetime">datetime</Select.Option>
        </Select>
      ),
      formItemProps: () => {
        return {
          rules: [{ required: true, message: '此项为必填项' }],
        };
      },
    },
    {
      title: '是否主键',
      dataIndex: 'isPrimary',
      component: Switch,
      width: 120,
      editable: false,
      align: 'center',
      componentProps: {
        unCheckedChildren: '否',
        checkedChildren: '是',
      },
      formItemProps: {
        valuePropName: 'checked',
      },
      render: (text) => (
        <Switch checked={text} disabled={true} checkedChildren="是" unCheckedChildren="否" />
      ),
      renderFormItem: (text) => (
        <Switch checked={text} checkedChildren="是" unCheckedChildren="否" />
      ),
    },
    // {
    //   title: '是否为空',
    //   dataIndex: 'sourceIsEmpty',
    //   component: Switch,
    //   width: 100,
    //   align: 'center',
    //   componentProps: {
    //     unCheckedChildren: '否',
    //     checkedChildren: '是',
    //   },
    //   formItemProps: {
    //     valuePropName: 'checked',
    //   },
    //   render: (text, record) => (
    //     <Switch disabled={true} checked={text} checkedChildren="是" unCheckedChildren="否" />
    //   ),
    //   renderFormItem: (text) => (
    //     <Switch checked={text} checkedChildren="是" unCheckedChildren="否" />
    //   ),
    // },
    {
      title: '目标字段',
      dataIndex: 'targetField',
      width: 120,
      formItemProps: () => {
        return {
          rules: [
            { required: true, message: '此项为必填项' },
            {
              pattern: /^[^\s]*$/,
              message: '禁止输入空格',
            },
            {
              pattern: /^[^0-9]/,
              message: '不能以数字开头',
            },
          ],
        };
      },
      // render: (text, record) => {
      //   if (record.targetIfKey) {
      //     return (
      //       <Space>
      //         <span>{text}</span>
      //         <Tag color="#f50">主键</Tag>
      //       </Space>
      //     );
      //   }
      //   return text;
      // },
    },
    // {
    //   title: '数据类型',
    //   dataIndex: 'targetDataType',
    //   align: 'center',
    //   renderFormItem: () => (
    //     <Select style={{ width: '100px' }} getPopupContainer={(t) => document.body}>
    //       <Select.Option value="int">int</Select.Option>
    //       <Select.Option value="varchar">varchar</Select.Option>
    //       <Select.Option value="date">date</Select.Option>
    //       <Select.Option value="decimal">decimal</Select.Option>
    //       <Select.Option value="datetime">datetime</Select.Option>
    //     </Select>
    //   ),
    //   formItemProps: () => {
    //     return {
    //       rules: [{ required: true, message: '此项为必填项' }],
    //     };
    //   },
    // },
    // {
    //   title: '是否主键',
    //   dataIndex: 'targetIfKey',
    //   component: Switch,
    //   width: 100,
    //   align: 'center',
    //   componentProps: {
    //     unCheckedChildren: '否',
    //     checkedChildren: '是',
    //   },
    //   formItemProps: {
    //     valuePropName: 'checked',
    //   },
    //   render: (text, record) => (
    //     <Switch
    //       checked={text}
    //       checkedChildren="是"
    //       unCheckedChildren="否"
    //       // onChange={(state) => handleSave({ ...record, enabled: state })}
    //     />
    //   ),
    //   renderFormItem: (text) => (
    //     <Switch checked={text} checkedChildren="是" unCheckedChildren="否" />
    //   ),
    // },
    // {
    //   title: '是否为空',
    //   dataIndex: 'targetIsEmpty',
    //   component: Switch,
    //   width: 100,
    //   align: 'center',
    //   componentProps: {
    //     unCheckedChildren: '否',
    //     checkedChildren: '是',
    //   },
    //   formItemProps: {
    //     valuePropName: 'checked',
    //   },
    //   render: (text, record) => (
    //     <Switch
    //       checked={text}
    //       checkedChildren="是"
    //       unCheckedChildren="否"
    //       disabled={true}
    //       // onChange={(state) => handleSave({ ...record, enabled: state })}
    //     />
    //   ),
    //   renderFormItem: (text) => (
    //     <Switch checked={text} checkedChildren="是" unCheckedChildren="否" />
    //   ),
    // },
    // {
    //   title: '操作',
    //   valueType: 'option',
    //   width: 120,
    //   align: 'center',
    //   render: (text, row, _, action) => (
    //     <Space>
    //       <Button
    //         type="link"
    //         size="small"
    //         key={`editable${row.id}`}
    //         onClick={() => {
    //           action?.startEditable?.(row.id);
    //         }}
    //       >
    //         编辑
    //       </Button>
    //       <Popconfirm
    //         title="您确定删除吗?"
    //         onConfirm={() =>
    //           setMetaDataDataSource(metaDataDataSource.filter((item) => item.id !== row.id))
    //         }
    //       >
    //         <Button type="link" size="small" key={`delete${row.id}`}>
    //           删除
    //         </Button>
    //       </Popconfirm>
    //     </Space>
    //   ),
    // },
  ];
  function batchDelete() {
    let tempList = [...metaDataDataSource];
    selectedRowKey.forEach((item) => {
      tempList = tempList.filter((i) => i.id !== item);
    });
    request
      .postWMessage('/syndata/syncModel/deleteSyncModelHypertable', selectedRowKey)
      .then((res) => {
        setMetaDataDataSource(() => tempList);
        setSelectRowKey([]);
      });
  }
  function onSave(current, allData) {
    const sameArr = metaDataDataSource.filter(
      (i) => i.id !== current && i.sourceField === allData.sourceField,
    );
    if (sameArr.length > 0) {
      message.error('存在重复数据');
      return Promise.reject();
    }
    return Promise.resolve();
  }
  const rowSelection = {
    selectedRowKey,
    onChange: (selectedRowKeysList) => {
      setSelectRowKey(selectedRowKeysList);
    },
  };
  function handleTableChange(current, pageSize) {
    fetchTableData({ current, pageSize });
  }
  function columnsOptions(record, index, editRow) {
    return (
      <Button type="link" size="small" onClick={() => editRow(record)}>
        编辑
      </Button>
    );
  }
  return (
    <>
      <Row className="mb-4">
        <Col span={4} offset={1}>
          <span className="text-base">元数据配置</span>
        </Col>
        {/*<Col span={18} style={{ textAlign: 'right' }}>*/}
        {/*  <Space>*/}
        {/*    <Button type="primary" danger onClick={batchDelete}>*/}
        {/*      批量删除*/}
        {/*    </Button>*/}
        {/*    <Button>引入源表</Button>*/}
        {/*  </Space>*/}
        {/*</Col>*/}
      </Row>
      <Row>
        <EditProTable
          rowKey="id"
          size="middle"
          bordered
          columns={fieldColumns}
          // rowSelection={rowSelection}
          value={metaDataDataSource}
          onEdit={setMetaDataDataSource}
          onEditingKeyChange={setSelectRowKey}
          className="ml-2 w-full"
          handleSave={onSave}
          scroll={{ y: 360 }}
          onChange={setMetaDataDataSource}
          pagination={{
            ...pagination,
            showQuickJumper: true,
            showSizeChanger: false,
            showTotal: (total) => `共 ${total} 项`,
          }}
          onTableChange={handleTableChange}
          creatorButtonText={false}
          columnsOptions={columnsOptions}
        />
        {/*<EditableProTable*/}
        {/*  rowSelection={{*/}
        {/*    type: 'checkbox',*/}
        {/*    onChange: setSelectRowKey,*/}
        {/*  }}*/}
        {/*  toolBarRender={false}*/}
        {/*  tableAlertRender={false}*/}
        {/*  columns={fieldColumns}*/}
        {/*  value={metaDataDataSource}*/}
        {/*  className="ml-2"*/}
        {/*  rowKey="id"*/}
        {/*  onChange={setMetaDataDataSource}*/}
        {/*  // recordCreatorProps={{*/}
        {/*  //   record: () => ({*/}
        {/*  //     id: `new${Date.now().toString()}`,*/}
        {/*  //   }),*/}
        {/*  //   creatorButtonText: '添加行',*/}
        {/*  // }}*/}
        {/*  recordCreatorProps={false}*/}
        {/*  rowClassName={(item, index) => {*/}
        {/*    if (item.ifEmpty) {*/}
        {/*      return styles.emptyRow;*/}
        {/*    }*/}
        {/*    if (item.ifSame) {*/}
        {/*      return styles.errorRow;*/}
        {/*    }*/}
        {/*    return '';*/}
        {/*  }}*/}
        {/*  editable={{*/}
        {/*    type: 'multiple',*/}
        {/*    editableKeys: selectedRowKey,*/}
        {/*    onChange: setSelectRowKey,*/}
        {/*    onSave,*/}
        {/*    actionRender: (row, config, defaultDom) => [defaultDom.save, defaultDom.cancel],*/}
        {/*  }}*/}
        {/*/>*/}
      </Row>
    </>
  );
}
export default MetaDataTable;
