import styles from '@/pages/system/syncModel/SyncModel.module.less';
import { Button, Col, Descriptions, Row, Space, Spin, Switch, Table, Tabs, Tag } from 'antd';
import MetaDataTable from '@/pages/system/syncModel/MetaDataTable';
import request from '@/utils/request';
import { useEffect, useState } from 'react';
import FilterRulesDrawer from '@/pages/system/syncModel/FilterRulesDrawer';
import SpecificFieldsDrawer from '@/pages/system/syncModel/SpecificFieldsDrawer';
import { useBoolean } from 'ahooks';
import { useParams } from 'react-router-dom';

function MetadataConfiguration(props) {
  const { id } = useParams();
  const {
    businessModelName,
    selectedRowKeys,
    setSelectedRowKeys,
    metaDataDataSource,
    setMetaDataDataSource,
  } = props;
  const [items, setItems] = useState([]);
  const [activeKey, setActiveKey] = useState('');
  const [loading, { setTrue, setFalse }] = useBoolean(false);
  const [dataSource, setDataSource] = useState([]);
  const [pagination, setPagination] = useState({ total: 0, current: 1, pagSize: 10 });
  const [filterRulesOpen, { setTrue: setFilterRulesTrue, setFalse: setFilterRulesFalse }] =
    useBoolean(false);
  const [isMasterModel, setIsMasterModel] = useState(false);

  const [
    specificFieldsOpen,
    { setTrue: setSpecificFieldsOpenTrue, setFalse: setSpecificFieldsOpenFalse },
  ] = useBoolean(false);
  useEffect(() => handleSearchSyncModel(), [id]);
  const columns = [
    {
      title: '同步表',
      dataIndex: 'tableName',
      key: 'tableName',
      width: 100,
      required: true,
      align: 'center',
      componentProps: {
        style: { minWidth: 180 },
      },
      render: (text, record) => {
        if (record.pid === '0') {
          return (
            <Space>
              {text}
              <Tag color="#f50">主表</Tag>
            </Space>
          );
        }
        return text;
      },
    },
    {
      key: 'isShare',
      dataIndex: 'isShare',
      title: '是否共享',
      component: Switch,
      width: 100,
      align: 'center',
      componentProps: {
        unCheckedChildren: '否',
        checkedChildren: '是',
      },
      formItemProps: {
        valuePropName: 'checked',
      },
      render: (text, record) => (
        <Switch
          checked={text}
          checkedChildren="是"
          unCheckedChildren="否"
          onChange={(state) => handleSave({ ...record, isShare: state })}
        />
      ),
    },
    {
      title: '操作',
      align: 'center',
      width: 100,
      dataIndex: 'option',
      valueType: 'option',
      className: styles.tableCol,
      render: (_, record) => {
        return (
          <Space direction="vertical">
            <Button
              type="link"
              size="small"
              onClick={() => {
                setFilterRulesTrue();
                setIsMasterModel(record.pid === '0');
              }}
            >
              过滤规则
            </Button>
            <Button
              type="link"
              size="small"
              onClick={() => {
                setSpecificFieldsOpenTrue();
                setIsMasterModel(record.pid === '0');
              }}
            >
              特征字段
            </Button>
          </Space>
        );
      },
    },
  ];

  function handleSearchSyncModel() {
    return request
      .getWMessage('/syndata/syncModel/getModelTargetTenantList', { id })
      .then((res) => {
        setItems(res.data || []);
        if (res.data?.length > 0) {
          const targetTenantId = res.data[0].id;
          setActiveKey(targetTenantId);
          getLeftTableData(targetTenantId);
        }
      });
  }
  function getLeftTableData(targetTenantId, selectKey, params) {
    setTrue();
    return request
      .getWMessage('/syndata/syncModel/getSyncModelData', {
        syncModeId: id,
        targetTenantId: targetTenantId || activeKey,
        ...pagination,
        ...params,
      })
      .then((res) => {
        setDataSource(res.data.list || []);
        setPagination({
          current: res.data.current,
          total: res.data.total,
          pageSize: res.data.pageSize,
        });
        if (selectKey) {
          setSelectedRowKeys(selectKey);
          return;
        }
        if (res.data.list?.length > 0) {
          const selectId = res.data.list[0].id;
          setSelectedRowKeys(selectId);
        } else {
          setMetaDataDataSource([]);
          setSelectedRowKeys('');
          setFalse();
        }
      })
      .catch(setFalse);
  }
  function handleSave(params) {
    return request
      .postWMessage('/syndata/syncModel/saveSyncModelData', {
        id: params.id,
        isShare: params.isShare,
      })
      .then(() => getLeftTableData(activeKey, params.id));
  }
  function setRowClassName(record) {
    return record.id === selectedRowKeys ? styles.rowStyle : '';
  }
  function onTabChange(key) {
    setSelectedRowKeys('');
    setActiveKey(key);
    getLeftTableData(key);
  }
  function onSelectChange(record) {
    setSelectedRowKeys(record.id);
    setIsMasterModel(record.pid === '0');
  }
  function handleTableChange(page) {
    const param = {
      current: page.current,
      pageSize: page.pageSize,
    };
    getLeftTableData(activeKey, null, param);
  }
  return (
    <>
      <Row gutter={[0, 24]} className={styles.tabContent}>
        <Col span={24}>
          <Tabs
            onChange={onTabChange}
            activeKey={activeKey}
            style={{ marginTop: '15px' }}
            className={styles.tabContent}
          >
            {items?.length > 0 &&
              items.map((item) => (
                <Tabs.TabPane key={item.id} tab={item.tenantryName} className="h-full">
                  <Spin spinning={loading} size="large">
                    <Row className="h-full">
                      <Col span={10} className={styles.leftColBorder}>
                        <Descriptions
                          column={1}
                          className="pt-2 pl-1"
                          labelStyle={{ fontSize: 16 }}
                        >
                          <Descriptions.Item label="同步业务" style={{ padding: 0 }}>
                            <a className="text-base">{businessModelName}</a>
                          </Descriptions.Item>
                        </Descriptions>
                        <Table
                          dataSource={dataSource}
                          columns={columns}
                          rowClassName={setRowClassName}
                          className="px-2 pt-2"
                          scroll={{ y: 360 }}
                          onChange={handleTableChange}
                          rowKey="id"
                          pagination={{
                            ...pagination,
                            showQuickJumper: true,
                            showSizeChanger: false,
                            showTotal: (total) => `共 ${total} 项`,
                          }}
                          size="small"
                          onRow={(record) => ({
                            onClick: () => {
                              onSelectChange(record);
                            },
                          })}
                        />
                      </Col>
                      <Col span={14} className={styles.rightColBorder}>
                        <MetaDataTable
                          setFalse={setFalse}
                          setTrue={setTrue}
                          dataModelId={selectedRowKeys}
                          setMetaDataDataSource={setMetaDataDataSource}
                          metaDataDataSource={metaDataDataSource}
                        />
                      </Col>
                    </Row>
                  </Spin>
                </Tabs.TabPane>
              ))}
          </Tabs>
        </Col>
      </Row>
      <FilterRulesDrawer
        open={filterRulesOpen}
        setFalse={setFilterRulesFalse}
        dataModelId={selectedRowKeys}
      />
      <SpecificFieldsDrawer
        isMasterModel={isMasterModel}
        open={specificFieldsOpen}
        setFalse={setSpecificFieldsOpenFalse}
        dataModelId={selectedRowKeys}
      />
    </>
  );
}
export default MetadataConfiguration;
