import { EditableProTable } from '@ant-design/pro-table';
import { FilterTypeMap } from '@/const/TenantType';
import { Button, Space } from 'antd';
import { useEffect, useState } from 'react';
import request from '@/utils/request';
import TitleStyle from '@/layouts/header/TitleStyle';

function RuleTable(props) {
  const { dataModelId, drawerActiveKey, title, filterConfigId } = props;
  const [dataSource, setDataSource] = useState([]);
  useEffect(() => {
    if (dataModelId) {
      fetchTableData();
    }
  }, [dataModelId, filterConfigId, drawerActiveKey]);
  const columns = [
    {
      title: '类型',
      dataIndex: 'filterType',
      key: 'filterType',
      width: 100,
      align: 'center',
      editable: false,
      render: (text) => FilterTypeMap[text],
    },
    {
      key: 'filterCondition',
      dataIndex: 'filterCondition',
      title: '条件',
      width: 200,
      align: 'center',
    },
    {
      title: '操作',
      align: 'center',
      width: 120,
      dataIndex: 'option',
      valueType: 'option',
      render: (text, record, _, action) => {
        return (
          <Button
            type="link"
            size="small"
            onClick={() => {
              action?.startEditable?.(record.id);
            }}
          >
            编辑
          </Button>
        );
      },
    },
  ];
  function fetchTableData() {
    return request
      .getWMessage('/syndata/syncModel/getSyncModelFilter', {
        id: dataModelId,
        status: drawerActiveKey,
        filterConfigId,
      })
      .then((res) => setDataSource(res.data));
  }
  function handleSave(_, reocrd) {
    return request
      .postWMessage('/syndata/syncModel/saveSyncModelFilter', {
        ...reocrd,
        filterConfigId,
        status: drawerActiveKey,
      })
      .then(fetchTableData);
  }
  return (
    <>
      <TitleStyle className="text-base">{title}</TitleStyle>
      <EditableProTable
        value={dataSource}
        columns={columns}
        toolBarRender={false}
        tableAlertRender={false}
        onChange={setDataSource}
        className="mt-2 mb-8"
        cardProps={{ bodyStyle: { padding: 0 } }}
        rowKey="id"
        editable={{
          type: 'multiple',
          onSave: handleSave,
          actionRender: (row, config, defaultDom) => [defaultDom.save, defaultDom.cancel],
        }}
        recordCreatorProps={false}
      />
    </>
  );
}
export default RuleTable;
