import { Button, Drawer, Space, Table } from 'antd';
import React, { useEffect, useState } from 'react';
import request from '@/utils/request';

function SpecificFieldsDrawer(props) {
  const { open, setFalse, dataModelId, isMasterModel } = props;
  const [selectedRowKeys, setSelectedRowKeys] = useState([]);
  const [dataSource, setDataSource] = useState([]);
  const columns = [
    {
      title: '字段代码',
      dataIndex: 'fieldCode',
      key: 'fieldCode',
      width: 100,
      editable: true,
      align: 'center',
    },
    {
      key: 'fieldMeaning',
      dataIndex: 'fieldMeaning',
      title: '字段含义',
      width: 200,
      align: 'center',
      editable: true,
    },
    {
      title: '数据类型',
      dataIndex: 'dataType',
      key: 'dataType',
    },
    {
      title: '字段长度',
      dataIndex: 'fieldLength',
      key: 'fieldLength',
    },
    {
      title: '小数位数',
      dataIndex: 'decimalDigits',
      key: 'decimalDigits',
      render: (text) => text || '-',
    },
  ];
  useEffect(() => {
    if (dataModelId) {
      fetchTableData();
    }
  }, [dataModelId]);
  function fetchTableData() {
    return request
      .getWMessage('/syndata/syncModel/getSyncModelFeature', { id: dataModelId })
      .then((res) => {
        setDataSource(res.data.dataModelHypertableList || []);
        setSelectedRowKeys(res.data.featureFields);
      });
  }
  function handleSave() {
    return request
      .postWMessage('/syndata/syncModel/saveSyncModelFeature', {
        featureFields: selectedRowKeys,
        syncModelDataId: dataModelId,
      })
      .then(() => {
        fetchTableData();
        setFalse();
      });
  }
  function handleCancel() {
    setFalse();
  }
  return (
    <Drawer
      title="特征字段"
      open={open}
      onClose={handleCancel}
      width={'45vw'}
      closeIcon
      footerStyle={{ textAlign: 'right' }}
      footer={
        <Space>
          <Button onClick={handleCancel}>取消</Button>
          <Button type="primary" onClick={handleSave}>
            保存
          </Button>
        </Space>
      }
    >
      {
        <span className="text-blue-6">
          {isMasterModel
            ? '用于确定命中租户特征值的元数据字段'
            : '用于确定关联主表主键的元数据字段'}
        </span>
      }

      <Table
        dataSource={dataSource}
        columns={columns}
        onChange={setDataSource}
        rowKey="fieldCode"
        className="mt-2"
        pagination={false}
        rowSelection={{
          selectedRowKeys,
          type: isMasterModel ? 'checkbox' : 'radio',
          onChange: (keys) => {
            setSelectedRowKeys(keys);
          },
        }}
      />
    </Drawer>
  );
}
export default SpecificFieldsDrawer;
