import { ManagePage, withManagePage } from '@/components/hoc/ManagePage';
import { Button, Card, Form, Modal, Popconfirm, Space } from 'antd';
import request from '@/utils/request';
import { searchItem, syncModelCol } from '@/pages/system/syncModel/SyncCommon';
import { sendStatus } from '@/const/TenantType';
import { Link, useHistory } from 'react-router-dom';
import FormBuilder from '@/components/forms/FormBuilder';
import { useBoolean } from 'ahooks';
import RemoteSelect from '@/components/forms/RemoteSelect';
import React from 'react';

function SyncModelConfig(props) {
  const history = useHistory();
  const [visible, { setTrue, setFalse }] = useBoolean(false);
  const formItemLayout = { labelCol: { span: 4 }, wrapperCol: { span: 20 } };
  const [form] = Form.useForm();
  const itemList = [
    {
      key: 'modelName',
      name: 'modelName',
      label: '模型名称',
      required: true,
      span: 24,
    },
    {
      name: 'businessModeId',
      key: 'businessModeId',
      label: '同步业务',
      component: RemoteSelect,
      required: true,
      componentProps: {
        requestUrl: '/syndata/dataModel/getBusinessModel',
        titleAttr: 'modelName',
        valueAttr: 'id',
        style: { width: '100%' },
      },
      span: 24,
    },
  ];
  const option = {
    title: '操作',
    width: 80,
    align: 'center',
    render: (_, record) => {
      return (
        <Space>
          <Button type="link" onClick={() => handleEdit(record)} size="small">
            {record.status === sendStatus.PUBLISHED ? '撤销' : '发布'}
          </Button>
          <Link to={`/system/syncModelEdit/${record.id}`}>编辑</Link>
          <Popconfirm title="确认删除吗?" onConfirm={() => handleDelete(record.id)}>
            <Button type="link" size="small">
              删除
            </Button>
          </Popconfirm>
        </Space>
      );
    },
  };

  function handleEdit(record) {
    const url =
      record.status === sendStatus.UNPUBLISHED
        ? '/syndata/syncModel/publishSyncModel'
        : '/syndata/syncModel/cancelSyncModel';
    request.postWMessage(url, { id: record.id }).then(() => {
      props.refreshTableData();
    });
  }
  function handleCancel() {
    form.resetFields();
    setFalse();
  }
  function handleDelete(deleteId) {
    request.deleteWMessage('/syndata/syncModel/deleteSyncModel', { id: deleteId }).then(() => {
      props.refreshTableData();
    });
  }
  function handleFormSubmit() {
    return form.validateFields().then((values) => {
      request.postWMessage('/syndata/syncModel/saveSyncModel', values).then((res) => {
        setFalse();
        form.resetFields();
        history.push(`/system/syncModelEdit/${res.data.id}`);
      });
    });
  }
  return (
    <Card
      title="同步模型配置"
      extra={
        <Button type="primary" onClick={setTrue}>
          新增
        </Button>
      }
    >
      <ManagePage
        tableColumns={syncModelCol.concat(option)}
        searchBarItemList={searchItem}
        number={4}
      />
      <Modal
        closeIcon
        title="创建同步模型"
        open={visible}
        onCancel={handleCancel}
        onOk={handleFormSubmit}
        centered
        width={700}
      >
        <Form form={form} {...formItemLayout}>
          <FormBuilder items={itemList} />
        </Form>
      </Modal>
    </Card>
  );
}

export default withManagePage(SyncModelConfig, '/syndata/syncModel/getSyncModel');
