import { Button, Card, Col, Form, message, Popconfirm, Row, Space, Steps, Switch } from 'antd';
import { useEffect, useState } from 'react';
import styles from '@/pages/system/syncModel/SyncModel.module.less';
import EvalToolbar from '@/components/evalBid/EvalToolbar';
import { useHistory, useParams } from 'react-router-dom';
import FormBuilder from '@/components/forms/FormBuilder';
import { EditableProTable } from '@ant-design/pro-table';
import request from '@/utils/request';
import { v4 as uuid } from 'uuid';
import RemoteSelect from '@/components/forms/RemoteSelect';
import MetadataConfiguration from '@/pages/system/syncModel/MetadataConfiguration';
import RemoteRadio from '@/components/forms/RemoteRadio';
import SelectSourceHost from '@/components/system/modelManagement/SelectSourceHost';

function SyncModelEdit() {
  const { id } = useParams();
  const [current, setCurrent] = useState(0);
  const formItemLayout = { labelCol: { span: 2 }, wrapperCol: { span: 22 } };
  const history = useHistory();
  const [form] = Form.useForm();
  const [editTableKeys, setEditTableKeys] = useState([]);
  const [dataSource, setDataSource] = useState([]);
  const [metaDataDataSource, setMetaDataDataSource] = useState([]);
  const [selectedRowKeys, setSelectedRowKeys] = useState();
  useEffect(() => {
    handleSearch();
    handleSearchForm();
  }, [id]);
  const itemList = [
    { name: 'dbName', label: 'dbName', visible: false },
    {
      key: 'modelName',
      name: 'modelName',
      label: '模型名称',
      required: true,
      span: 24,
    },
    {
      name: 'businessModelName',
      key: 'businessModelName',
      label: '同步业务',
      required: true,
      disabled: true,
      span: 24,
    },
    {
      name: 'tenantryId',
      key: 'tenantryId',
      label: '源租户',
      component: RemoteRadio,
      required: true,
      span: 24,
      componentProps: {
        requestUrl: '/syndata/tenantry/getTenantryList',
        titleAttr: 'tenantryName',
        valueAttr: 'id',
        onChange: (v) => {
          form.resetFields(['host']);
        },
      },
    },
    {
      key: 'host',
      name: 'host',
      label: '源主机',
      component: SelectSourceHost,
      rules: [{ required: true, message: '请选择源主机' }],
      componentProps: {
        form,
      },
      shouldUpdate: (prev, currentValue) => prev.tenantryId !== currentValue.tenantryId,
      shouldRender: ({ getFieldValue }) => getFieldValue('tenantryId'),
      span: 24,
    },
  ];
  const columns = [
    {
      title: <span className={styles.required}>目标租户</span>,
      dataIndex: 'tenantryUserType',
      key: 'tenantryUserType',
      width: 100,
      required: true,
      align: 'center',
      render: (_, record) => record.tenantTypeName,
      renderFormItem: () => (
        <RemoteSelect
          requestUrl="/system/dict/option"
          requestParam={{ dictType: 'YHLX' }}
          titleAttr="dictLabel"
          valueAttr="dictValue"
          style={{ width: '100%' }}
        />
      ),
    },
    {
      key: 'isTransactionCollaboration',
      dataIndex: 'isTransactionCollaboration',
      title: <span className={styles.required}>事务协同</span>,
      component: Switch,
      width: 80,
      align: 'center',
      componentProps: {
        unCheckedChildren: '否',
        checkedChildren: '是',
      },
      formItemProps: {
        valuePropName: 'checked',
        initialValue: false,
      },
      render: (text, record) => (
        <Switch
          checked={text}
          checkedChildren="是"
          unCheckedChildren="否"
          onChange={(state) => onSave(null, { ...record, isTransactionCollaboration: state })}
        />
      ),
      renderFormItem: (text) => (
        <Switch checked={text} checkedChildren="是" unCheckedChildren="否" />
      ),
    },
    {
      title: <span className={styles.required}>租户匹配规则</span>,
      dataIndex: 'tenantMatchingRule',
      key: 'tenantMatchingRule',
      width: 120,
      required: true,
      align: 'center',
    },
    {
      title: <span className={styles.required}>主机匹配规则</span>,
      dataIndex: 'hostMatchingRule',
      key: 'hostMatchingRule',
      width: 120,
      required: true,
      align: 'center',
    },
    {
      title: '操作',
      align: 'center',
      width: 100,
      dataIndex: 'option',
      valueType: 'option',
      render: (text, record, _, action) => {
        return (
          <Space>
            <Button
              type="link"
              size="small"
              onClick={() => {
                action?.startEditable?.(record.id);
              }}
            >
              编辑
            </Button>
            <Popconfirm title="确认删除吗?" onConfirm={() => handleDelete(record.id)}>
              <Button type="link" size="small">
                删除
              </Button>
            </Popconfirm>
          </Space>
        );
      },
    },
  ];
  function handleSearch() {
    return request.getWMessage('/syndata/syncModel/getModelTargetTenant', { id }).then((res) => {
      setDataSource(res.data || []);
    });
  }
  function handleSearchForm() {
    return request.getWMessage('/syndata/syncModel/getSyncModeById', { id }).then((res) => {
      const { data } = res;
      const host = { hostName: data.hostName, tenantryHostId: data.tenantryHostId };
      if (data?.hostName) {
        delete data.hostName;
      }
      if (data.tenantryHostId) {
        delete data.tenantryHostId;
      }
      form.setFieldsValue({ ...data, host: { ...host } });
    });
  }
  function handleDelete(deleteId) {
    request
      .deleteWMessage('/syndata/syncModel/deleteModelTargetTenant', { id: deleteId })
      .then(handleSearch);
  }
  function handleSave() {
    return form.validateFields().then((values) => {
      const param = { ...values.host };
      if (values.host) {
        delete values.host;
      }
      return request
        .postWMessage('/syndata/syncModel/saveSyncModel', {
          ...values,
          ...param,
          id,
        })
        .then(handleSearch);
    });
  }

  function nextSave() {
    if (dataSource?.length > 0) {
      return handleSave().then(() => setCurrent(current + 1));
    }
    message.error('请至少添加一条目标租户信息');
    return Promise.reject();
  }
  function onSave(_, data) {
    return request
      .postWMessage('/syndata/syncModel/saveModelTargetTenant', {
        ...data,
        syncModelId: id,
      })
      .then(handleSearch);
  }
  function handleSaveMetadata() {
    return request
      .postWMessage('/syndata/syncModel/saveSyncModelHypertable', {
        syncModelDataId: selectedRowKeys,
        metaData: metaDataDataSource,
      })
      .then(fetchTableData);
  }
  function handleRelease() {
    request
      .postWMessage('/syndata/syncModel/publishSyncModel', { id })
      .then(() => history.push('/system/syncModelConfig'));
  }
  function fetchTableData() {
    return request
      .getWMessage('/syndata/syncModel/getSyncModelHypertable', {
        id: selectedRowKeys.toString(),
        total: 0,
        current: 1,
        pagSize: 10,
      })
      .then((res) => {
        setMetaDataDataSource(res.data.list || []);
      });
  }
  return (
    <Row gutter={12} className="fullBox">
      {/*<Col span={current === 0 ? 18 : 24}>*/}
      <Col span={current === 24}>
        <Card
          title="同步模型配置"
          className={styles.configCard}
          bodyStyle={{ height: 'calc(80vh - 48px)', overflow: 'auto' }}
        >
          <Row gutter={[0, 24]} className={current === 0 ? 'm-12' : 'mb-2'} justify="center">
            <Col span={16}>
              <Steps current={current}>
                <Steps.Step title="基础配置" />
                <Steps.Step title="同步配置" />
              </Steps>
            </Col>
          </Row>
          {current === 0 && (
            <Row gutter={[0, 24]} className="mb-6">
              <Col span={24}>
                <Form form={form} {...formItemLayout}>
                  <FormBuilder items={itemList} />
                </Form>
              </Col>
              <Col span={24}>
                <Row gutter={24}>
                  {/*<Col span={8}>*/}
                  {/*  <EditableProTable*/}
                  {/*    value={sourceDataSource}*/}
                  {/*    columns={leftColumns}*/}
                  {/*    toolBarRender={false}*/}
                  {/*    cardProps={{ bodyStyle: { padding: 0 } }}*/}
                  {/*    tableAlertRender={false}*/}
                  {/*    recordCreatorProps={false}*/}
                  {/*    rowKey="tenantryUserType"*/}
                  {/*    onChange={setSourceDataSource}*/}
                  {/*    editable={{*/}
                  {/*      type: 'multiple',*/}
                  {/*      sourceEditTableKeys,*/}
                  {/*      onChange: setSourceEditTableKeys,*/}
                  {/*      actionRender: (row, config, defaultDom) => [*/}
                  {/*        defaultDom.save,*/}
                  {/*        defaultDom.cancel,*/}
                  {/*      ],*/}
                  {/*    }}*/}
                  {/*  />*/}
                  {/*</Col>*/}
                  <Col span={24}>
                    <EditableProTable
                      value={dataSource}
                      columns={columns}
                      toolBarRender={false}
                      tableAlertRender={false}
                      onChange={setDataSource}
                      cardProps={{ bodyStyle: { padding: 0 } }}
                      rowKey="id"
                      editable={{
                        type: 'multiple',
                        editTableKeys,
                        onChange: setEditTableKeys,
                        onSave,
                        onlyAddOneLineAlertMessage: '只能同时新增一行数据',
                        actionRender: (row, config, defaultDom) => [
                          defaultDom.save,
                          defaultDom.cancel,
                        ],
                      }}
                      recordCreatorProps={{
                        record: () => ({ id: uuid().replace(/-/g, '') }),
                        creatorButtonText: '添加目标租户',
                      }}
                    />
                  </Col>
                </Row>
              </Col>
            </Row>
          )}
          {current === 1 && (
            <MetadataConfiguration
              businessModelName={form.getFieldValue('businessModelName')}
              selectedRowKeys={selectedRowKeys}
              setSelectedRowKeys={setSelectedRowKeys}
              metaDataDataSource={metaDataDataSource}
              setMetaDataDataSource={setMetaDataDataSource}
            />
          )}
        </Card>
        <EvalToolbar>
          {current === 0 && (
            <Space>
              <Button onClick={history.goBack}>返回</Button>
              <Button onClick={handleSave}>保存</Button>
              <Button onClick={nextSave} type="primary">
                下一步
              </Button>
            </Space>
          )}
          {current === 1 && (
            <Space>
              <Button onClick={() => setCurrent(current - 1)}>上一步</Button>
              <Button onClick={handleSaveMetadata}>保存</Button>
              <Button onClick={() => handleSaveMetadata().then(handleRelease)} type="primary">
                发布
              </Button>
            </Space>
          )}
        </EvalToolbar>
      </Col>
      {/*{current === 0 && <SyncRightCol />}*/}
    </Row>
  );
}
export default SyncModelEdit;
