import { Button, Card, Form, Radio, Table } from 'antd';
import request from '@/utils/request';
import React, { useState } from 'react';
import dayjs from 'dayjs';
import RemoteSelect from '@/components/forms/RemoteSelect';
import {
  FunctionTypeDescriptionsMap,
  FunctionTypeMap,
  SyncOptionStatusColor,
  SyncOptionStatusName,
} from '@/pages/system/syncProcess/ProcessStatus';
import SearchBar from '@/components/forms/SearchBar';
import { useParams } from 'react-router-dom';
import { usePagination } from 'ahooks';

function ErrorLog() {
  const { id } = useParams();
  const [form] = Form.useForm();
  const searchBarItemList = [
    {
      name: 'dataModelId',
      key: 'dataModelId',
      label: '业务表',
      component: RemoteSelect,
      componentProps: {
        requestUrl: '/syndata/MonitorOverview/getErrorLogBusiness',
        titleAttr: 'modelName',
        requestParam: { id },
        valueAttr: 'id',
        style: { minWidth: 200 },
      },
    },
    {
      key: 'featureType',
      label: '同步类型',
      component: Radio.Group,
      componentProps: {
        options: [
          {
            label: '全部',
            value: '',
          },
          { value: '2', label: '全量迁移' },
          { value: '3', label: '增量同步' },
        ],
      },
    },
  ];
  const columns = [
    {
      title: '序号',
      dataIndex: 'index',
      width: 80,
      align: 'center',
      render: (text, record, index) => index + 1,
    },
    {
      title: '来源主机',
      dataIndex: 'hostName',
      key: 'hostName',
      width: 180,
      align: 'center',
    },
    {
      key: 'hostAddress',
      dataIndex: 'hostAddress',
      title: '目标主机地址',
      width: 100,
      align: 'center',
    },
    {
      title: '业务类型',
      dataIndex: 'businessModelName',
      key: 'businessModelName',
      width: 100,
      align: 'center',
    },
    {
      title: '业务表',
      dataIndex: 'tableName',
      key: 'tableName',
      width: 100,
      align: 'center',
    },
    {
      title: '同步类型',
      dataIndex: 'featureType',
      key: 'featureType',
      width: 100,
      align: 'center',
      render: (text) => FunctionTypeMap[text],
    },
    {
      key: 'dataModelId',
      dataIndex: 'dataModelId',
      title: '业务主键',
      width: 100,
      align: 'center',
      render: (text) => (
        <div style={{ wordWrap: 'break-word', wordBreak: 'break-all' }}>{text}</div>
      ),
    },
    {
      key: 'syncType',
      dataIndex: 'syncType',
      title: '操作类型',
      width: 100,
      align: 'center',
      render: (text) => (
        <span className={SyncOptionStatusColor[text]}>{SyncOptionStatusName[text]}</span>
      ),
    },
    {
      title: '同步时间',
      dataIndex: 'syncTime',
      key: 'syncTime',
      width: 100,
      align: 'center',
      render: (text) => (text ? dayjs(text).format('YYYY-MM-DD HH:mm') : '-'),
    },
    {
      title: '失败原因',
      dataIndex: 'errorCause',
      key: 'errorCause',
      width: 100,
      align: 'center',
      render: (text) => <span className="text-red-6">{text}</span>,
    },
    {
      title: '操作',
      align: 'center',
      width: 100,
      dataIndex: 'option',
      valueType: 'option',
      render: () => {
        return (
          <Button type="link" size="small" onClick={handleResend} disabled={true}>
            重新发送
          </Button>
        );
      },
    },
  ];
  const {
    data = { list: [] },
    run,
    pagination = {
      pageSize: 10,
    },
  } = usePagination(
    async (params) => {
      const res = await fetchTableData(params);
      const { list, total } = res.data || {};
      return { list, total };
    },
    {
      refreshDeps: [id],
    },
  );
  function handleResend() {}
  function handleBatchResend() {}
  function fetchTableData(params) {
    return request.getWMessage('/syndata/MonitorOverview/getListenDetailsErrorLog', {
      id,
      ...form.getFieldsValue(),
      ...params,
    });
  }
  function onSearch() {
    run({ ...form.getFieldsValue(), ...pagination });
  }
  function onChange(page, filters, sorter) {
    run({
      current: page.current,
      pageSize: page.pageSize,
      sortField: sorter.field,
      sortOrder: sorter.order,
      ...filters,
    });
  }

  return (
    <Card
      title="错误日志"
      extra={
        <Button onClick={handleBatchResend} type="primary" disabled={true}>
          批量重发
        </Button>
      }
    >
      <SearchBar onSearch={onSearch} itemList={searchBarItemList} form={form} />
      <Table
        rowKey="id"
        columns={columns}
        dataSource={data.list}
        onChange={onChange}
        pagination={{
          ...pagination,
          showQuickJumper: true,
          showSizeChanger: true,
          showTotal: (total) => `共 ${total} 项`,
        }}
      />
      {/*<ManagePage tableColumns={columns} searchBarItemList={searchBarItemList} />*/}
    </Card>
  );
}
export default ErrorLog;
