import { Button, Card, Tabs } from 'antd';
import { useHistory, useParams } from 'react-router-dom';
import React, { useEffect, useState } from 'react';
import { useBoolean } from 'ahooks';
import AddAHostDrawer from '@/components/system/syncModel/AddAHostDrawer';
import request from '@/utils/request';
import styles from '@/pages/system/syncModel/SyncModel.module.less';
import HostManageTable from '@/components/system/syncModel/HostManageTable';
import EvalToolbar from '@/components/evalBid/EvalToolbar';

function HostMaintenance() {
  const { id } = useParams();
  const history = useHistory();
  const [visible, { setTrue, setFalse }] = useBoolean(false);
  const [activeKey, setActiveKey] = useState('');
  const [items, setItems] = useState([]);

  const [dataSource, setDataSource] = useState([]);

  useEffect(() => handleSearchSyncModel(), [id]);
  function handleSearchSyncModel() {
    return request.getWMessage('/syndata/syncTask/getModelTargetTenantList', { id }).then((res) => {
      setItems(res.data || []);
      if (res.data?.length > 0) {
        const targetTenantId = res.data[0].id;
        setActiveKey(targetTenantId);
      }
    });
  }
  function onTabChange(tabKey) {
    setActiveKey(tabKey);
  }
  function fetchTableData(syncModelTargetTenantId) {
    request
      .getWMessage('/syndata/syncTask/getSyncTaskHostList', {
        id,
        syncModelTargetTenantId: syncModelTargetTenantId || activeKey,
      })
      .then((res) => {
        setDataSource(res.data);
      });
  }
  return (
    <Card
      title="主机维护"
      extra={
        <Button type="primary" onClick={setTrue}>
          添加主机
        </Button>
      }
    >
      {items?.length > 0 && (
        <Tabs
          onChange={onTabChange}
          activeKey={activeKey}
          className={styles.tabContent}
          items={items.map((item) => ({
            key: item.id,
            label: item.tenantryName,
            children: (
              <HostManageTable
                activeKey={activeKey}
                dataSource={dataSource}
                fetchTableData={fetchTableData}
              />
            ),
          }))}
        />
      )}
      <AddAHostDrawer
        isMaintenance
        drawerVisible={visible}
        id={id}
        setFalse={setFalse}
        activeKey={activeKey}
        fetchTableData={fetchTableData}
        requestUrl="/syndata/syncTask/getUnselectedHostList"
        postUrl="/syndata/syncTask/saveSyncTaskHostDynamic"
      />
      <EvalToolbar>
        <Button onClick={() => history.goBack()}>返回</Button>
      </EvalToolbar>
    </Card>
  );
}
export default HostMaintenance;
