import React, { useEffect, useState } from 'react';
import request from '@/utils/request';
import { Card, Col, Divider, Row, Space } from 'antd';
import styles from '@/pages/system/syncProcess/logDetail.module.less';
import TitleStyle from '@/layouts/header/TitleStyle';
import { DoubleRightOutlined } from '@ant-design/icons';
import SourceBusinessBarChart from '@/components/system/SourceBusinessBarChart';
import classnames from 'classnames';
import LogAreaChart from '@/components/system/LogAreaChart';
import HitTheTenantHistogram from '@/components/system/HitTheTenantHistogram';
import { Link } from 'react-router-dom';

function LogDetails() {
  const [sourceAndHost, setSourceAndHost] = useState({});
  const [hostHitsNum, setHostHitsNum] = useState({});
  useEffect(() => fetchData(), []);
  function fetchData() {
    return Promise.all([getSourceAndHost(), getHostHitsNum()]).then(([res1, res2]) => {
      setSourceAndHost(res1.data);
      setHostHitsNum(res2.data);
    });
  }
  function getSourceAndHost() {
    return request.getWMessage('/syndata/syncTaskLogDetails/getSourceAndHost');
  }
  function getHostHitsNum() {
    return request.getWMessage('/syndata/syncTaskLogDetails/getHostHitsNum');
  }
  return (
    <Card
      title="日志总览"
      bodyStyle={{ paddingTop: '4px' }}
      extra={
        <Link to={'/system/LogDetailsInfo'}>
          详情
          <DoubleRightOutlined />
        </Link>
      }
    >
      <div className={styles.box}>
        <Row gutter={12} className="mt-4">
          <Col span={12}>
            <Card className={classnames(styles.cardStyle, styles.sourceTenantBackground)}>
              <Card.Meta title={<h3 className="font-bold">源租户监听日志</h3>} />
              <Row>
                <Col span={16} className="h-full">
                  <Row justify="center">
                    <Col span={7}>
                      <Space direction="vertical" align="center" className="font-bold text-blue-6">
                        <span>{sourceAndHost.totalCount}</span>
                        <span style={{ color: '#0066FF' }}>累计监听(条)</span>
                      </Space>
                    </Col>
                    <Col span={1}>
                      <Divider type="vertical" style={{ height: '32px' }} />
                    </Col>
                    <Col span={7}>
                      <Space
                        direction="vertical"
                        align="center"
                        className="font-bold"
                        style={{ color: '#39AB7E' }}
                      >
                        <span>{sourceAndHost.monthCount}</span>
                        <span>本月监听(条)</span>
                      </Space>
                    </Col>
                    <Col span={1}>
                      <Divider type="vertical" style={{ height: '32px' }} />
                    </Col>
                    <Col span={8}>
                      <Space direction="vertical" align="center">
                        <span className="font-bold">{sourceAndHost.todayCount}</span>
                        <span className="font-bold">今日监听</span>
                      </Space>
                    </Col>
                  </Row>
                </Col>
              </Row>
            </Card>
          </Col>
          <Col span={12}>
            <Card className={classnames(styles.cardStyle, styles.hostLogBackground)}>
              <Card.Meta title={<h3 className="font-bold">主机命中日志</h3>} />
              <Row>
                <Col span={16} className="h-full">
                  <Row justify="center">
                    <Col span={7}>
                      <Space direction="vertical" align="center" className="font-bold text-blue-6">
                        <span>{hostHitsNum.totalCount || 0}</span>
                        <span>累计命中(条)</span>
                      </Space>
                    </Col>
                    <Col span={1}>
                      <Divider type="vertical" style={{ height: '48px' }} />
                    </Col>
                    <Col span={7}>
                      <Space
                        direction="vertical"
                        align="center"
                        className="font-bold text-orange-6"
                      >
                        <span>{hostHitsNum.totalErrorCount}</span>
                        <span>异常记录(条)</span>
                      </Space>
                    </Col>
                    <Col span={1}>
                      <Divider type="vertical" style={{ height: '48px' }} />
                    </Col>
                    <Col span={8}>
                      <Space direction="vertical" align="center" className="font-bold text-red-6">
                        <span className="font-bold">{hostHitsNum.todayErrorCount}</span>
                        <span className="font-bold">今日异常(条)</span>
                      </Space>
                    </Col>
                  </Row>
                </Col>
              </Row>
            </Card>
          </Col>
        </Row>
        <div className={styles.logChart}>
          <Row className="h-full" align="center">
            <Col span={23}>
              <LogAreaChart />
            </Col>
          </Row>
        </div>
        <div className={styles.sourceBusiness}>
          <Row className="h-full" gutter={24}>
            <Col span={12}>
              <div className="h-8 mb-2">
                <TitleStyle>来源业务</TitleStyle>
              </div>
              <div style={{ height: '92%' }}>
                <SourceBusinessBarChart />
              </div>
            </Col>
            <Col span={12}>
              <div className="h-8 mb-2">
                <TitleStyle>命中租户</TitleStyle>
              </div>
              <div style={{ height: '92%' }}>
                <HitTheTenantHistogram />
              </div>
            </Col>
          </Row>
        </div>
      </div>
    </Card>
  );
}

export default LogDetails;
