import { Button, Card, Select } from 'antd';
import { ManagePage, withManagePage } from '@/components/hoc/ManagePage';
import { logDetailsInfoCol } from '@/components/system/LogDetailsInfoCol';
import RemoteSelect from '@/components/forms/RemoteSelect';
import { syncOption, SyncStatus, syncStatusOption } from '@/pages/system/syncProcess/ProcessStatus';
import RangePickerString from '@/components/forms/RangePickerString';
import React, { useState } from 'react';
import { useBoolean } from 'ahooks';
import LogDetailDrawer from '@/components/system/syncModel/LogDetailDrawer';
import SynchronizationDetailsDrawer from '@/components/system/syncModel/SynchronizationDetailsDrawer';
import LogClearModal from '@/components/system/syncModel/LogClearModal';
import { ClearOutlined } from '@ant-design/icons';
import request from '@/utils/request';

function LogDetailsInfo({ refreshTableData }) {
  const [drawerVisible, { setTrue, setFalse }] = useBoolean(false);
  const [
    synchronizationVisible,
    { setTrue: setSynchronizationVisibleTrue, setFalse: setSynchronizationVisibleFalse },
  ] = useBoolean(false);
  const [content, setContent] = useState();
  const [businessId, setBusinessId] = useState();
  const [syncRecordsId, setSyncRecordsId] = useState();
  const [clearVisible, { setTrue: setClearVisibleTrue, setFalse: setClearVisibleFalse }] =
    useBoolean(false);
  const option = [
    {
      title: '同步情况',
      width: 80,
      align: 'center',
      dataIndex: 'allNum',
      key: 'allNum',
      render: (text, record) => {
        let spanColor = 'text-orange-6';
        if (record.successNum === '0') {
          spanColor = 'text-red-6';
        }
        if (record.successNum === text) {
          spanColor = 'text-green-6';
        }
        return (
          <Button
            className={spanColor}
            onClick={() => handleClick(record.businessId, record.syncRecordsId)}
            type="text"
          >
            {record.successNum} / {text}
          </Button>
        );
      },
    },
    {
      title: '操作',
      align: 'center',
      width: 100,
      dataIndex: 'option',
      valueType: 'option',
      render: (_, record) => {
        return (
          <Button type="link" size="small" onClick={() => handleOptionClick(record.syncSql)}>
            日志明细
          </Button>
        );
      },
    },
  ];
  const searchBarItem = [
    {
      name: 'keyword',
      key: 'keyword',
      label: '模糊搜索',
      componentProps: { placeholder: '主机名/业务主键', width: 200 },
    },
    {
      name: 'tenantryUserType',
      key: 'tenantryUserType',
      label: '源租户',
      component: RemoteSelect,
      componentProps: {
        allowClear: true,
        placeholder: '请选择',
        requestUrl: '/system/dict/option',
        requestParam: { dictType: 'YHLX' },
        showSearch: true,
        optionFilterProp: 'label',
        titleAttr: 'dictLabel',
        valueAttr: 'dictValue',
        style: { width: 200 },
      },
    },
    {
      name: 'business',
      key: 'business',
      label: '业务类型',
      component: RemoteSelect,
      componentProps: {
        requestUrl: '/syndata/dataModel/getBusinessModel',
        titleAttr: 'modelName',
        valueAttr: 'id',
        optionFilterProp: 'label',
        showSearch: true,
        style: { minWidth: 200 },
      },
    },
    {
      name: 'modelId',
      key: 'modelId',
      label: '数据模型',
      component: RemoteSelect,
      componentProps: {
        requestUrl: '/syndata/syncTaskLogDetails/getDataModelList',
        optionFilterProp: 'label',
        titleAttr: 'modelName',
        valueAttr: 'id',
        showSearch: true,
        style: { minWidth: 200 },
      },
    },
    {
      name: 'operateType',
      key: 'operateType',
      label: '操作类型',
      component: Select,
      componentProps: {
        style: { minWidth: 200 },
        options: syncOption,
      },
    },
    {
      name: 'state',
      key: 'state',
      label: '同步状态',
      component: Select,
      componentProps: {
        style: { minWidth: 200 },
        options: syncStatusOption.filter((i) => i.value !== SyncStatus.TO_COMPILED),
      },
    },
    {
      key: 'dateRangeArray',
      label: '时间范围',
      component: RangePickerString,
      componentProps: {
        allowClear: true,
        allowEmpty: [true, true],
      },
    },
  ];
  function handleClick(currentBusinessId, currentSyncRecordsId) {
    setBusinessId(currentBusinessId);
    setSyncRecordsId(currentSyncRecordsId);
    setSynchronizationVisibleTrue();
  }
  function handleOptionClick(syncSqlContent) {
    setContent(syncSqlContent);
    setTrue();
  }
  function handleClear() {
    request.getWMessage('/log/logClear/queryExportStatus').then(() => {
      setClearVisibleTrue();
    });
  }

  return (
    <Card
      title="日志详情"
      extra={
        <Button onClick={handleClear}>
          <ClearOutlined />
          日志清理
        </Button>
      }
    >
      <ManagePage
        tableColumns={logDetailsInfoCol.concat(option)}
        searchBarItemList={searchBarItem}
        number={3}
        rowKey="businessId"
      />
      <LogDetailDrawer visible={drawerVisible} content={content} setFalse={setFalse} />
      <SynchronizationDetailsDrawer
        visible={synchronizationVisible}
        id={businessId}
        syncRecordsId={syncRecordsId}
        setFalse={setSynchronizationVisibleFalse}
      />
      <LogClearModal
        visible={clearVisible}
        setFalse={setClearVisibleFalse}
        refreshTableData={refreshTableData}
      />
    </Card>
  );
}
export default withManagePage(LogDetailsInfo, '/syndata/syncTaskLogDetails/getSourceTenantDetails');
