import { Badge, Button, Col, Drawer, Row, Space, Table, Tabs } from 'antd';
import dataBase from '@/pages/system/syncProcess/img/dataBase.JPG';
import React, { useEffect, useState } from 'react';
import {
  FunctionType,
  RunStatusMap,
  TaskStatusColor,
  TaskStatusName,
} from '@/pages/system/syncProcess/ProcessStatus';
import styles from '@/pages/system/syncProcess/SyncProcessStyle.module.less';
import { ExclamationCircleFilled } from '@ant-design/icons';
import dayjs from 'dayjs';
import { Link, useParams } from 'react-router-dom';
import request from '@/utils/request';
import { TenantUserTypeMap } from '@/const/TenantType';

function MonitorDetails(props) {
  const { id } = useParams();
  const { open, setFalse, syncModelTargetTenantId, tenantryUserType } = props;
  const [activeKey, setActiveKey] = useState(FunctionType.STRUCTURE);
  const [dataSource, setDataSource] = useState([]);
  const [runStatus, setRunStatus] = useState([]);
  const [hostDataSource, setHostDataSource] = useState([]);
  const [items, setItems] = useState([]);
  const [selectedRowKeys, setSelectedRowKeys] = useState();
  const publicColumns = [
    {
      title: '序号',
      dataIndex: 'index',
      key: 'index',
      width: 80,
      align: 'center',
      render: (text, record, index) => index + 1,
    },
    {
      title: '业务表',
      dataIndex: 'tableName',
      key: 'tableName',
      width: 100,
      align: 'center',
    },
  ];
  const executeResult = {
    title: '执行结果',
    dataIndex: 'executionResult',
    key: 'executionResult',
    width: 80,
    align: 'center',
    render: (text, record) => (
      <span className={TaskStatusColor[record.executionResult]}>{TaskStatusName[text]}</span>
    ),
  };
  const endTime = {
    title: '结束时间',
    align: 'center',
    dataIndex: 'syncTime',
    key: 'syncTime',
    width: 100,
    render: (text) => (text ? dayjs(text).format('YYYY-MM-DD HH:mm') : '-'),
  };
  const lastTime = {
    title: '最后执行时间',
    align: 'center',
    dataIndex: 'syncTime',
    key: 'syncTime',
    width: 110,
    render: (text) => (text ? dayjs(text).format('YYYY-MM-DD HH:mm') : '-'),
  };
  const abnormalIllustrate = {
    title: '异常说明',
    dataIndex: 'exceptionDeclaration',
    key: 'exceptionDeclaration',
    width: 120,
    align: 'center',
    render: (text, record) =>
      record.executeStatus ? <span className="text-red-6">{text}</span> : '-',
  };
  const option = {
    title: '操作',
    width: 80,
    align: 'center',
    render: (_, record) => {
      if (activeKey === FunctionType.STRUCTURE) {
        return record.executeStatus === '0' ? (
          <Button type="link" onClick={() => console.log(record)} size="small" disabled={true}>
            重新迁移
          </Button>
        ) : (
          '-'
        );
      }
      if (record.executeStatus === '0') {
        return (
          <Button type="link" onClick={() => console.log(record)} size="small" disabled={true}>
            重启
          </Button>
        );
      }
      if (record.executeStatus === '1') {
        return (
          <Button type="link" onClick={() => console.log(record)} size="small" disabled={true}>
            暂停
          </Button>
        );
      }
      return (
        <Button type="link" onClick={() => console.log(record)} size="small" disabled={true}>
          恢复
        </Button>
      );
    },
  };
  const notSynchronized = {
    title: '待同步',
    width: 80,
    align: 'center',
    dataIndex: 'toBeSynchronized',
    key: 'toBeSynchronized',
    render: (text) => <span className="text-blue-6">{text}</span>,
  };
  const accumulateSync = {
    title: '累计同步',
    width: 80,
    align: 'center',
    dataIndex: 'toBeSynchronized',
    key: 'toBeSynchronized',
    render: (text) => <span className="text-blue-6">{text}</span>,
  };
  const synchronized = {
    title: '已同步',
    width: 80,
    align: 'center',
    dataIndex: 'alreadySynchronized',
    key: 'alreadySynchronized',
    render: (text) => <span className="text-green-6">{text}</span>,
  };
  const todaySync = {
    title: '同步成功',
    width: 80,
    align: 'center',
    dataIndex: 'alreadySynchronized',
    key: 'alreadySynchronized',
    render: (text) => <span className="text-green-6">{text}</span>,
  };
  const migrateCol = [
    {
      title: '失败',
      width: 80,
      align: 'center',
      dataIndex: 'numberOfFailures',
      key: 'numberOfFailures',
      render: (text) => (
        <Link
          to={`/system/syncProcessManage/errorLog/${selectedRowKeys}`}
          className="text-red-6"
          target="_blank"
        >
          {text}
        </Link>
      ),
    },
    {
      title: '状态',
      width: 80,
      align: 'center',
      dataIndex: 'synchronized',
      key: 'synchronized',
      render: (text) => <span color="success">{text}</span>,
    },
  ];
  useEffect(() => {
    getDetails();
  }, [id, syncModelTargetTenantId, open]);
  function getCol() {
    if (activeKey === FunctionType.STRUCTURE) {
      return [executeResult, endTime, abnormalIllustrate, option];
    }
    if (activeKey === FunctionType.COMPLETE) {
      return [notSynchronized, synchronized, ...migrateCol, endTime, option];
    }
    return [accumulateSync, todaySync, ...migrateCol, lastTime, option];
  }

  function onTabChange(tabKey) {
    setActiveKey(tabKey);
    fetchTableData(selectedRowKeys, tabKey);
  }
  function onSelectChange(record) {
    setSelectedRowKeys(record.id);
    fetchTableData(record.id, activeKey);
    fetchSyncData(record.id);
  }
  function setRowClassName(record) {
    return record.id === selectedRowKeys ? styles.clickStyle : '';
  }
  function getListeningDetail() {
    return request
      .getWMessage('/syndata/MonitorOverview/getListeningDetailNum', {
        id,
        syncModelTargetTenantId,
      })
      .then((res) => {
        const { data } = res;
        const runStatusMap = Object.entries(data).map(([key, value]) => ({
          key,
          value,
        }));
        setRunStatus(runStatusMap);
      });
  }
  function getHostList() {
    return request
      .getWMessage('/syndata/MonitorOverview/getSyncTaskHostData', {
        id,
        syncModelTargetTenantId,
      })
      .then((res) => {
        setHostDataSource(res.data);
        const { data } = res;
        if (data?.length > 0) {
          setSelectedRowKeys(data[0].id);
          fetchSyncData(data[0].id);
        }
      });
  }
  function fetchSyncData(selectedId) {
    const currentId = selectedId || selectedRowKeys;
    return request
      .getWMessage('/syndata/MonitorOverview/getFunctionalType', {
        id: currentId,
      })
      .then((res) => {
        const { data } = res;
        setItems(data);
        if (data?.length > 0) {
          setActiveKey(data[0].featureType);
          fetchTableData(currentId, data[0].featureType);
        }
      });
  }
  function fetchTableData(selectedId, currentKey) {
    return request
      .getWMessage('/syndata/MonitorOverview/getMonitorDetailData', {
        id: selectedId || selectedRowKeys,
        featureType: currentKey || activeKey,
      })
      .then((res) => {
        setDataSource(res.data);
      });
  }
  function getDetails() {
    if (id && syncModelTargetTenantId) {
      return Promise.all[(getListeningDetail(), getHostList())];
    }
  }
  return (
    <Drawer
      title={`${TenantUserTypeMap[tenantryUserType]}监听详情`}
      open={open}
      onClose={setFalse}
      width="65vw"
      closeIcon
      footerStyle={{ textAlign: 'right' }}
      footer={
        <Space>
          <Button onClick={setFalse}>取消</Button>
          <Button type="primary" onClick={setFalse}>
            确定
          </Button>
        </Space>
      }
    >
      <Row className="w-2/3">
        {runStatus.map((i) => (
          <Col flex={2} key={i.key}>
            <Space>
              <input type="image" alt="" src={dataBase} className="w-10" />
              <Badge count={i.value} offset={[12, -5]} color="volcano">
                <span className="font-bold">{RunStatusMap[i.key]}</span>
              </Badge>
            </Space>
          </Col>
        ))}
      </Row>
      <Row className={styles.rowStyle}>
        <Col flex={4} className={styles.colBorder}>
          <Table
            dataSource={hostDataSource}
            bordered
            rowClassName={setRowClassName}
            columns={[
              {
                title: '主机名称',
                dataIndex: 'id',
                key: 'id',
                width: 120,
                render: (text, record) => {
                  return (
                    <>
                      {record.abnormalState ? (
                        <Row>
                          <Col flex={20}> {record.hostName}</Col>
                          <Col flex={4}>
                            <ExclamationCircleFilled className="text-orange-6 text-xl" />
                          </Col>
                        </Row>
                      ) : (
                        record.hostName
                      )}
                    </>
                  );
                },
              },
            ]}
            style={{ padding: '5px' }}
            pagination={false}
            rowKey="id"
            onRow={(record) => ({
              onClick: () => {
                onSelectChange(record);
              },
            })}
          />
        </Col>
        <Col flex={20}>
          <Tabs onChange={onTabChange} activeKey={activeKey} style={{ padding: '5px' }}>
            {items.map((item) => (
              <Tabs.TabPane
                key={item.featureType}
                tab={`${item.featureTypeName}(${item.successfulQuantity}/${item.grossAmount})`}
              >
                <Table
                  dataSource={dataSource}
                  columns={publicColumns.concat(getCol())}
                  rowKey="id"
                />
              </Tabs.TabPane>
            ))}
          </Tabs>
        </Col>
      </Row>
    </Drawer>
  );
}
export default MonitorDetails;
