export enum ProcessStatus {
  NOT_START = '0',
  IN_PROCESS = '1',
  SUCCEED = '2',
}
export enum SyncStatus {
  TO_COMPILED = 0, //待编
  SUCCESS = 1, //正常
  ERROR = -1, //失败
}
export enum SyncOptionStatus {
  TO_ADD = 1, //新增
  TO_UPDATE = 2, //更新
  TO_DELETE = 3, //删除
  RESEARCH = 4, //刷新
  BACKTRACK = 5, //回溯
}
export enum FunctionType {
  NOT_START = '0',
  STRUCTURE = '1',
  COMPLETE = '2',
  INCREMENT = '3',
}
export enum CheckRules {
  NOT_OPEN = '0',
  INITIAL = '1',
  REAL_TIME = '2',
}
export enum TaskStatus {
  ERROR = '0',
  SUCCESS = '1',
  IN_PROGRESS = '2',
  END = '3',
  STOP = '3',
}
export const TaskStatusColor = {
  [TaskStatus.SUCCESS]: 'text-green-6',
  [TaskStatus.ERROR]: 'text-red-6',
  [TaskStatus.IN_PROGRESS]: 'text-blue-6',
  [TaskStatus.END]: 'text-green-6',
  [TaskStatus.STOP]: 'text-orange-6',
};
export const SyncOptionStatusColor = {
  [SyncOptionStatus.TO_ADD]: 'text-green-6',
  [SyncOptionStatus.TO_UPDATE]: 'text-blue-6',
  [SyncOptionStatus.TO_DELETE]: 'text-red-6',
  [SyncOptionStatus.RESEARCH]: 'text-blue-6',
  [SyncOptionStatus.BACKTRACK]: 'text-blue-6',
};
export const TaskStatusName = {
  [TaskStatus.SUCCESS]: '成功',
  [TaskStatus.ERROR]: '失败',
  [TaskStatus.IN_PROGRESS]: '待执行',
  [TaskStatus.END]: '已结束',
  [TaskStatus.STOP]: '暂停',
};
export const SyncOptionStatusName = {
  [SyncOptionStatus.TO_ADD]: '新增',
  [SyncOptionStatus.TO_UPDATE]: '更新',
  [SyncOptionStatus.TO_DELETE]: '删除',
  [SyncOptionStatus.RESEARCH]: '刷新',
  [SyncOptionStatus.BACKTRACK]: '回溯',
};
export enum TabKey {
  MONITOR = 'monitor',
  TENANT = 'tenant',
}

export const MissionDetailsName = {
  [TabKey.MONITOR]: '监听总览',
  [TabKey.TENANT]: '租户列表',
};
export enum HostKey {
  ALL = '0',
  SOME = '1',
  ADD = '2',
}
export enum RunStatus {
  NORMAL = 'normalOperation',
  DOWN = 'runDown',
  EXCEPTION = 'runningException',
}
export const RunStatusMap = {
  [RunStatus.NORMAL]: '运行正常',
  [RunStatus.DOWN]: '运行停止',
  [RunStatus.EXCEPTION]: '运行异常',
};
export const ProcessStatusMap = {
  [ProcessStatus.NOT_START]: '未开始',
  [ProcessStatus.IN_PROCESS]: '执行中',
  [ProcessStatus.SUCCEED]: '已完成',
};
export const SyncStatusMap = {
  [SyncStatus.SUCCESS]: '正常',
  [SyncStatus.TO_COMPILED]: '待编',
  [SyncStatus.ERROR]: '异常',
};
export const ProcessStatusPercent = {
  [ProcessStatus.NOT_START]: 0,
  [ProcessStatus.IN_PROCESS]: 60,
  [ProcessStatus.SUCCEED]: 100,
};
export const CheckRulesMap = {
  [CheckRules.NOT_OPEN]: '不开启校验',
  [CheckRules.INITIAL]: '初始校验',
  [CheckRules.REAL_TIME]: '实时校验',
};
export const FunctionTypeMap = {
  [FunctionType.NOT_START]: '任务初始化',
  [FunctionType.STRUCTURE]: '结构迁移',
  [FunctionType.COMPLETE]: '全量迁移',
  [FunctionType.INCREMENT]: '增量同步',
};
export const FunctionTypeDescriptionsMap = {
  [FunctionType.STRUCTURE]: '根据源租户同步业务的元数据在目标租户主机库中创建相同的表结构',
  [FunctionType.COMPLETE]: '根据匹配规则和过滤规则将数据全量初始化到命中的租户主机业务表中',
  [FunctionType.INCREMENT]: '根据匹配规则和过滤规则将数据全量初始化到命中的租户主机业务表中',
};
export const CheckRuleDescriptionsMap = {
  [CheckRules.NOT_OPEN]: '全量迁移、增量迁移时都不对数据进行校验',
  [CheckRules.INITIAL]: '仅对全量迁移的数据进行校验',
  [CheckRules.REAL_TIME]: '对全量迁移、增量迁移的数据都进行校验',
};
export const FunctionTypeOptions = Object.entries(FunctionTypeMap).map(([value, label]) => ({
  value,
  label,
}));
export const CheckRulesOptions = Object.entries(CheckRulesMap).map(([value, label]) => ({
  value,
  label,
}));
export const syncStatusOption = Object.entries(SyncStatusMap).map(([value, label]) => ({
  value: parseInt(value),
  label,
}));
export const syncOption = Object.entries(SyncOptionStatusName).map(([value, label]) => ({
  value,
  label,
}));
