import { Button, Drawer, Form, Radio, Space, Table, Tabs } from 'antd';
import React, { useEffect, useState } from 'react';
import request from '@/utils/request';
import { useParams } from 'react-router-dom';
import { HostKey } from '@/pages/system/syncProcess/ProcessStatus';
import ReSyncHost from '@/pages/system/syncProcess/ReSyncHost';

function ReSyncProtects(props) {
  const { id } = useParams();
  const { open, setFalse } = props;
  const [drawerActiveKey, setDrawerActiveKey] = useState('');
  const [form] = Form.useForm();
  const [drawerItems, setDrawerItems] = useState([]);
  const [type, setType] = useState(HostKey.SOME);
  const [info, setInfo] = useState([]);
  useEffect(() => handleSearchSyncModel(), [id]);
  function handleSave() {
    return form.validateFields().then((values) => {
      const selectedIds = info.map((i) => i.selectedTenantryHostList);
      const params = {
        ...values,
        id,
        ids: selectedIds.flat(),
      };
      request
        .postWMessage('/syndata/MonitorOverview/saveTenanTypeInformation', params)
        .then(() => {
          handleSearchSyncModel();
        })
        .finally(() => {
          setFalse();
          form.resetFields();
        });
    });
  }
  function onTabChange(tabKey) {
    setDrawerActiveKey(tabKey);
  }
  function handleSearchSyncModel() {
    return request
      .getWMessage('/syndata/MonitorOverview/getTenanTypeInformation', { id })
      .then((res) => {
        const { syncModelTargetTenantVOList, taskType } = res.data;
        setDrawerItems(syncModelTargetTenantVOList || []);
        if (syncModelTargetTenantVOList?.length > 0) {
          const targetTenantId = syncModelTargetTenantVOList[0].id;
          setDrawerActiveKey(targetTenantId);
          const infoList = syncModelTargetTenantVOList.map((i) => ({
            id: i.id,
            taskHostNum: i.taskHostNum,
            selectedTenantryHostList: [...i.selectedTenantryHostList],
            tenantryHostList: [...i.tenantryHostList],
          }));
          setInfo(infoList);
        }
        if (taskType) {
          form.setFieldValue('taskType', taskType);
          setType(taskType);
        }
      });
  }
  function changeMethod(e) {
    const { value } = e.target;
    setType(value);
  }
  return (
    <Drawer
      title="重新同步"
      open={open}
      onClose={setFalse}
      width="45vw"
      closeIcon
      footerStyle={{ textAlign: 'right' }}
      footer={
        <Space>
          <Button onClick={setFalse}>取消</Button>
          <Button type="primary" onClick={handleSave}>
            确定
          </Button>
        </Space>
      }
    >
      <Form form={form}>
        <Form.Item
          label="同步类型"
          name="taskType"
          rules={[{ required: true, message: '请选择同步类型' }]}
          initialValue={HostKey.SOME}
        >
          <Radio.Group onChange={changeMethod}>
            <Radio value={HostKey.SOME}>特定租户特定主机</Radio>
            <Radio value={HostKey.ADD}>全部新增主机</Radio>
            <Radio value={HostKey.ALL}>全部租户全部主机</Radio>
          </Radio.Group>
        </Form.Item>
      </Form>
      {type === HostKey.SOME && info.length > 0 && (
        <Tabs onChange={onTabChange} activeKey={drawerActiveKey} style={{ marginTop: '15px' }}>
          {drawerItems.map((item) => {
            return (
              <Tabs.TabPane
                key={item.id}
                tab={`${item.tenantryName}(${info.filter((i) => i.id === item.id)[0].taskHostNum})`}
              >
                <ReSyncHost setInfo={setInfo} info={info} drawerActiveKey={drawerActiveKey} />
              </Tabs.TabPane>
            );
          })}
        </Tabs>
      )}
    </Drawer>
  );
}
export default ReSyncProtects;
