import { FlowAnalysisGraph } from '@ant-design/graphs';
import React, { useEffect, useState } from 'react';
import { useParams } from 'react-router-dom';
import request from '@/utils/request';
import sync from '@/pages/system/syncProcess/img/sync.JPG';
import success from '@/pages/system/syncProcess/img/success.JPG';
import error from '@/pages/system/syncProcess/img/error.JPG';

function SourceAndDestinationChart() {
  const { id } = useParams();
  const [nodeData, setNodeData] = useState();
  const [innerWidth, setInnerWidth] = useState();
  const [edgesData, setEdgesData] = useState();

  const config = {
    data: {
      nodes: nodeData,
      edges: edgesData,
    },
    layout: {
      rankdir: 'TB',
      ranksepFunc: () => 10,
      nodesepFunc: () => 10,
    },
    edgeCfg: {
      type: 'polyline',
      style: {
        stroke: '#1677ff',
      },
    },
    markerCfg: (cfg) => {
      return {
        position: 'bottom',
      };
    },
    nodeCfg: {
      anchorPoints: [
        [0.5, 0],
        [0.5, 1],
      ],
      type: 'image',
      labelCfg: {
        position: 'bottom',
        offset: -20,
      },
      size: [60, 90],
      title: {
        containerStyle: {
          width: 10,
          fill: 'red',
        },
        style: {
          fontSize: 16, // 设置标题文字大小为 12px
          autoEllipsis: true,
        },
      },
      autoWidth: true,
    },
    behaviors: [],
    height: 600,
    autoFit: false,
    width: innerWidth,
  };
  useEffect(() => {
    fetchData();
  }, [id]);
  function fetchData() {
    return request
      .getWMessage('/syndata/MonitorOverview/getMonitorOverview', { id })
      .then((res) => {
        const resultData = res.data;
        if (resultData?.node.length > 0) {
          const screenWidth = window.innerWidth;
          if (resultData.count < 10) {
            setInnerWidth(screenWidth < 1600 ? 1200 : 1400);
          } else {
            const width = 1400 + (resultData.count - 10) * 130;
            setInnerWidth(width);
          }
          const dataMap = resultData.node.map((i) => ({
            id: i.id,
            img: getImg(i.status),
            label: i.label,
          }));
          setNodeData(dataMap);
        }
        if (resultData?.edges.length > 0) {
          setEdgesData(resultData.edges);
        }
      });
  }
  function getImg(currentStatus) {
    if (currentStatus === null) {
      return sync;
    }
    if (currentStatus) {
      return success;
    }
    return error;
  }
  return (
    <>
      {nodeData?.length > 0 && edgesData?.length > 0 && innerWidth && (
        <div className="overflow-auto">
          <FlowAnalysisGraph {...config} />
        </div>
      )}
    </>
  );
}
export default SourceAndDestinationChart;
