import { Button, Tabs } from 'antd';
import styles from '@/pages/system/syncModel/SyncModel.module.less';
import request from '@/utils/request';
import React, { useEffect, useState } from 'react';
import { useBoolean } from 'ahooks';
import AddAHostDrawer from '@/components/system/syncModel/AddAHostDrawer';
import HostManageTable from '@/components/system/syncModel/HostManageTable';

function SyncHostManage(props) {
  const { recordId: id } = props;
  const [drawerVisible, { setTrue, setFalse }] = useBoolean(false);
  const [items, setItems] = useState([]);
  const [dataSource, setDataSource] = useState([]);
  const [activeKey, setActiveKey] = useState('');
  useEffect(() => handleSearchSyncModel(), [id]);
  function handleSearchSyncModel() {
    return request.getWMessage('/syndata/syncTask/getModelTargetTenantList', { id }).then((res) => {
      setItems(res.data || []);
      if (res.data?.length > 0) {
        const targetTenantId = res.data[0].id;
        setActiveKey(targetTenantId);
      }
    });
  }
  function onTabChange(tabKey) {
    setActiveKey(tabKey);
  }
  function fetchTableData(syncModelTargetTenantId) {
    request
      .getWMessage('/syndata/syncTask/getSyncTaskHostList', {
        id,
        syncModelTargetTenantId: syncModelTargetTenantId || activeKey,
      })
      .then((res) => {
        setDataSource(res.data);
      });
  }
  return (
    <>
      {items?.length > 0 && (
        <Tabs
          onChange={onTabChange}
          activeKey={activeKey}
          style={{ marginTop: '15px' }}
          className={styles.tabContent}
          tabBarExtraContent={
            <Button type="primary" onClick={setTrue}>
              添加主机
            </Button>
          }
          items={items.map((item) => ({
            key: item.id,
            label: item.tenantryName,
            children: (
              <HostManageTable
                activeKey={activeKey}
                dataSource={dataSource}
                fetchTableData={fetchTableData}
              />
            ),
          }))}
        />
      )}
      <AddAHostDrawer
        drawerVisible={drawerVisible}
        activeKey={activeKey}
        setFalse={setFalse}
        fetchTableData={fetchTableData}
        id={id}
      />
    </>
  );
}
export default SyncHostManage;
