import { Button, Card, Col, Form, Radio, Row, Select, Space, Steps, Table } from 'antd';
import { useEffect, useState } from 'react';
import request from '@/utils/request';
import FormBuilder from '@/components/forms/FormBuilder';
import styles from '@/pages/system/syncProcess/SyncProcessStyle.module.less';
import RemoteSelect from '@/components/forms/RemoteSelect';
import {
  CheckRuleDescriptionsMap,
  CheckRulesOptions,
} from '@/pages/system/syncProcess/ProcessStatus';
import EvalToolbar from '@/components/evalBid/EvalToolbar';
import { useHistory, useParams } from 'react-router-dom';
import SyncHostManage from '@/pages/system/syncProcess/SyncHostManage';

const columns = [
  {
    title: '序号',
    dataIndex: 'index',
    width: 50,
    align: 'center',
    render: (text, record, index) => index + 1,
  },
  {
    title: '租户类型',
    dataIndex: 'tenantryName',
    width: 100,
    align: 'center',
  },
  {
    title: '同步表',
    dataIndex: 'smdCount',
    width: 100,
    align: 'center',
    render: (text) => <span className="text-blue-6">{text}</span>,
  },
  {
    title: '同步规则',
    dataIndex: 'tenantMatchingRule',
    width: 100,
  },
];
function TargetTenant(props) {
  return <Table columns={columns} dataSource={props.value} pagination={false} bordered />;
}
function SyncProcessManage() {
  const { id } = useParams();
  const [recordId, setRecordId] = useState(id);
  const [currentStep, setCurrentStep] = useState(0);
  const [form] = Form.useForm();
  const history = useHistory();
  const formItemLayout = { labelCol: { span: 4 }, wrapperCol: { span: 20 } };
  const formItemLayout1 = { labelCol: { span: 2 }, wrapperCol: { span: 22, offset: 1 } };
  const formItem = [
    { name: 'id', visible: false },
    {
      name: 'taskName',
      key: 'taskName',
      label: '任务名称',
      required: true,
    },
    {
      name: 'syncModelId',
      key: 'syncModelId',
      label: '任务模型',
      required: true,
      component: RemoteSelect,
      componentProps: {
        requestUrl: '/syndata/syncTask/getSyncModelList',
        titleAttr: 'model_name',
        valueAttr: 'id',
        style: { minWidth: 200 },
        onChange: (i) => getOtherInfo(i),
      },
    },
    {
      name: 'businessModelName',
      key: 'businessModelName',
      label: '同步业务',
      required: true,
      component: Select,
      disabled: true,
    },
    {
      name: 'tenantryName',
      key: 'tenantryName',
      label: '源租户',
      required: true,
      disabled: true,
    },
    {
      label: '目标租户',
      name: 'syncModelTargetTenantList',
      key: 'syncModelTargetTenantList',
      width: 100,
      align: 'center',
      // required: true,
      component: TargetTenant,
      formItemProps: {
        className: styles.targetTenantStyle,
      },
      span: 24,
      formItemLayout: { labelCol: { span: 2 }, wrapperCol: { span: 23, offset: 1 } },
    },
    {
      key: 'checkRules',
      name: 'checkRules',
      label: '校验规则',
      component: Radio.Group,
      // required: true,
      formItemProps: {
        className: styles.targetTenantStyle,
      },
      children: CheckRulesOptions.map((i) => (
        <Radio value={i.value} key={i.value} style={{ width: '100%', marginBottom: '10px' }}>
          <Space size="large">
            {i.label}
            <span style={{ color: 'rgba(0, 0, 0, 0.45)' }}>
              {CheckRuleDescriptionsMap[i.value]}
            </span>
          </Space>
        </Radio>
      )),
      span: 24,
      formItemLayout: formItemLayout1,
    },
  ];
  useEffect(() => {
    if (recordId || id) {
      fetchFormData();
    }
  }, [recordId]);
  function fetchFormData() {
    return request
      .getWMessage('/syndata/syncTask/getSyncTaskAll', { id: id || recordId })
      .then((res) => {
        form.setFieldsValue(res.data);
      });
  }
  function handleSave() {
    return form.validateFields().then((values) => {
      return request
        .postWMessage('/syndata/syncTask/saveSyncTask', {
          taskName: values.taskName,
          syncModelId: values.syncModelId,
          id: id || recordId,
          checkRules: values.checkRules,
        })
        .then((res) => {
          setRecordId(res.data.id);
        });
    });
  }
  function nextSave() {
    handleSave().then(() => setCurrentStep((current) => current + 1));
  }
  function getOtherInfo(modelId) {
    return request
      .getWMessage('/syndata/syncTask/getSyncModelData', { id: modelId })
      .then((res) => {
        form.setFieldsValue(res.data);
      });
  }
  function handleStart() {
    request
      .postWMessage('/syndata/syncTask/startOrPauseSyncTask', {
        id: id || recordId,
      })
      .then(() => history.push('/system/syncTaskList'));
  }
  return (
    <Card title="同步任务配置">
      <Row justify="center" gutter={[0, 32]}>
        <Col span={16}>
          <Steps current={currentStep}>
            <Steps.Step title="基础配置" />
            <Steps.Step title="主机配置" />
          </Steps>
        </Col>
        {currentStep === 0 && (
          <Col span={22}>
            <Form form={form} {...formItemLayout}>
              <FormBuilder items={formItem} colLayout={{ span: 12 }} />
            </Form>
          </Col>
        )}
        {currentStep === 1 && (
          <Col span={24}>
            <SyncHostManage recordId={recordId} />
          </Col>
        )}
      </Row>
      <EvalToolbar>
        <Space>
          <Button onClick={history.goBack}>返回</Button>

          {currentStep === 0 && (
            <>
              <Button onClick={nextSave} type="primary">
                下一步
              </Button>
              <Button onClick={handleSave}>保存</Button>
            </>
          )}
          {currentStep === 1 && (
            <>
              <Button onClick={() => setCurrentStep((current) => current - 1)}>上一步</Button>
              <Button onClick={handleStart} type="primary">
                启动
              </Button>
            </>
          )}
        </Space>
      </EvalToolbar>
    </Card>
  );
}
export default SyncProcessManage;
