import { Button, Card, Col, Row, Space, Table, Tabs, Tag } from 'antd';
import dataBase from '@/pages/system/syncProcess/img/dataBase.JPG';
import request from '@/utils/request';
import styles from '@/pages/system/syncProcess/SyncProcessStyle.module.less';
import { MissionDetailsName, SyncStatus, TabKey } from '@/pages/system/syncProcess/ProcessStatus';
import React, { useEffect, useState } from 'react';
import { useBoolean } from 'ahooks';
import MonitorDetails from '@/pages/system/syncProcess/MonitorDetails';
import ReSyncProtects from '@/pages/system/syncProcess/ReSyncProtects';
import { useParams } from 'react-router-dom';
import successStatus from '@/pages/system/syncProcess/img/successStatus.svg';
import error from '@/pages/system/syncProcess/img/errorStatus.png';
import ListeningDetails from '@/components/system/syncModel/ListeningDetails';

function SyncProcessManageDetails() {
  const { id } = useParams();
  const [dataSource, setDataSource] = useState([]);
  const [activeKey, setActiveKey] = useState(TabKey.MONITOR);
  const [open, { setTrue, setFalse }] = useBoolean(false);
  const [detailDrawer, { setTrue: setDetailDrawerTrue, setFalse: setDetailDrawerFalse }] =
    useBoolean(false);
  const [taskInfo, setTaskInfo] = useState({});
  const [syncModelTargetTenantId, setSyncModelTargetTenantId] = useState();
  const [tenantryUserType, setTenantryUserType] = useState();
  const tenantColumns = [
    {
      title: '序号',
      dataIndex: 'index',
      width: 50,
      align: 'center',
      render: (text, record, index) => index + 1,
    },
    {
      title: '租户类型',
      dataIndex: 'tenantryUserType',
      width: 130,
      align: 'center',
      render: (text, record) => record.tenantryName || '-',
    },
    {
      title: '结构迁移',
      dataIndex: 'structuralTransitionStatus',
      key: 'structuralTransitionStatus',
      width: 130,
      align: 'center',
      render: (text) => {
        if (text) {
          return (
            <input
              type="image"
              src={successStatus}
              style={{ width: '30px', height: '30px' }}
              alt=""
            />
          );
        }
        return <input type="image" src={error} style={{ width: '30px', height: '30px' }} alt="" />;
      },
    },
    {
      title: '全量迁移',
      dataIndex: 'fullMigrationStatus',
      key: 'fullMigrationStatus',
      width: 130,
      align: 'center',
      render: (text) => {
        if (text) {
          return (
            <input
              type="image"
              alt=""
              src={successStatus}
              style={{ width: '30px', height: '30px' }}
            />
          );
        }
        return <input type="image" alt="" src={error} style={{ width: '30px', height: '30px' }} />;
      },
    },
    {
      title: '增量同步',
      dataIndex: 'incrementalSynchronizationStatus',
      key: 'incrementalSynchronizationStatus',
      width: 130,
      align: 'center',
      render: (text) => (text ? <Tag color="success">执行中</Tag> : '-'),
    },
    {
      title: '今日数据',
      dataIndex: 'todayData',
      key: 'todayData',
      align: 'center',
      width: 130,
      render: (text) => text || '-',
    },
    {
      title: '运行主机',
      width: 180,
      align: 'center',
      dataIndex: 'runningHost',
      key: 'runningHost',
      render: (text, record) => {
        if (text === 0) {
          return (
            <span className="text-red-6">
              {text}/{record.selectHost}
            </span>
          );
        }
        if (text === record.selectHost) {
          return (
            <span className="text-green-6">
              {text}/{record.selectHost}
            </span>
          );
        }
        return (
          <span className="text-orange-6">
            {text}/{record.selectHost}
          </span>
        );
      },
    },
    {
      title: '操作',
      width: 180,
      align: 'center',
      dataIndex: 'options',
      key: 'options',
      render: (_, record) => {
        return (
          <Space>
            <Button
              onClick={() => {
                setDetailDrawerTrue();
                setSyncModelTargetTenantId(record.id);
                setTenantryUserType(record.tenantryUserType);
              }}
              type="link"
            >
              管理
            </Button>
            <Button type="link" disabled={true}>
              暂停
            </Button>
          </Space>
        );
      },
    },
  ];

  useEffect(() => {
    handleSearch();
  }, [id]);
  useEffect(() => {
    fetchTableData();
  }, [id, activeKey]);
  function fetchTableData() {
    return request
      .getWMessage('/syndata/MonitorOverview/getDetailsTenantList', {
        id,
      })
      .then((res) => setDataSource(res.data));
  }
  function handleSearch() {
    return request
      .getWMessage('/syndata/MonitorOverview/getSyncTaskDetails', {
        id,
      })
      .then((res) => {
        const { data } = res;
        setTaskInfo(data);
      });
  }
  function onTabChange(tabKey) {
    setActiveKey(tabKey);
  }
  return (
    <Card
      className={styles.cardBox}
      bodyStyle={{ minHeight: 'calc(80vh - 48px)', padding: '0px 10px' }}
      title={
        <Row align="middle" className="w-4/5">
          <Col span={2}>
            <input type="image" alt="" src={dataBase} style={{ width: 60, height: 70 }} />
          </Col>
          <Col span={4}>
            <Space direction="vertical" size="large">
              <span className="pt-1">{taskInfo?.taskName}</span>
              <div>
                <span>运行状态：</span>
                <span
                  className={
                    taskInfo.status === SyncStatus.SUCCESS ||
                    [SyncStatus.SUCCESS, SyncStatus.TO_COMPILED].includes(taskInfo.isFull)
                      ? 'text-green-6'
                      : 'text-red-6'
                  }
                >
                  {taskInfo.status === SyncStatus.SUCCESS ||
                  [SyncStatus.SUCCESS, SyncStatus.TO_COMPILED].includes(taskInfo.isFull)
                    ? '正常'
                    : '异常'}
                </span>
              </div>
            </Space>
          </Col>
        </Row>
      }
      extra={
        <Space>
          {activeKey === TabKey.MONITOR ? (
            <Button type="primary" danger onClick={setTrue}>
              重新同步
            </Button>
          ) : (
            <Button type="primary" danger style={{ minWidth: '88px' }}>
              重启
            </Button>
          )}
          <Button className={styles.buttonStyle} disabled={true}>
            暂停
          </Button>
        </Space>
      }
    >
      <Tabs
        onChange={onTabChange}
        activeKey={activeKey}
        destroyInactiveTabPane
        className={styles.tabContent}
        items={[
          {
            key: TabKey.MONITOR,
            label: MissionDetailsName[TabKey.MONITOR],
            children: <ListeningDetails activeKey={activeKey} />,
          },
          {
            key: TabKey.TENANT,
            label: MissionDetailsName[TabKey.TENANT],
            children: (
              <Table
                dataSource={dataSource}
                columns={tenantColumns}
                rowKey="id"
                pagination={false}
              />
            ),
          },
        ]}
      />
      <ReSyncProtects open={open} setFalse={setFalse} />
      <MonitorDetails
        open={detailDrawer}
        tenantryUserType={tenantryUserType}
        setFalse={setDetailDrawerFalse}
        syncModelTargetTenantId={syncModelTargetTenantId}
        setSyncModelTargetTenantId={setSyncModelTargetTenantId}
      />
    </Card>
  );
}
export default SyncProcessManageDetails;
