import { ManagePage, withManagePage } from '@/components/hoc/ManagePage';
import { Button, Card, Form, Modal, Popconfirm, Space } from 'antd';
import { tenantCharacteristicsSearchItem } from '@/pages/system/tenant/TenantSearchItem';
import { tenantCharacteristicsColumns } from '@/pages/system/tenant/TenentColumns';
import FormBuilder from '@/components/forms/FormBuilder';
import { useBoolean } from 'ahooks';
import request from '@/utils/request';
import RemoteSelect from '@/components/forms/RemoteSelect';

function TenantCharacteristics(props) {
  const [visible, { setTrue, setFalse }] = useBoolean(false);
  const [form] = Form.useForm();
  const formItemLayout = { labelCol: { span: 4 }, wrapperCol: { span: 18 } };
  function handleCancel() {
    setFalse();
    form.resetFields();
  }
  function handleEdit(record) {
    setTrue();
    form.setFieldsValue(record);
  }
  function handleFormSubmit() {
    return form.validateFields().then((values) => {
      request.postWMessage('/syndata/tenantryFeature/saveTenantryFeature', values).then(() => {
        setFalse();
        props.refreshTableData();
      });
    });
  }
  function handleReset(id) {
    request.getWMessage('/syndata/tenantryFeature/resetTenantryFeature', { id }).then(() => {
      setFalse();
      props.refreshTableData();
    });
  }
  const options = {
    title: '操作',
    width: 80,
    dataIndex: 'options',
    align: 'center',
    render: (_, record) => {
      return (
        <Space>
          <Button type="link" onClick={() => handleEdit(record)} size="small">
            配置
          </Button>
          <Popconfirm title="确认重置吗?" onConfirm={() => handleReset(record.id)}>
            <Button type="link" size="small">
              重置
            </Button>
          </Popconfirm>
        </Space>
      );
    },
  };
  const formItems = [
    { name: 'id', key: 'id', visible: false },
    { name: 'tenantryId', key: 'tenantryId', visible: false },
    {
      name: 'tenantryUserType',
      key: 'tenantryUserType',
      label: '租户类型',
      required: true,
      disabled: true,
      component: RemoteSelect,
      componentProps: {
        placeholder: '请选择',
        requestUrl: '/system/dict/option',
        requestParam: { dictType: 'YHLX' },
        titleAttr: 'dictLabel',
        valueAttr: 'dictValue',
        style: { width: '100%' },
      },
    },
    {
      name: 'featureType',
      key: 'featureType',
      label: '特征类型',
      component: RemoteSelect,
      componentProps: {
        allowClear: true,
        placeholder: '请选择',
        requestUrl: '/system/dict/option',
        requestParam: { dictType: 'TZLX' },
        titleAttr: 'dictLabel',
        valueAttr: 'dictValue',
        style: { width: '100%' },
      },
    },
  ];
  return (
    <>
      <Card title="租户特征管理">
        <ManagePage
          tableColumns={tenantCharacteristicsColumns.concat(options)}
          searchBarItemList={tenantCharacteristicsSearchItem}
        />
      </Card>
      <Modal
        closeIcon
        title="租户特征类型维护"
        open={visible}
        onCancel={handleCancel}
        onOk={handleFormSubmit}
        centered
        width={700}
        className="mb-2"
      >
        <Form form={form} {...formItemLayout}>
          <FormBuilder items={formItems} />
        </Form>
      </Modal>
    </>
  );
}
export default withManagePage(TenantCharacteristics, '/syndata/tenantryFeature/getTenantryFeature');
