import { ManagePage, withManagePage } from '@/components/hoc/ManagePage';
import { Button, Card, Form, Modal, Popconfirm, Space } from 'antd';
import { tenantTypeSearchItem } from '@/pages/system/tenant/TenantSearchItem';
import { tenantTypeColumns } from '@/pages/system/tenant/TenentColumns';
import FormBuilder from '@/components/forms/FormBuilder';
import { useBoolean } from 'ahooks';
import request from '@/utils/request';
import RemoteSelect from '@/components/forms/RemoteSelect';

function TenantTypeManagement(props) {
  const [visible, { setTrue, setFalse }] = useBoolean(false);
  const [form] = Form.useForm();
  const formItemLayout = { labelCol: { span: 4 }, wrapperCol: { span: 18 } };
  function handleAdd() {
    setTrue();
  }
  function handleCancel() {
    setFalse();
    form.resetFields();
  }
  function handleEdit(record) {
    setTrue();
    form.setFieldsValue(record);
  }
  function handleFormSubmit() {
    return form.validateFields().then((values) => {
      request
        .postWMessage('/syndata/tenantry/saveTenantry', values)
        .then(() => props.refreshTableData())
        .finally(() => {
          setFalse();
          form.resetFields();
        });
    });
  }
  function handleDelete(id) {
    request
      .deleteWMessage('/syndata/tenantry/deleteTenantry', { id })
      .then(() => props.refreshTableData());
  }
  const options = {
    title: '操作',
    width: 80,
    dataIndex: 'options',
    align: 'center',
    render: (_, record) => {
      return (
        <Space>
          <Button type="link" onClick={() => handleEdit(record)} size="small">
            编辑
          </Button>
          <Popconfirm title="确认删除吗?" onConfirm={() => handleDelete(record.id)}>
            <Button type="link" size="small">
              删除
            </Button>
          </Popconfirm>
        </Space>
      );
    },
  };
  const formItems = [
    { name: 'id', key: 'id', visible: false },
    {
      name: 'tenantryName',
      key: 'tenantryName',
      label: '租户名称',
      required: true,
    },
    {
      name: 'tenantryUserType',
      key: 'tenantryUserType',
      label: '用户类型',
      required: true,
      component: RemoteSelect,
      componentProps: {
        allowClear: true,
        placeholder: '请选择',
        requestUrl: '/system/dict/option',
        requestParam: { dictType: 'YHLX' },
        titleAttr: 'dictLabel',
        valueAttr: 'dictValue',
        style: { width: '100%' },
      },
    },
    {
      name: 'tenantryIdentification',
      key: 'tenantryIdentification',
      label: '租户标识',
      required: true,
      disabled: !!form.getFieldValue('id'),
    },
    {
      name: 'tenantryType',
      key: 'tenantryType',
      label: '租户类型',
      required: true,
      component: RemoteSelect,
      componentProps: {
        allowClear: true,
        placeholder: '请选择',
        requestUrl: '/system/dict/option',
        requestParam: { dictType: 'ZHLX' },
        titleAttr: 'dictLabel',
        valueAttr: 'dictValue',
        style: { width: '100%' },
      },
    },
  ];
  return (
    <>
      <Card
        title="租户类型管理"
        extra={
          <Button onClick={handleAdd} type="primary">
            新增
          </Button>
        }
      >
        <ManagePage
          tableColumns={tenantTypeColumns.concat(options)}
          searchBarItemList={tenantTypeSearchItem}
        />
      </Card>
      <Modal
        closeIcon
        title="租户类型维护"
        open={visible}
        onCancel={handleCancel}
        onOk={handleFormSubmit}
        centered
        width={700}
      >
        <Form form={form} {...formItemLayout}>
          <FormBuilder items={formItems} />
        </Form>
      </Modal>
    </>
  );
}
export default withManagePage(TenantTypeManagement, '/syndata/tenantry/getTenantry');
