import axios from 'axios';
import { message } from 'antd';
import store from 'store';
import NodeRSA from 'node-rsa';

export default {
  state: {
    visible: false,
  },
  reducers: {
    setVisible(state, visible = true) {
      return { ...state, visible };
    },
  },
  effects: (dispatch) => ({
    preLogin(params) {
      return axios.get(`/system/account/loginPre?username=${params.username}`).then((res) => {
        if (res.error) {
          message.error(res.msg);
          return Promise.reject(res);
        }
        const key = new NodeRSA(res.data, 'public', { encryptionScheme: 'pkcs1' });
        const encrypt1 = key.encrypt(params.password, 'base64');
        const password = encrypt1.replace(/\//g, '_').replace(/\+/g, '-');
        const username = params.username.trim();
        return this.userLogin({ username, password });
      });
    },
    userLogin(params, rootState) {
      return axios.post('/system/account/login', params).then((res) => {
        if (res.success) {
          store.set('jwtToken', res.data);
          // dispatch.user.setToken(res.data.access_token);
          dispatch.user.setToken(res.data);
          if (rootState.login.visible) {
            this.setVisible(false);
          }
          return dispatch.user.fetchUserInfo();
        }
        message.error(res.msg);
        return Promise.reject(res);
      });
    },
    logout() {
      dispatch.user.reset();
    },
  }),
};
