import store from 'store';
import request from '@/utils/request';
import Cookies from 'js-cookie';

const initState = () => ({
  id: store.get('userId') || '',
  info: store.get('userInfo') || {},
  token: Cookies.get('utk') || '',
});

export default {
  state: initState(),
  reducers: {
    setId(userState, id) {
      store.set('userId', id);
      return { ...userState, id };
    },
    setInfo(userState, info) {
      store.set('userInfo', info);
      return { ...userState, info };
    },
    setToken(userState, token) {
      Cookies.set('utk', token);
      return { ...userState, token };
    },
    setUserState(userState, { id, info }) {
      store.set('userId', id);
      store.set('userInfo', info);
      return {
        ...userState,
        id,
        info,
      };
    },
    reset() {
      Cookies.remove('utk');
      return initState();
    },
  },
  effects: () => ({
    fetchUserInfo() {
      return request.getWMessage('/system/account/getCurrentUser').then((res) => {
        this.setUserState({
          id: res.data.id,
          info: res.data,
        });
        return res;
      });
    },
  }),
};
