# React编码规范
>Airbnb的编码规范是在业界非常流行的一套规范，而且它一直都在进化，推出最新技术的规范，例如ES6的规范，让人读了感觉受益匪浅，最近更新了React的编码规范，各位不妨读一读这个规范，借鉴学习，写出漂亮的代码。[原文在此](https://github.com/airbnb/javascript/tree/master/react)

对于下列的编码规范, 本项目已经使用eslint进行了校验, 违反规范的部分会进行提示.

## 基本规范
* 每个文件只包含一个React组件；
  * 但是无状态, 或者 Pure 组件 允许一个文件包含多个组件。eslint: react/no-multi-comp.
* 始终使用 JSX 语法;
* 不要使用 React.createElement方法

## Function vs Class vs React.createClass
如果没有组件没有内部 state 或者 refs，那么推荐普通函数式组件 (不要使用箭头函数) 的写法：

```
// bad
class Listing extends React.Component {
  render() {
    return <div>{this.props.hello}</div>;
  }
}

// bad (因为箭头函数没有“name”属性)
const Listing = ({ hello }) => (
  <div>{hello}</div>
);

// good
function Listing({ hello }) {
  return <div>{hello}</div>;
}
```
## Mixins
* 不要使用mixins

为什么? Mixins 会增加隐式的依赖，导致命名冲突，并且会以雪球式增加复杂度。在大多数情况下Mixins可以被更好的方法替代，如：组件化，高阶组件，工具模块等。


## 变量
* 尽量使用 const 和 let 来声明变量, 使用优先级为: const > let >> var
* 尽量避免使用全局变量 (config除外): 打包之后不同模块之间的全局变量加载顺序不确定, 可能造成无法预知的bug, 且无法通过debug定位问题.
* 如果需要使用全局变量, 尽量通过redux或mobx等状态管理库实现.

## 命名
* 扩展名：React 组件使用.jsx扩展名；
* 文件名：文件名使用帕斯卡命名。 例如： ReservationCard.jsx。
* 引用命名：React 组件使用帕斯卡命名，引用实例采用驼峰命名。 eslint: react/jsx-pascal-case

```
// bad
import reservationCard from './ReservationCard';

// good
import ReservationCard from './ReservationCard';

// bad
const ReservationItem = <ReservationCard />;

// good
const reservationItem = <ReservationCard />;
```
* 组件命名：组件名称应该和文件名一致， 例如： ReservationCard.jsx 应该有一个ReservationCard的引用名称。 但是， 如果是在目录中的组件， 应该使用 index.jsx 作为文件名 并且使用文件夹名称作为组件名：

```
// bad
import Footer from './Footer/Footer';

// bad
import Footer from './Footer/index';

// good
import Footer from './Footer';
```

* 高阶组件命名：对于生成一个新的模块，其中的模块名 displayName 应该为高阶模块名和传入模块名的组合. 例如, 高阶模块 withFoo(), 当传入一个 Bar 模块的时候， 生成的模块名 displayName 应该为 withFoo(Bar).

  为什么？一个模块的 displayName 可能会在开发者工具或者错误信息中使用到，因此有一个能清楚的表达这层关系的值能帮助我们更好的理解模块发生了什么，更好的Debug.

```
// bad
export default function withFoo(WrappedComponent) {
  return function WithFoo(props) {
    return <WrappedComponent {...props} foo />;
  }
}

// good
export default function withFoo(WrappedComponent) {
  function WithFoo(props) {
    return <WrappedComponent {...props} foo />;
  }

  const wrappedComponentName = WrappedComponent.displayName
    || WrappedComponent.name
    || 'Component';

  WithFoo.displayName = `withFoo(${wrappedComponentName})`;
  return WithFoo;
}
```

* 属性命名: 避免使用DOM相关的属性来用作其他的用途.

  为什么？对于style 和 className这样的属性名，我们都会默认它们代表一些特殊的含义，如元素的样式，CSS class的名称。在你的应用中使用这些属性来表示其他的含义会使你的代码更难阅读，更难维护，并且可能会引起bug.

```
// bad
<MyComponent style="fancy" />

// good
<MyComponent variant="fancy" />
```

## 对齐
为 JSX 语法使用下列的对其方式. eslint: react/jsx-closing-bracket-location react/jsx-closing-tag-location

```
// bad
<Foo superLongParam="bar"
     anotherSuperLongParam="baz" />

// good, 有多行属性的话, 新建一行关闭标签
<Foo
  superLongParam="bar"
  anotherSuperLongParam="baz"
/>

// 若能在一行中显示, 直接写成一行
<Foo bar="bar" />

// 子元素按照常规方式缩进
<Foo
  superLongParam="bar"
  anotherSuperLongParam="baz"
>
  <Quux />
</Foo>
```
## 引号
JSX 的属性都采用双引号，其他的 JS 都使用单引号。eslint: jsx-quotes

为什么这样做？JSX 属性 不能包含转义的引号, 所以当输入"don't"这类的缩写的时候用双引号会更方便。

标准的 HTML 属性通常也会使用双引号，所以 JSX 属性也会遵守这样的约定。
```
  // bad
  <Foo bar='bar' />

  // good
  <Foo bar="bar" />

  // bad
  <Foo style={{ left: "20px" }} />

  // good
  <Foo style={{ left: '20px' }} />
```
## 空格
终始在自闭合标签前面添加一个空格。

```
// bad
<Foo/>

// very bad
<Foo                 />

// bad
<Foo
 />

// good
<Foo />
```
## 属性
属性名称始终使用驼峰命名法。

```
// bad
<Foo
  UserName="hello"
  phone_number={12345678}
/>

// good
<Foo
  userName="hello"
  phoneNumber={12345678}
/>
```
当属性值等于true的时候，省略该属性的赋值。 eslint: react/jsx-boolean-value

```
// bad
<Foo
  hidden={true}
/>

// good
<Foo
  hidden
/>
```

避免使用数组的index来作为属性key的值，推荐使用唯一ID.
```
// bad
{todos.map((todo, index) =>
  <Todo
    {...todo}
    key={index}
  />
)}

// good
{todos.map(todo => (
  <Todo
    {...todo}
    key={todo.id}
  />
))}
```

总是在Refs里使用回调函数. eslint: react/no-string-refs
```jsx
// bad
<Foo
  ref="myRef"
/>

// good
<Foo
  ref={(ref) => { this.myRef = ref; }}
/>
```


## 括号
用括号包裹多行 JSX 标签。 eslint: react/wrap-multilines

```
// bad
render() {
  return <MyComponent className="long body" foo="bar">
           <MyChild />
         </MyComponent>;
}

// good
render() {
  return (
    <MyComponent className="long body" foo="bar">
      <MyChild />
    </MyComponent>
  );
}

// good, when single line
render() {
  const body = <div>hello</div>;
  return <MyComponent>{body}</MyComponent>;
}
```
## 标签
当标签没有子元素时，始终时候自闭合标签。 eslint: react/self-closing-comp

```
// bad
<Foo className="stuff"></Foo>

// good
<Foo className="stuff" />
如果控件有多行属性，关闭标签要另起一行。 eslint: react/jsx-closing-bracket-location


// bad
<Foo
  bar="bar"
  baz="baz" />

// good
<Foo
  bar="bar"
  baz="baz"
/>
```

## 方法
在 render 方法中事件的回调函数，应该在构造函数中进行bind绑定。 eslint: react/jsx-no-bind

为什么这样做? 在 render 方法中的 bind 调用每次调用 render 的时候都会创建一个全新的函数。
```
  // bad
  class extends React.Component {
    onClickDiv() {
      // do stuff
    }

    render() {
      return <div onClick={this.onClickDiv.bind(this)} />
    }
  }

  // good
  class extends React.Component {
    constructor(props) {
      super(props);

      this.onClickDiv = this.onClickDiv.bind(this);
    }

    onClickDiv() {
      // do stuff
    }

    render() {
      return <div onClick={this.onClickDiv} />
    }
  }
  ```
React 组件的内部方法命名不要使用下划线前缀。

```
// bad
React.createClass({
  _onClickSubmit() {
    // do stuff
  },

  // other stuff
});

// good
class extends React.Component {
  onClickSubmit() {
    // do stuff
  }

  // other stuff
}
```
## 排序
class extends React.Component的顺序：

1. 可选的 static 方法
2. constructor 构造函数
3. getChildContext 获取子元素内容
4. componentWillMount 模块渲染前
5. componentDidMount 模块渲染后
6. componentWillReceiveProps 模块将接受新的数据
7. shouldComponentUpdate 判断模块需不需要重新渲染
8. componentWillUpdate 上面的方法返回 true， 模块将重新渲染
9. componentDidUpdate 模块渲染结束
10. componentWillUnmount 模块将从DOM中清除, 做一些清理任务
11. 点击回调或者事件处理器 如 onClickSubmit() 或 onChangeDescription()
12. render 里的 getter 方法 如 getSelectReason() 或 getFooterContent()
13. 可选的 render 方法 如 renderNavigation() 或 renderProfilePicture()
14. render 方法

## 怎样定义 propTypes, defaultProps, contextTypes等
在组件前定义propTypes和defaultProps可以节省查阅类型的时间

```
import React, { PropTypes } from 'react';

const propTypes = {
  id: PropTypes.number.isRequired,
  url: PropTypes.string.isRequired,
  text: PropTypes.string,
};

const defaultProps = {
  text: 'Hello World',
};

class Link extends React.Component {
  static methodsAreOk() {
    return true;
  }

  render() {
    return <a href={this.props.url} data-id={this.props.id}>{this.props.text}</a>
  }
}

Link.propTypes = propTypes;
Link.defaultProps = defaultProps;

export default Link;
```
